/*     */ package org.apache.batik.dom;
/*     */ 
/*     */ import org.apache.batik.dom.util.DOMUtilities;
/*     */ import org.w3c.dom.Attr;
/*     */ import org.w3c.dom.DOMException;
/*     */ import org.w3c.dom.Element;
/*     */ import org.w3c.dom.Node;
/*     */ import org.w3c.dom.TypeInfo;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public abstract class AbstractAttr
/*     */   extends AbstractParentNode
/*     */   implements Attr
/*     */ {
/*     */   protected String nodeName;
/*     */   protected boolean unspecified;
/*     */   protected boolean isIdAttr;
/*     */   protected AbstractElement ownerElement;
/*     */   protected TypeInfo typeInfo;
/*     */   
/*     */   protected AbstractAttr() {}
/*     */   
/*     */   protected AbstractAttr(String name, AbstractDocument owner) throws DOMException {
/*  77 */     this.ownerDocument = owner;
/*  78 */     if (owner.getStrictErrorChecking() && !DOMUtilities.isValidName(name)) {
/*  79 */       throw createDOMException((short)5, "xml.name", new Object[] { name });
/*     */     }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void setNodeName(String v) {
/*  89 */     this.nodeName = v;
/*  90 */     this.isIdAttr = this.ownerDocument.isId(this);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  98 */   public String getNodeName() { return this.nodeName; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 106 */   public short getNodeType() { return 2; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public String getNodeValue() {
/* 114 */     Node first = getFirstChild();
/* 115 */     if (first == null) {
/* 116 */       return "";
/*     */     }
/* 118 */     Node n = first.getNextSibling();
/* 119 */     if (n == null) {
/* 120 */       return first.getNodeValue();
/*     */     }
/* 122 */     StringBuffer result = new StringBuffer(first.getNodeValue());
/*     */     do {
/* 124 */       result.append(n.getNodeValue());
/* 125 */       n = n.getNextSibling();
/* 126 */     } while (n != null);
/* 127 */     return result.toString();
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void setNodeValue(String nodeValue) {
/* 134 */     if (isReadonly()) {
/* 135 */       throw createDOMException((short)7, "readonly.node", new Object[] { new Integer(getNodeType()), getNodeName() });
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 141 */     String s = getNodeValue();
/*     */     
/*     */     Node n;
/*     */     
/* 145 */     while ((n = getFirstChild()) != null) {
/* 146 */       removeChild(n);
/*     */     }
/*     */     
/* 149 */     String val = (nodeValue == null) ? "" : nodeValue;
/*     */ 
/*     */     
/* 152 */     n = getOwnerDocument().createTextNode(val);
/* 153 */     appendChild(n);
/*     */     
/* 155 */     if (this.ownerElement != null) {
/* 156 */       this.ownerElement.fireDOMAttrModifiedEvent(this.nodeName, this, s, val, (short)1);
/*     */     }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 169 */   public String getName() { return getNodeName(); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 177 */   public boolean getSpecified() { return !this.unspecified; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 184 */   public void setSpecified(boolean v) { this.unspecified = !v; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 192 */   public String getValue() { return getNodeValue(); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 199 */   public void setValue(String value) { setNodeValue(value); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 206 */   public void setOwnerElement(AbstractElement v) { this.ownerElement = v; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 213 */   public Element getOwnerElement() { return this.ownerElement; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public TypeInfo getSchemaTypeInfo() {
/* 220 */     if (this.typeInfo == null) {
/* 221 */       this.typeInfo = new AttrTypeInfo(this);
/*     */     }
/* 223 */     return this.typeInfo;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 230 */   public boolean isId() { return this.isIdAttr; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 237 */   public void setIsId(boolean isId) { this.isIdAttr = isId; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 244 */   protected void nodeAdded(Node n) { setSpecified(true); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 251 */   protected void nodeToBeRemoved(Node n) { setSpecified(true); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected Node export(Node n, AbstractDocument d) {
/* 258 */     super.export(n, d);
/* 259 */     AbstractAttr aa = (AbstractAttr)n;
/* 260 */     aa.nodeName = this.nodeName;
/* 261 */     aa.unspecified = false;
/* 262 */     aa.isIdAttr = d.isId(aa);
/* 263 */     return n;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected Node deepExport(Node n, AbstractDocument d) {
/* 270 */     super.deepExport(n, d);
/* 271 */     AbstractAttr aa = (AbstractAttr)n;
/* 272 */     aa.nodeName = this.nodeName;
/* 273 */     aa.unspecified = false;
/* 274 */     aa.isIdAttr = d.isId(aa);
/* 275 */     return n;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected Node copyInto(Node n) {
/* 283 */     super.copyInto(n);
/* 284 */     AbstractAttr aa = (AbstractAttr)n;
/* 285 */     aa.nodeName = this.nodeName;
/* 286 */     aa.unspecified = this.unspecified;
/* 287 */     aa.isIdAttr = this.isIdAttr;
/* 288 */     return n;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected Node deepCopyInto(Node n) {
/* 296 */     super.deepCopyInto(n);
/* 297 */     AbstractAttr aa = (AbstractAttr)n;
/* 298 */     aa.nodeName = this.nodeName;
/* 299 */     aa.unspecified = this.unspecified;
/* 300 */     aa.isIdAttr = this.isIdAttr;
/* 301 */     return n;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected void checkChildType(Node n, boolean replace) {
/* 308 */     switch (n.getNodeType()) {
/*     */       case 3:
/*     */       case 5:
/*     */       case 11:
/*     */         return;
/*     */     } 
/* 314 */     throw createDOMException((short)3, "child.type", new Object[] { new Integer(getNodeType()), getNodeName(), new Integer(n.getNodeType()), n.getNodeName() });
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected void fireDOMSubtreeModifiedEvent() {
/* 328 */     AbstractDocument doc = getCurrentDocument();
/* 329 */     if (doc.getEventsEnabled()) {
/* 330 */       super.fireDOMSubtreeModifiedEvent();
/* 331 */       if (getOwnerElement() != null)
/* 332 */         ((AbstractElement)getOwnerElement()).fireDOMSubtreeModifiedEvent(); 
/*     */     } 
/*     */   }
/*     */   
/*     */   public class AttrTypeInfo
/*     */     implements TypeInfo
/*     */   {
/*     */     private final AbstractAttr this$0;
/*     */     
/* 341 */     public AttrTypeInfo(AbstractAttr this$0) { this.this$0 = this$0; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 347 */     public String getTypeNamespace() { return null; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 354 */     public String getTypeName() { return null; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 361 */     public boolean isDerivedFrom(String ns, String name, int method) { return false; }
/*     */   }
/*     */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-dom.jar!\org\apache\batik\dom\AbstractAttr.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */