/*      */ package org.apache.batik.dom;
/*      */ 
/*      */ import java.io.IOException;
/*      */ import java.io.ObjectInputStream;
/*      */ import java.io.ObjectOutputStream;
/*      */ import java.lang.reflect.Method;
/*      */ import java.util.ArrayList;
/*      */ import java.util.HashMap;
/*      */ import java.util.Iterator;
/*      */ import java.util.LinkedList;
/*      */ import java.util.List;
/*      */ import java.util.Locale;
/*      */ import java.util.Map;
/*      */ import java.util.MissingResourceException;
/*      */ import java.util.WeakHashMap;
/*      */ import javax.xml.transform.TransformerException;
/*      */ import org.apache.batik.dom.events.DocumentEventSupport;
/*      */ import org.apache.batik.dom.events.EventSupport;
/*      */ import org.apache.batik.dom.traversal.TraversalSupport;
/*      */ import org.apache.batik.dom.util.DOMUtilities;
/*      */ import org.apache.batik.dom.xbl.GenericXBLManager;
/*      */ import org.apache.batik.dom.xbl.XBLManager;
/*      */ import org.apache.batik.i18n.Localizable;
/*      */ import org.apache.batik.i18n.LocalizableSupport;
/*      */ import org.apache.batik.util.CleanerThread;
/*      */ import org.apache.batik.util.SoftDoublyIndexedTable;
/*      */ import org.apache.batik.xml.XMLUtilities;
/*      */ import org.apache.xml.utils.PrefixResolver;
/*      */ import org.apache.xpath.XPath;
/*      */ import org.apache.xpath.XPathContext;
/*      */ import org.apache.xpath.objects.XObject;
/*      */ import org.w3c.dom.Attr;
/*      */ import org.w3c.dom.CDATASection;
/*      */ import org.w3c.dom.Comment;
/*      */ import org.w3c.dom.DOMConfiguration;
/*      */ import org.w3c.dom.DOMError;
/*      */ import org.w3c.dom.DOMErrorHandler;
/*      */ import org.w3c.dom.DOMException;
/*      */ import org.w3c.dom.DOMImplementation;
/*      */ import org.w3c.dom.DOMLocator;
/*      */ import org.w3c.dom.DOMStringList;
/*      */ import org.w3c.dom.Document;
/*      */ import org.w3c.dom.DocumentFragment;
/*      */ import org.w3c.dom.DocumentType;
/*      */ import org.w3c.dom.Element;
/*      */ import org.w3c.dom.EntityReference;
/*      */ import org.w3c.dom.NamedNodeMap;
/*      */ import org.w3c.dom.Node;
/*      */ import org.w3c.dom.NodeList;
/*      */ import org.w3c.dom.ProcessingInstruction;
/*      */ import org.w3c.dom.Text;
/*      */ import org.w3c.dom.events.DocumentEvent;
/*      */ import org.w3c.dom.events.Event;
/*      */ import org.w3c.dom.events.MutationNameEvent;
/*      */ import org.w3c.dom.traversal.DocumentTraversal;
/*      */ import org.w3c.dom.traversal.NodeFilter;
/*      */ import org.w3c.dom.traversal.NodeIterator;
/*      */ import org.w3c.dom.traversal.TreeWalker;
/*      */ import org.w3c.dom.xpath.XPathEvaluator;
/*      */ import org.w3c.dom.xpath.XPathException;
/*      */ import org.w3c.dom.xpath.XPathExpression;
/*      */ import org.w3c.dom.xpath.XPathNSResolver;
/*      */ import org.w3c.dom.xpath.XPathResult;
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ public abstract class AbstractDocument
/*      */   extends AbstractParentNode
/*      */   implements Document, DocumentEvent, DocumentTraversal, Localizable, XPathEvaluator
/*      */ {
/*      */   protected static final String RESOURCES = "org.apache.batik.dom.resources.Messages";
/*  105 */   protected LocalizableSupport localizableSupport = new LocalizableSupport("org.apache.batik.dom.resources.Messages", getClass().getClassLoader());
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected DOMImplementation implementation;
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected TraversalSupport traversalSupport;
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected DocumentEventSupport documentEventSupport;
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected boolean eventsEnabled;
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected WeakHashMap elementsByTagNames;
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected WeakHashMap elementsByTagNamesNS;
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected String inputEncoding;
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected String xmlEncoding;
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  152 */   protected String xmlVersion = "1.0";
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected boolean xmlStandalone;
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected String documentURI;
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected boolean strictErrorChecking = true;
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected DocumentConfiguration domConfig;
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  177 */   protected XBLManager xblManager = new GenericXBLManager();
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected Map elementsById;
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected AbstractDocument() {}
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public AbstractDocument(DocumentType dt, DOMImplementation impl) {
/*  198 */     this.implementation = impl;
/*  199 */     if (dt != null) {
/*  200 */       if (dt instanceof GenericDocumentType) {
/*  201 */         GenericDocumentType gdt = (GenericDocumentType)dt;
/*  202 */         if (gdt.getOwnerDocument() == null)
/*  203 */           gdt.setOwnerDocument(this); 
/*      */       } 
/*  205 */       appendChild(dt);
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  214 */   public void setDocumentInputEncoding(String ie) { this.inputEncoding = ie; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  221 */   public void setDocumentXmlEncoding(String xe) { this.xmlEncoding = xe; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  228 */   public void setLocale(Locale l) { this.localizableSupport.setLocale(l); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  235 */   public Locale getLocale() { return this.localizableSupport.getLocale(); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  244 */   public String formatMessage(String key, Object[] args) throws MissingResourceException { return this.localizableSupport.formatMessage(key, args); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  251 */   public boolean getEventsEnabled() { return this.eventsEnabled; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  258 */   public void setEventsEnabled(boolean b) { this.eventsEnabled = b; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  266 */   public String getNodeName() { return "#document"; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  274 */   public short getNodeType() { return 9; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public DocumentType getDoctype() {
/*  281 */     for (Node n = getFirstChild(); n != null; n = n.getNextSibling()) {
/*  282 */       if (n.getNodeType() == 10) {
/*  283 */         return (DocumentType)n;
/*      */       }
/*      */     } 
/*  286 */     return null;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void setDoctype(DocumentType dt) {
/*  293 */     if (dt != null) {
/*  294 */       appendChild(dt);
/*  295 */       ((ExtendedNode)dt).setReadonly(true);
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  304 */   public DOMImplementation getImplementation() { return this.implementation; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public Element getDocumentElement() {
/*  312 */     for (Node n = getFirstChild(); n != null; n = n.getNextSibling()) {
/*  313 */       if (n.getNodeType() == 1) {
/*  314 */         return (Element)n;
/*      */       }
/*      */     } 
/*  317 */     return null;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  326 */   public Node importNode(Node importedNode, boolean deep) throws DOMException { return importNode(importedNode, deep, false); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public Node importNode(Node importedNode, boolean deep, boolean trimId) {
/*      */     Element e;
/*      */     Node result;
/*  346 */     switch (importedNode.getNodeType()) {
/*      */       case 1:
/*  348 */         e = createElementNS(importedNode.getNamespaceURI(), importedNode.getNodeName());
/*      */         
/*  350 */         result = e;
/*  351 */         if (importedNode.hasAttributes()) {
/*  352 */           NamedNodeMap attr = importedNode.getAttributes();
/*  353 */           int len = attr.getLength();
/*  354 */           for (int i = 0; i < len; i++) {
/*  355 */             Attr a = (Attr)attr.item(i);
/*  356 */             if (a.getSpecified()) {
/*  357 */               AbstractAttr aa = (AbstractAttr)importNode(a, true);
/*  358 */               if (trimId && aa.isId())
/*  359 */                 aa.setIsId(false); 
/*  360 */               e.setAttributeNodeNS(aa);
/*      */             } 
/*      */           } 
/*      */         } 
/*      */         break;
/*      */       case 2:
/*  366 */         result = createAttributeNS(importedNode.getNamespaceURI(), importedNode.getNodeName());
/*      */         break;
/*      */ 
/*      */       
/*      */       case 3:
/*  371 */         result = createTextNode(importedNode.getNodeValue());
/*  372 */         deep = false;
/*      */         break;
/*      */       
/*      */       case 4:
/*  376 */         result = createCDATASection(importedNode.getNodeValue());
/*  377 */         deep = false;
/*      */         break;
/*      */       
/*      */       case 5:
/*  381 */         result = createEntityReference(importedNode.getNodeName());
/*      */         break;
/*      */       
/*      */       case 7:
/*  385 */         result = createProcessingInstruction(importedNode.getNodeName(), importedNode.getNodeValue());
/*      */ 
/*      */         
/*  388 */         deep = false;
/*      */         break;
/*      */       
/*      */       case 8:
/*  392 */         result = createComment(importedNode.getNodeValue());
/*  393 */         deep = false;
/*      */         break;
/*      */       
/*      */       case 11:
/*  397 */         result = createDocumentFragment();
/*      */         break;
/*      */       
/*      */       default:
/*  401 */         throw createDOMException((short)9, "import.node", new Object[0]);
/*      */     } 
/*      */ 
/*      */ 
/*      */     
/*  406 */     if (importedNode instanceof AbstractNode)
/*      */     {
/*      */       
/*  409 */       fireUserDataHandlers((short)2, importedNode, result);
/*      */     }
/*      */ 
/*      */ 
/*      */     
/*  414 */     if (deep) {
/*  415 */       Node n = importedNode.getFirstChild();
/*  416 */       for (; n != null; 
/*  417 */         n = n.getNextSibling()) {
/*  418 */         result.appendChild(importNode(n, true));
/*      */       }
/*      */     } 
/*  421 */     return result;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public Node cloneNode(boolean deep) {
/*  428 */     Document n = (Document)newNode();
/*  429 */     copyInto(n);
/*  430 */     fireUserDataHandlers((short)1, this, n);
/*  431 */     if (deep) {
/*  432 */       Node c = getFirstChild();
/*  433 */       for (; c != null; 
/*  434 */         c = c.getNextSibling()) {
/*  435 */         n.appendChild(n.importNode(c, deep));
/*      */       }
/*      */     } 
/*  438 */     return n;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public abstract boolean isId(Attr paramAttr);
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  451 */   public Element getElementById(String id) { return getChildElementById(getDocumentElement(), id); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public Element getChildElementById(Node requestor, String id) {
/*  459 */     if (id == null || id.length() == 0) return null; 
/*  460 */     if (this.elementsById == null) return null;
/*      */     
/*  462 */     Node root = getRoot(requestor);
/*      */     
/*  464 */     Object o = this.elementsById.get(id);
/*  465 */     if (o == null) return null; 
/*  466 */     if (o instanceof IdSoftRef) {
/*  467 */       o = ((IdSoftRef)o).get();
/*  468 */       if (o == null) {
/*  469 */         this.elementsById.remove(id);
/*  470 */         return null;
/*      */       } 
/*  472 */       Element e = (Element)o;
/*  473 */       if (getRoot(e) == root)
/*  474 */         return e; 
/*  475 */       return null;
/*      */     } 
/*      */ 
/*      */     
/*  479 */     List l = (List)o;
/*  480 */     Iterator li = l.iterator();
/*  481 */     while (li.hasNext()) {
/*  482 */       IdSoftRef sr = (IdSoftRef)li.next();
/*  483 */       o = sr.get();
/*  484 */       if (o == null) {
/*  485 */         li.remove(); continue;
/*      */       } 
/*  487 */       Element e = (Element)o;
/*  488 */       if (getRoot(e) == root) {
/*  489 */         return e;
/*      */       }
/*      */     } 
/*  492 */     return null;
/*      */   }
/*      */   
/*      */   protected Node getRoot(Node n) {
/*  496 */     Node r = n;
/*  497 */     while (n != null) {
/*  498 */       r = n;
/*  499 */       n = n.getParentNode();
/*      */     } 
/*  501 */     return r;
/*      */   }
/*      */   
/*      */   protected class IdSoftRef extends CleanerThread.SoftReferenceCleared {
/*      */     String id;
/*      */     
/*      */     IdSoftRef(AbstractDocument this$0, Object o, String id) {
/*  508 */       super(o); this.this$0 = this$0;
/*  509 */       this.id = id;
/*      */     } List list; private final AbstractDocument this$0;
/*      */     IdSoftRef(AbstractDocument this$0, Object o, String id, List list) {
/*  512 */       super(o); this.this$0 = this$0;
/*  513 */       this.id = id;
/*  514 */       this.list = list;
/*      */     }
/*      */     
/*  517 */     public void setList(List list) { this.list = list; }
/*      */     
/*      */     public void cleared() {
/*  520 */       if (this.this$0.elementsById == null)
/*  521 */         return;  synchronized (this.this$0.elementsById) {
/*  522 */         if (this.list != null) {
/*  523 */           this.list.remove(this);
/*      */         } else {
/*  525 */           Object o = this.this$0.elementsById.remove(this.id);
/*  526 */           if (o != this) {
/*  527 */             this.this$0.elementsById.put(this.id, o);
/*      */           }
/*      */         } 
/*      */       } 
/*      */     }
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void removeIdEntry(Element e, String id) {
/*  538 */     if (id == null)
/*  539 */       return;  if (this.elementsById == null)
/*      */       return; 
/*  541 */     synchronized (this.elementsById) {
/*  542 */       Object o = this.elementsById.get(id);
/*  543 */       if (o == null)
/*      */         return; 
/*  545 */       if (o instanceof IdSoftRef) {
/*  546 */         this.elementsById.remove(id);
/*      */         
/*      */         return;
/*      */       } 
/*  550 */       List l = (List)o;
/*  551 */       Iterator li = l.iterator();
/*  552 */       while (li.hasNext()) {
/*  553 */         IdSoftRef ip = (IdSoftRef)li.next();
/*  554 */         o = ip.get();
/*  555 */         if (o == null) {
/*  556 */           li.remove(); continue;
/*  557 */         }  if (e == o) {
/*  558 */           li.remove();
/*      */           
/*      */           break;
/*      */         } 
/*      */       } 
/*  563 */       if (l.size() == 0)
/*  564 */         this.elementsById.remove(id); 
/*      */     } 
/*      */   }
/*      */   
/*      */   public void addIdEntry(Element e, String id) {
/*  569 */     if (id == null)
/*      */       return; 
/*  571 */     if (this.elementsById == null) {
/*  572 */       Map tmp = new HashMap();
/*  573 */       tmp.put(id, new IdSoftRef(this, e, id));
/*  574 */       this.elementsById = tmp;
/*      */       
/*      */       return;
/*      */     } 
/*  578 */     synchronized (this.elementsById) {
/*      */       
/*  580 */       Object o = this.elementsById.get(id);
/*  581 */       if (o == null) {
/*  582 */         this.elementsById.put(id, new IdSoftRef(this, e, id));
/*      */         return;
/*      */       } 
/*  585 */       if (o instanceof IdSoftRef) {
/*  586 */         IdSoftRef ip = (IdSoftRef)o;
/*  587 */         Object r = ip.get();
/*  588 */         if (r == null) {
/*  589 */           this.elementsById.put(id, new IdSoftRef(this, e, id));
/*      */           
/*      */           return;
/*      */         } 
/*      */         
/*  594 */         List l = new ArrayList(4);
/*  595 */         ip.setList(l);
/*  596 */         l.add(ip);
/*  597 */         l.add(new IdSoftRef(this, e, id, l));
/*  598 */         this.elementsById.put(id, l);
/*      */         
/*      */         return;
/*      */       } 
/*  602 */       List l = (List)o;
/*  603 */       l.add(new IdSoftRef(this, e, id, l));
/*      */     } 
/*      */   }
/*      */   
/*      */   public void updateIdEntry(Element e, String oldId, String newId) {
/*  608 */     if (oldId == newId || (oldId != null && oldId.equals(newId))) {
/*      */       return;
/*      */     }
/*      */     
/*  612 */     removeIdEntry(e, oldId);
/*      */     
/*  614 */     addIdEntry(e, newId);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public AbstractParentNode.ElementsByTagName getElementsByTagName(Node n, String ln) {
/*  622 */     if (this.elementsByTagNames == null) {
/*  623 */       return null;
/*      */     }
/*      */     
/*  626 */     SoftDoublyIndexedTable t = (SoftDoublyIndexedTable)this.elementsByTagNames.get(n);
/*  627 */     if (t == null) {
/*  628 */       return null;
/*      */     }
/*  630 */     return (AbstractParentNode.ElementsByTagName)t.get(null, ln);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void putElementsByTagName(Node n, String ln, AbstractParentNode.ElementsByTagName l) {
/*  637 */     if (this.elementsByTagNames == null) {
/*  638 */       this.elementsByTagNames = new WeakHashMap(11);
/*      */     }
/*      */     
/*  641 */     SoftDoublyIndexedTable t = (SoftDoublyIndexedTable)this.elementsByTagNames.get(n);
/*  642 */     if (t == null) {
/*  643 */       this.elementsByTagNames.put(n, t = new SoftDoublyIndexedTable());
/*      */     }
/*  645 */     t.put(null, ln, l);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public AbstractParentNode.ElementsByTagNameNS getElementsByTagNameNS(Node n, String ns, String ln) {
/*  654 */     if (this.elementsByTagNamesNS == null) {
/*  655 */       return null;
/*      */     }
/*      */     
/*  658 */     SoftDoublyIndexedTable t = (SoftDoublyIndexedTable)this.elementsByTagNamesNS.get(n);
/*  659 */     if (t == null) {
/*  660 */       return null;
/*      */     }
/*  662 */     return (AbstractParentNode.ElementsByTagNameNS)t.get(ns, ln);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void putElementsByTagNameNS(Node n, String ns, String ln, AbstractParentNode.ElementsByTagNameNS l) {
/*  670 */     if (this.elementsByTagNamesNS == null) {
/*  671 */       this.elementsByTagNamesNS = new WeakHashMap(11);
/*      */     }
/*      */     
/*  674 */     SoftDoublyIndexedTable t = (SoftDoublyIndexedTable)this.elementsByTagNamesNS.get(n);
/*  675 */     if (t == null) {
/*  676 */       this.elementsByTagNamesNS.put(n, t = new SoftDoublyIndexedTable());
/*      */     }
/*  678 */     t.put(ns, ln, l);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public Event createEvent(String eventType) throws DOMException {
/*  688 */     if (this.documentEventSupport == null) {
/*  689 */       this.documentEventSupport = ((AbstractDOMImplementation)this.implementation).createDocumentEventSupport();
/*      */     }
/*      */ 
/*      */     
/*  693 */     return this.documentEventSupport.createEvent(eventType);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public boolean canDispatch(String ns, String eventType) {
/*  701 */     if (eventType == null) {
/*  702 */       return false;
/*      */     }
/*  704 */     if (ns != null && ns.length() == 0) {
/*  705 */       ns = null;
/*      */     }
/*  707 */     if (ns == null || ns.equals("http://www.w3.org/2001/xml-events")) {
/*  708 */       return (eventType.equals("Event") || eventType.equals("MutationEvent") || eventType.equals("MutationNameEvent") || eventType.equals("UIEvent") || eventType.equals("MouseEvent") || eventType.equals("KeyEvent") || eventType.equals("KeyboardEvent") || eventType.equals("TextEvent") || eventType.equals("CustomEvent"));
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  718 */     return false;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public NodeIterator createNodeIterator(Node root, int whatToShow, NodeFilter filter, boolean entityReferenceExpansion) throws DOMException {
/*  732 */     if (this.traversalSupport == null) {
/*  733 */       this.traversalSupport = new TraversalSupport();
/*      */     }
/*  735 */     return this.traversalSupport.createNodeIterator(this, root, whatToShow, filter, entityReferenceExpansion);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  749 */   public TreeWalker createTreeWalker(Node root, int whatToShow, NodeFilter filter, boolean entityReferenceExpansion) throws DOMException { return TraversalSupport.createTreeWalker(this, root, whatToShow, filter, entityReferenceExpansion); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  758 */   public void detachNodeIterator(NodeIterator it) { this.traversalSupport.detachNodeIterator(it); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void nodeToBeRemoved(Node node) {
/*  765 */     if (this.traversalSupport != null) {
/*  766 */       this.traversalSupport.nodeToBeRemoved(node);
/*      */     }
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  774 */   protected AbstractDocument getCurrentDocument() { return this; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  783 */   protected Node export(Node n, Document d) { throw createDOMException((short)9, "import.document", new Object[0]); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  794 */   protected Node deepExport(Node n, Document d) { throw createDOMException((short)9, "import.document", new Object[0]); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected Node copyInto(Node n) {
/*  804 */     super.copyInto(n);
/*  805 */     AbstractDocument ad = (AbstractDocument)n;
/*  806 */     ad.implementation = this.implementation;
/*  807 */     ad.localizableSupport = new LocalizableSupport("org.apache.batik.dom.resources.Messages", getClass().getClassLoader());
/*      */     
/*  809 */     ad.inputEncoding = this.inputEncoding;
/*  810 */     ad.xmlEncoding = this.xmlEncoding;
/*  811 */     ad.xmlVersion = this.xmlVersion;
/*  812 */     ad.xmlStandalone = this.xmlStandalone;
/*  813 */     ad.documentURI = this.documentURI;
/*  814 */     ad.strictErrorChecking = this.strictErrorChecking;
/*      */     
/*  816 */     return n;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected Node deepCopyInto(Node n) {
/*  824 */     super.deepCopyInto(n);
/*  825 */     AbstractDocument ad = (AbstractDocument)n;
/*  826 */     ad.implementation = this.implementation;
/*  827 */     ad.localizableSupport = new LocalizableSupport("org.apache.batik.dom.resources.Messages", getClass().getClassLoader());
/*      */     
/*  829 */     return n;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected void checkChildType(Node n, boolean replace) {
/*  836 */     short t = n.getNodeType();
/*  837 */     switch (t) {
/*      */       case 1:
/*      */       case 7:
/*      */       case 8:
/*      */       case 10:
/*      */       case 11:
/*      */         break;
/*      */       default:
/*  845 */         throw createDOMException((short)3, "child.type", new Object[] { new Integer(getNodeType()), getNodeName(), new Integer(t), n.getNodeName() });
/*      */     } 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  852 */     if ((!replace && t == 1 && getDocumentElement() != null) || (t == 10 && getDoctype() != null))
/*      */     {
/*      */       
/*  855 */       throw createDOMException((short)9, "document.child.already.exists", new Object[] { new Integer(t), n.getNodeName() });
/*      */     }
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  866 */   public String getInputEncoding() { return this.inputEncoding; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  873 */   public String getXmlEncoding() { return this.xmlEncoding; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  880 */   public boolean getXmlStandalone() { return this.xmlStandalone; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  887 */   public void setXmlStandalone(boolean b) { this.xmlStandalone = b; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  894 */   public String getXmlVersion() { return this.xmlVersion; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void setXmlVersion(String v) {
/*  901 */     if (v == null || (!v.equals("1.0") && !v.equals("1.1")))
/*      */     {
/*      */       
/*  904 */       throw createDOMException((short)9, "xml.version", new Object[] { v });
/*      */     }
/*      */ 
/*      */     
/*  908 */     this.xmlVersion = v;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  915 */   public boolean getStrictErrorChecking() { return this.strictErrorChecking; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  922 */   public void setStrictErrorChecking(boolean b) { this.strictErrorChecking = b; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  929 */   public String getDocumentURI() { return this.documentURI; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  936 */   public void setDocumentURI(String uri) { this.documentURI = uri; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public DOMConfiguration getDomConfig() {
/*  943 */     if (this.domConfig == null) {
/*  944 */       this.domConfig = new DocumentConfiguration(this);
/*      */     }
/*  946 */     return this.domConfig;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public Node adoptNode(Node n) {
/*  953 */     if (!(n instanceof AbstractNode)) {
/*  954 */       return null;
/*      */     }
/*  956 */     switch (n.getNodeType()) {
/*      */       case 9:
/*  958 */         throw createDOMException((short)9, "adopt.document", new Object[0]);
/*      */ 
/*      */       
/*      */       case 10:
/*  962 */         throw createDOMException((short)9, "adopt.document.type", new Object[0]);
/*      */ 
/*      */       
/*      */       case 6:
/*      */       case 12:
/*  967 */         return null;
/*      */     } 
/*  969 */     AbstractNode an = (AbstractNode)n;
/*  970 */     if (an.isReadonly()) {
/*  971 */       throw createDOMException((short)7, "readonly.node", new Object[] { new Integer(an.getNodeType()), an.getNodeName() });
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  977 */     Node parent = n.getParentNode();
/*  978 */     if (parent != null) {
/*  979 */       parent.removeChild(n);
/*      */     }
/*  981 */     adoptNode1((AbstractNode)n);
/*  982 */     return n;
/*      */   }
/*      */   
/*      */   protected void adoptNode1(AbstractNode n) {
/*      */     int i, len;
/*      */     NamedNodeMap nnm;
/*      */     AbstractAttr attr;
/*  989 */     n.ownerDocument = this;
/*  990 */     switch (n.getNodeType()) {
/*      */       case 2:
/*  992 */         attr = (AbstractAttr)n;
/*  993 */         attr.ownerElement = null;
/*  994 */         attr.unspecified = false;
/*      */         break;
/*      */       case 1:
/*  997 */         nnm = n.getAttributes();
/*  998 */         len = nnm.getLength();
/*  999 */         for (i = 0; i < len; i++) {
/* 1000 */           attr = (AbstractAttr)nnm.item(i);
/* 1001 */           if (attr.getSpecified()) {
/* 1002 */             adoptNode1(attr);
/*      */           }
/*      */         } 
/*      */         break;
/*      */       case 5:
/* 1007 */         while (n.getFirstChild() != null) {
/* 1008 */           n.removeChild(n.getFirstChild());
/*      */         }
/*      */         break;
/*      */     } 
/*      */     
/* 1013 */     fireUserDataHandlers((short)5, n, null);
/*      */     
/* 1015 */     for (Node m = n.getFirstChild(); m != null; m = m.getNextSibling()) {
/* 1016 */       switch (m.getNodeType()) {
/*      */         case 6:
/*      */         case 10:
/*      */         case 12:
/*      */           return;
/*      */       } 
/* 1022 */       adoptNode1((AbstractNode)m);
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public Node renameNode(Node n, String ns, String qn) {
/* 1030 */     AbstractNode an = (AbstractNode)n;
/* 1031 */     if (an == getDocumentElement()) {
/* 1032 */       throw createDOMException((short)9, "rename.document.element", new Object[0]);
/*      */     }
/*      */ 
/*      */     
/* 1036 */     int nt = n.getNodeType();
/* 1037 */     if (nt != 1 && nt != 2) {
/* 1038 */       throw createDOMException((short)9, "rename.node", new Object[] { new Integer(nt), n.getNodeName() });
/*      */     }
/*      */ 
/*      */ 
/*      */     
/* 1043 */     if ((this.xmlVersion.equals("1.1") && !DOMUtilities.isValidName11(qn)) || !DOMUtilities.isValidName(qn))
/*      */     {
/*      */       
/* 1046 */       throw createDOMException((short)9, "wf.invalid.name", new Object[] { qn });
/*      */     }
/*      */ 
/*      */     
/* 1050 */     if (n.getOwnerDocument() != this) {
/* 1051 */       throw createDOMException((short)9, "node.from.wrong.document", new Object[] { new Integer(nt), n.getNodeName() });
/*      */     }
/*      */ 
/*      */ 
/*      */     
/* 1056 */     int i = qn.indexOf(':');
/* 1057 */     if (i == 0 || i == qn.length() - 1) {
/* 1058 */       throw createDOMException((short)14, "qname", new Object[] { new Integer(nt), n.getNodeName(), qn });
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 1064 */     String prefix = DOMUtilities.getPrefix(qn);
/* 1065 */     if (ns != null && ns.length() == 0) {
/* 1066 */       ns = null;
/*      */     }
/* 1068 */     if (prefix != null && ns == null) {
/* 1069 */       throw createDOMException((short)14, "prefix", new Object[] { new Integer(nt), n.getNodeName(), prefix });
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 1075 */     if (this.strictErrorChecking && ((
/* 1076 */       "xml".equals(prefix) && !"http://www.w3.org/XML/1998/namespace".equals(ns)) || ("xmlns".equals(prefix) && !"http://www.w3.org/2000/xmlns/".equals(ns))))
/*      */     {
/*      */ 
/*      */       
/* 1080 */       throw createDOMException((short)14, "namespace", new Object[] { new Integer(nt), n.getNodeName(), ns });
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 1088 */     String prevNamespaceURI = n.getNamespaceURI();
/* 1089 */     String prevNodeName = n.getNodeName();
/* 1090 */     if (nt == 1) {
/* 1091 */       Node parent = n.getParentNode();
/* 1092 */       AbstractElement e = (AbstractElement)createElementNS(ns, qn);
/*      */ 
/*      */       
/* 1095 */       EventSupport es1 = an.getEventSupport();
/* 1096 */       if (es1 != null) {
/* 1097 */         EventSupport es2 = e.getEventSupport();
/* 1098 */         if (es2 == null) {
/* 1099 */           AbstractDOMImplementation di = (AbstractDOMImplementation)this.implementation;
/*      */           
/* 1101 */           es2 = di.createEventSupport(e);
/* 1102 */           setEventsEnabled(true);
/* 1103 */           e.eventSupport = es2;
/*      */         } 
/* 1105 */         es1.moveEventListeners(e.getEventSupport());
/*      */       } 
/*      */ 
/*      */       
/* 1109 */       e.userData = (e.userData == null) ? null : (HashMap)an.userData.clone();
/*      */ 
/*      */       
/* 1112 */       e.userDataHandlers = (e.userDataHandlers == null) ? null : (HashMap)an.userDataHandlers.clone();
/*      */ 
/*      */ 
/*      */ 
/*      */       
/* 1117 */       Node next = null;
/* 1118 */       if (parent != null) {
/* 1119 */         n.getNextSibling();
/* 1120 */         parent.removeChild(n);
/*      */       } 
/*      */ 
/*      */       
/* 1124 */       while (n.getFirstChild() != null) {
/* 1125 */         e.appendChild(n.getFirstChild());
/*      */       }
/*      */ 
/*      */       
/* 1129 */       NamedNodeMap nnm = n.getAttributes();
/* 1130 */       for (int j = 0; j < nnm.getLength(); j++) {
/* 1131 */         Attr a = (Attr)nnm.item(j);
/* 1132 */         e.setAttributeNodeNS(a);
/*      */       } 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */       
/* 1140 */       if (parent != null) {
/* 1141 */         if (next == null) {
/* 1142 */           parent.appendChild(e);
/*      */         } else {
/* 1144 */           parent.insertBefore(next, e);
/*      */         } 
/*      */       }
/*      */       
/* 1148 */       fireUserDataHandlers((short)4, n, e);
/* 1149 */       if (getEventsEnabled()) {
/* 1150 */         MutationNameEvent ev = (MutationNameEvent)createEvent("MutationNameEvent");
/*      */         
/* 1152 */         ev.initMutationNameEventNS("http://www.w3.org/2001/xml-events", "DOMElementNameChanged", true, false, null, prevNamespaceURI, prevNodeName);
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */         
/* 1159 */         dispatchEvent(ev);
/*      */       } 
/* 1161 */       return e;
/*      */     } 
/* 1163 */     if (n instanceof AbstractAttrNS) {
/* 1164 */       AbstractAttrNS a = (AbstractAttrNS)n;
/* 1165 */       Element e = a.getOwnerElement();
/*      */ 
/*      */       
/* 1168 */       if (e != null) {
/* 1169 */         e.removeAttributeNode(a);
/*      */       }
/*      */ 
/*      */       
/* 1173 */       a.namespaceURI = ns;
/* 1174 */       a.nodeName = qn;
/*      */ 
/*      */       
/* 1177 */       if (e != null) {
/* 1178 */         e.setAttributeNodeNS(a);
/*      */       }
/*      */       
/* 1181 */       fireUserDataHandlers((short)4, a, null);
/* 1182 */       if (getEventsEnabled()) {
/* 1183 */         MutationNameEvent ev = (MutationNameEvent)createEvent("MutationNameEvent");
/*      */         
/* 1185 */         ev.initMutationNameEventNS("http://www.w3.org/2001/xml-events", "DOMAttrNameChanged", true, false, a, prevNamespaceURI, prevNodeName);
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */         
/* 1192 */         dispatchEvent(ev);
/*      */       } 
/* 1194 */       return a;
/*      */     } 
/* 1196 */     AbstractAttr a = (AbstractAttr)n;
/* 1197 */     Element e = a.getOwnerElement();
/*      */ 
/*      */     
/* 1200 */     if (e != null) {
/* 1201 */       e.removeAttributeNode(a);
/*      */     }
/* 1203 */     AbstractAttr a2 = (AbstractAttr)createAttributeNS(ns, qn);
/*      */ 
/*      */     
/* 1206 */     a2.setNodeValue(a.getNodeValue());
/*      */ 
/*      */     
/* 1209 */     a2.userData = (a.userData == null) ? null : (HashMap)a.userData.clone();
/*      */ 
/*      */     
/* 1212 */     a2.userDataHandlers = (a.userDataHandlers == null) ? null : (HashMap)a.userDataHandlers.clone();
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 1217 */     if (e != null) {
/* 1218 */       e.setAttributeNodeNS(a2);
/*      */     }
/*      */     
/* 1221 */     fireUserDataHandlers((short)4, a, a2);
/* 1222 */     if (getEventsEnabled()) {
/* 1223 */       MutationNameEvent ev = (MutationNameEvent)createEvent("MutationNameEvent");
/*      */       
/* 1225 */       ev.initMutationNameEventNS("http://www.w3.org/2001/xml-events", "DOMAttrNameChanged", true, false, a2, prevNamespaceURI, prevNodeName);
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */       
/* 1232 */       dispatchEvent(ev);
/*      */     } 
/* 1234 */     return a2;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void normalizeDocument() {
/* 1244 */     if (this.domConfig == null) {
/* 1245 */       this.domConfig = new DocumentConfiguration(this);
/*      */     }
/* 1247 */     boolean cdataSections = this.domConfig.getBooleanParameter("cdata-sections");
/*      */     
/* 1249 */     boolean comments = this.domConfig.getBooleanParameter("comments");
/*      */     
/* 1251 */     boolean elementContentWhitespace = this.domConfig.getBooleanParameter("element-content-whitespace");
/*      */     
/* 1253 */     boolean namespaceDeclarations = this.domConfig.getBooleanParameter("namespace-declarations");
/*      */     
/* 1255 */     boolean namespaces = this.domConfig.getBooleanParameter("namespaces");
/*      */     
/* 1257 */     boolean splitCdataSections = this.domConfig.getBooleanParameter("split-cdata-sections");
/*      */     
/* 1259 */     DOMErrorHandler errorHandler = (DOMErrorHandler)this.domConfig.getParameter("error-handler");
/*      */     
/* 1261 */     normalizeDocument(getDocumentElement(), cdataSections, comments, elementContentWhitespace, namespaceDeclarations, namespaces, splitCdataSections, errorHandler);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected boolean normalizeDocument(Element e, boolean cdataSections, boolean comments, boolean elementContentWhitepace, boolean namespaceDeclarations, boolean namespaces, boolean splitCdataSections, DOMErrorHandler errorHandler) {
/* 1282 */     AbstractElement ae = (AbstractElement)e;
/* 1283 */     Node n = e.getFirstChild();
/* 1284 */     while (n != null) {
/* 1285 */       int nt = n.getNodeType();
/* 1286 */       if (nt == 3 || (!cdataSections && nt == 4)) {
/*      */ 
/*      */         
/* 1289 */         Node t = n;
/* 1290 */         StringBuffer sb = new StringBuffer();
/* 1291 */         sb.append(t.getNodeValue());
/* 1292 */         n = n.getNextSibling();
/* 1293 */         while (n != null && (n.getNodeType() == 3 || (!cdataSections && n.getNodeType() == 4))) {
/*      */           
/* 1295 */           sb.append(n.getNodeValue());
/* 1296 */           Node next = n.getNextSibling();
/* 1297 */           e.removeChild(n);
/* 1298 */           n = next;
/*      */         } 
/* 1300 */         String s = sb.toString();
/* 1301 */         if (s.length() == 0) {
/* 1302 */           Node next = n.getNextSibling();
/* 1303 */           e.removeChild(n);
/* 1304 */           n = next;
/*      */           continue;
/*      */         } 
/* 1307 */         if (!s.equals(t.getNodeValue())) {
/* 1308 */           if (!cdataSections && nt == 3) {
/* 1309 */             n = createTextNode(s);
/* 1310 */             e.replaceChild(n, t);
/*      */           } else {
/* 1312 */             n = t;
/* 1313 */             t.setNodeValue(s);
/*      */           } 
/*      */         } else {
/* 1316 */           n = t;
/*      */         } 
/* 1318 */         if (!elementContentWhitepace) {
/*      */           
/* 1320 */           nt = n.getNodeType();
/* 1321 */           if (nt == 3) {
/* 1322 */             AbstractText tn = (AbstractText)n;
/* 1323 */             if (tn.isElementContentWhitespace()) {
/* 1324 */               Node next = n.getNextSibling();
/* 1325 */               e.removeChild(n);
/* 1326 */               n = next;
/*      */               continue;
/*      */             } 
/*      */           } 
/*      */         } 
/* 1331 */         if (nt == 4 && splitCdataSections && 
/* 1332 */           !splitCdata(e, n, errorHandler)) {
/* 1333 */           return false;
/*      */         }
/*      */       }
/* 1336 */       else if (nt == 4 && splitCdataSections) {
/*      */         
/* 1338 */         if (!splitCdata(e, n, errorHandler)) {
/* 1339 */           return false;
/*      */         }
/* 1341 */       } else if (nt == 8 && !comments) {
/*      */         
/* 1343 */         Node next = n.getPreviousSibling();
/* 1344 */         if (next == null) {
/* 1345 */           next = n.getNextSibling();
/*      */         }
/* 1347 */         e.removeChild(n);
/* 1348 */         n = next;
/*      */         
/*      */         continue;
/*      */       } 
/* 1352 */       n = n.getNextSibling();
/*      */     } 
/*      */     
/* 1355 */     NamedNodeMap nnm = e.getAttributes();
/* 1356 */     LinkedList toRemove = new LinkedList();
/* 1357 */     HashMap names = new HashMap();
/* 1358 */     for (int i = 0; i < nnm.getLength(); i++) {
/* 1359 */       Attr a = (Attr)nnm.item(i);
/* 1360 */       String prefix = a.getPrefix();
/* 1361 */       if ((a != null && "xmlns".equals(prefix)) || a.getNodeName().equals("xmlns"))
/*      */       {
/* 1363 */         if (!namespaceDeclarations) {
/*      */           
/* 1365 */           toRemove.add(a);
/*      */         } else {
/*      */           
/* 1368 */           String ns = a.getNodeValue();
/* 1369 */           if (!a.getNodeValue().equals("http://www.w3.org/2000/xmlns/") && ns.equals("http://www.w3.org/2000/xmlns/"))
/*      */           {
/*      */ 
/*      */             
/* 1373 */             names.put(prefix, ns);
/*      */           }
/*      */         } 
/*      */       }
/*      */     } 
/*      */     
/* 1379 */     if (!namespaceDeclarations) {
/*      */       
/* 1381 */       Iterator i = toRemove.iterator();
/* 1382 */       while (i.hasNext()) {
/* 1383 */         e.removeAttributeNode((Attr)i.next());
/*      */       }
/*      */     }
/* 1386 */     else if (namespaces) {
/*      */       
/* 1388 */       String ens = e.getNamespaceURI();
/* 1389 */       if (ens != null) {
/* 1390 */         String eprefix = e.getPrefix();
/* 1391 */         if (!compareStrings(ae.lookupNamespaceURI(eprefix), ens)) {
/* 1392 */           e.setAttributeNS("http://www.w3.org/2000/xmlns/", (eprefix == null) ? "xmlns" : ("xmlns:" + eprefix), ens);
/*      */ 
/*      */         
/*      */         }
/*      */       
/*      */       }
/* 1398 */       else if (e.getLocalName() != null) {
/*      */ 
/*      */         
/* 1401 */         if (ae.lookupNamespaceURI(null) == null) {
/* 1402 */           e.setAttributeNS("http://www.w3.org/2000/xmlns/", "xmlns", "");
/*      */         }
/*      */       } 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */       
/* 1410 */       nnm = e.getAttributes();
/* 1411 */       for (int i = 0; i < nnm.getLength(); i++) {
/* 1412 */         Attr a = (Attr)nnm.item(i);
/* 1413 */         String ans = a.getNamespaceURI();
/* 1414 */         if (ans != null) {
/* 1415 */           String apre = a.getPrefix();
/* 1416 */           if ((apre == null || (!apre.equals("xml") && !apre.equals("xmlns"))) && !ans.equals("http://www.w3.org/2000/xmlns/"))
/*      */           {
/*      */ 
/*      */ 
/*      */ 
/*      */             
/* 1422 */             String aprens = (apre == null) ? null : ae.lookupNamespaceURI(apre);
/* 1423 */             if (apre == null || aprens == null || !aprens.equals(ans))
/*      */             {
/*      */               
/* 1426 */               String newpre = ae.lookupPrefix(ans);
/* 1427 */               if (newpre != null) {
/* 1428 */                 a.setPrefix(newpre);
/*      */               }
/* 1430 */               else if (apre != null && ae.lookupNamespaceURI(apre) == null) {
/*      */                 
/* 1432 */                 e.setAttributeNS("http://www.w3.org/2000/xmlns/", "xmlns:" + apre, ans);
/*      */               
/*      */               }
/*      */               else {
/*      */                 
/* 1437 */                 int index = 1;
/*      */                 do {
/* 1439 */                   newpre = "NS" + index;
/* 1440 */                 } while (ae.lookupPrefix(newpre) != null);
/* 1441 */                 e.setAttributeNS("http://www.w3.org/2000/xmlns/", "xmlns:" + newpre, ans);
/*      */ 
/*      */ 
/*      */                 
/* 1445 */                 a.setPrefix(newpre);
/*      */               }
/*      */             
/*      */             }
/*      */           
/*      */           }
/*      */         
/*      */         }
/* 1453 */         else if (a.getLocalName() == null) {
/*      */         
/*      */         } 
/*      */       } 
/*      */     } 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 1462 */     nnm = e.getAttributes();
/* 1463 */     for (int i = 0; i < nnm.getLength(); i++) {
/* 1464 */       Attr a = (Attr)nnm.item(i);
/* 1465 */       if (!checkName(a.getNodeName()) && 
/* 1466 */         errorHandler != null && 
/* 1467 */         !errorHandler.handleError(createDOMError("wf-invalid-character-in-node-name", (short)2, "wf.invalid.name", new Object[] { a.getNodeName() }, a, null)))
/*      */       {
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */         
/* 1474 */         return false;
/*      */       }
/*      */ 
/*      */       
/* 1478 */       if (!checkChars(a.getNodeValue()) && 
/* 1479 */         errorHandler != null && 
/* 1480 */         !errorHandler.handleError(createDOMError("wf-invalid-character", (short)2, "wf.invalid.character", new Object[] { new Integer(2), a.getNodeName(), a.getNodeValue() }, a, null)))
/*      */       {
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */         
/* 1489 */         return false;
/*      */       }
/*      */     } 
/*      */ 
/*      */     
/* 1494 */     for (Node m = e.getFirstChild(); m != null; m = m.getNextSibling()) {
/* 1495 */       String s; int nt = m.getNodeType();
/*      */       
/* 1497 */       switch (nt) {
/*      */         case 3:
/* 1499 */           s = m.getNodeValue();
/* 1500 */           if (!checkChars(s) && 
/* 1501 */             errorHandler != null && 
/* 1502 */             !errorHandler.handleError(createDOMError("wf-invalid-character", (short)2, "wf.invalid.character", new Object[] { new Integer(m.getNodeType()), m.getNodeName(), s }, m, null)))
/*      */           {
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */             
/* 1511 */             return false;
/*      */           }
/*      */           break;
/*      */ 
/*      */         
/*      */         case 8:
/* 1517 */           s = m.getNodeValue();
/* 1518 */           if (!checkChars(s) || s.indexOf("--") != -1 || s.charAt(s.length() - 1) == '-')
/*      */           {
/*      */             
/* 1521 */             if (errorHandler != null && 
/* 1522 */               !errorHandler.handleError(createDOMError("wf-invalid-character", (short)2, "wf.invalid.character", new Object[] { new Integer(m.getNodeType()), m.getNodeName(), s }, m, null)))
/*      */             {
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */               
/* 1531 */               return false;
/*      */             }
/*      */           }
/*      */           break;
/*      */         
/*      */         case 4:
/* 1537 */           s = m.getNodeValue();
/* 1538 */           if (!checkChars(s) || s.indexOf("]]>") != -1)
/*      */           {
/* 1540 */             if (errorHandler != null && 
/* 1541 */               !errorHandler.handleError(createDOMError("wf-invalid-character", (short)2, "wf.invalid.character", new Object[] { new Integer(m.getNodeType()), m.getNodeName(), s }, m, null)))
/*      */             {
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */               
/* 1550 */               return false;
/*      */             }
/*      */           }
/*      */           break;
/*      */         
/*      */         case 7:
/* 1556 */           if (m.getNodeName().equalsIgnoreCase("xml"))
/*      */           {
/* 1558 */             if (errorHandler != null && 
/* 1559 */               !errorHandler.handleError(createDOMError("wf-invalid-character-in-node-name", (short)2, "wf.invalid.name", new Object[] { m.getNodeName() }, m, null)))
/*      */             {
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */               
/* 1566 */               return false;
/*      */             }
/*      */           }
/*      */           
/* 1570 */           s = m.getNodeValue();
/* 1571 */           if (!checkChars(s) || s.indexOf("?>") != -1)
/*      */           {
/*      */             
/* 1574 */             if (errorHandler != null && 
/* 1575 */               !errorHandler.handleError(createDOMError("wf-invalid-character", (short)2, "wf.invalid.character", new Object[] { new Integer(m.getNodeType()), m.getNodeName(), s }, m, null)))
/*      */             {
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */               
/* 1584 */               return false;
/*      */             }
/*      */           }
/*      */           break;
/*      */         
/*      */         case 1:
/* 1590 */           if (!checkName(m.getNodeName()) && 
/* 1591 */             errorHandler != null && 
/* 1592 */             !errorHandler.handleError(createDOMError("wf-invalid-character-in-node-name", (short)2, "wf.invalid.name", new Object[] { m.getNodeName() }, m, null)))
/*      */           {
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */             
/* 1599 */             return false;
/*      */           }
/*      */ 
/*      */           
/* 1603 */           if (!normalizeDocument((Element)m, cdataSections, comments, elementContentWhitepace, namespaceDeclarations, namespaces, splitCdataSections, errorHandler))
/*      */           {
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */             
/* 1611 */             return false;
/*      */           }
/*      */           break;
/*      */       } 
/*      */     } 
/* 1616 */     return true;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected boolean splitCdata(Element e, Node n, DOMErrorHandler errorHandler) {
/* 1625 */     String s2 = n.getNodeValue();
/* 1626 */     int index = s2.indexOf("]]>");
/* 1627 */     if (index != -1) {
/* 1628 */       String before = s2.substring(0, index + 2);
/* 1629 */       String after = s2.substring(index + 2);
/* 1630 */       n.setNodeValue(before);
/* 1631 */       Node next = n.getNextSibling();
/* 1632 */       if (next == null) {
/* 1633 */         e.appendChild(createCDATASection(after));
/*      */       } else {
/* 1635 */         e.insertBefore(createCDATASection(after), next);
/*      */       } 
/*      */       
/* 1638 */       if (errorHandler != null && 
/* 1639 */         !errorHandler.handleError(createDOMError("cdata-sections-splitted", (short)1, "cdata.section.split", new Object[0], n, null)))
/*      */       {
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */         
/* 1646 */         return false;
/*      */       }
/*      */     } 
/*      */     
/* 1650 */     return true;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected boolean checkChars(String s) {
/* 1658 */     int len = s.length();
/* 1659 */     if (this.xmlVersion.equals("1.1")) {
/* 1660 */       for (int i = 0; i < len; i++) {
/* 1661 */         if (!XMLUtilities.isXML11Character(s.charAt(i))) {
/* 1662 */           return false;
/*      */         }
/*      */       } 
/*      */     } else {
/*      */       
/* 1667 */       for (int i = 0; i < len; i++) {
/* 1668 */         if (!XMLUtilities.isXMLCharacter(s.charAt(i))) {
/* 1669 */           return false;
/*      */         }
/*      */       } 
/*      */     } 
/* 1673 */     return true;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected boolean checkName(String s) {
/* 1680 */     if (this.xmlVersion.equals("1.1")) {
/* 1681 */       return DOMUtilities.isValidName11(s);
/*      */     }
/*      */     
/* 1684 */     return DOMUtilities.isValidName(s);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected DOMError createDOMError(String type, short severity, String key, Object[] args, Node related, Exception e) {
/*      */     try {
/* 1697 */       return new DocumentError(this, type, severity, getCurrentDocument().formatMessage(key, args), related, e);
/*      */     
/*      */     }
/*      */     catch (Exception ex) {
/*      */ 
/*      */       
/* 1703 */       return new DocumentError(this, type, severity, key, related, e);
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void setTextContent(String s) {}
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void setXBLManager(XBLManager m) {
/*      */     GenericXBLManager genericXBLManager;
/* 1721 */     boolean wasProcessing = this.xblManager.isProcessing();
/* 1722 */     this.xblManager.stopProcessing();
/* 1723 */     if (m == null) {
/* 1724 */       genericXBLManager = new GenericXBLManager();
/*      */     }
/* 1726 */     this.xblManager = genericXBLManager;
/* 1727 */     if (wasProcessing) {
/* 1728 */       this.xblManager.startProcessing();
/*      */     }
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/* 1736 */   public XBLManager getXBLManager() { return this.xblManager; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected class DocumentError
/*      */     implements DOMError
/*      */   {
/*      */     protected String type;
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     protected short severity;
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     protected String message;
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     protected Node relatedNode;
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     protected Object relatedException;
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     protected DOMLocator domLocator;
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     private final AbstractDocument this$0;
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     public DocumentError(AbstractDocument this$0, String type, short severity, String message, Node relatedNode, Exception relatedException) {
/* 1781 */       this.this$0 = this$0;
/* 1782 */       this.type = type;
/* 1783 */       this.severity = severity;
/* 1784 */       this.message = message;
/* 1785 */       this.relatedNode = relatedNode;
/* 1786 */       this.relatedException = relatedException;
/*      */     }
/*      */ 
/*      */     
/* 1790 */     public String getType() { return this.type; }
/*      */ 
/*      */ 
/*      */     
/* 1794 */     public short getSeverity() { return this.severity; }
/*      */ 
/*      */ 
/*      */     
/* 1798 */     public String getMessage() { return this.message; }
/*      */ 
/*      */ 
/*      */     
/* 1802 */     public Object getRelatedData() { return this.relatedNode; }
/*      */ 
/*      */ 
/*      */     
/* 1806 */     public Object getRelatedException() { return this.relatedException; }
/*      */ 
/*      */     
/*      */     public DOMLocator getLocation() {
/* 1810 */       if (this.domLocator == null) {
/* 1811 */         this.domLocator = new ErrorLocation(this, this.relatedNode);
/*      */       }
/* 1813 */       return this.domLocator;
/*      */     }
/*      */ 
/*      */ 
/*      */     
/*      */     protected class ErrorLocation
/*      */       implements DOMLocator
/*      */     {
/*      */       protected Node node;
/*      */ 
/*      */       
/*      */       private final AbstractDocument.DocumentError this$1;
/*      */ 
/*      */ 
/*      */       
/*      */       public ErrorLocation(AbstractDocument.DocumentError this$1, Node n) {
/* 1829 */         this.this$1 = this$1;
/* 1830 */         this.node = n;
/*      */       }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */       
/* 1837 */       public int getLineNumber() { return -1; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */       
/* 1844 */       public int getColumnNumber() { return -1; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */       
/* 1851 */       public int getByteOffset() { return -1; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */       
/* 1858 */       public int getUtf16Offset() { return -1; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */       
/* 1865 */       public Node getRelatedNode() { return this.node; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */       
/*      */       public String getUri() {
/* 1872 */         AbstractDocument doc = (AbstractDocument)this.node.getOwnerDocument();
/*      */         
/* 1874 */         return doc.getDocumentURI();
/*      */       } }
/*      */   }
/*      */   
/*      */   protected class DocumentConfiguration implements DOMConfiguration {
/*      */     protected String[] booleanParamNames;
/*      */     
/*      */     protected DocumentConfiguration(AbstractDocument this$0) {
/* 1882 */       this.this$0 = this$0;
/*      */ 
/*      */ 
/*      */ 
/*      */       
/* 1887 */       this.booleanParamNames = new String[] { "canonical-form", "cdata-sections", "check-character-normalization", "comments", "datatype-normalization", "element-content-whitespace", "entities", "infoset", "namespaces", "namespace-declarations", "normalize-characters", "split-cdata-sections", "validate", "validate-if-schema", "well-formed" };
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */       
/* 1908 */       this.booleanParamValues = new boolean[] { 
/*      */           false, true, false, true, false, false, true, false, true, true, 
/*      */           false, true, false, false, true };
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */       
/* 1929 */       this.booleanParamReadOnly = new boolean[] { 
/*      */           true, false, true, false, true, false, false, false, false, false, 
/*      */           true, false, true, true, false };
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */       
/* 1950 */       this.booleanParamIndexes = new HashMap();
/*      */       
/* 1952 */       for (int i = 0; i < this.booleanParamNames.length; i++) {
/* 1953 */         this.booleanParamIndexes.put(this.booleanParamNames[i], new Integer(i));
/*      */       }
/*      */     }
/*      */ 
/*      */     
/*      */     protected boolean[] booleanParamValues;
/*      */     
/*      */     protected boolean[] booleanParamReadOnly;
/*      */     
/*      */     protected Map booleanParamIndexes;
/*      */     
/*      */     protected Object errorHandler;
/*      */     
/*      */     protected ParameterNameList paramNameList;
/*      */     
/*      */     private final AbstractDocument this$0;
/*      */     
/*      */     public void setParameter(String name, Object value) {
/* 1971 */       if ("error-handler".equals(name)) {
/* 1972 */         if (value != null && !(value instanceof DOMErrorHandler)) {
/* 1973 */           throw this.this$0.createDOMException((short)17, "domconfig.param.type", new Object[] { name });
/*      */         }
/*      */ 
/*      */ 
/*      */         
/* 1978 */         this.errorHandler = value;
/*      */         return;
/*      */       } 
/* 1981 */       Integer i = (Integer)this.booleanParamIndexes.get(name);
/* 1982 */       if (i == null) {
/* 1983 */         throw this.this$0.createDOMException((short)8, "domconfig.param.not.found", new Object[] { name });
/*      */       }
/*      */ 
/*      */ 
/*      */       
/* 1988 */       if (value == null) {
/* 1989 */         throw this.this$0.createDOMException((short)9, "domconfig.param.value", new Object[] { name });
/*      */       }
/*      */ 
/*      */ 
/*      */       
/* 1994 */       if (!(value instanceof Boolean)) {
/* 1995 */         throw this.this$0.createDOMException((short)17, "domconfig.param.type", new Object[] { name });
/*      */       }
/*      */ 
/*      */ 
/*      */       
/* 2000 */       int index = i.intValue();
/* 2001 */       boolean val = ((Boolean)value).booleanValue();
/* 2002 */       if (this.booleanParamReadOnly[index] && this.booleanParamValues[index] != val)
/*      */       {
/* 2004 */         throw this.this$0.createDOMException((short)9, "domconfig.param.value", new Object[] { name });
/*      */       }
/*      */ 
/*      */ 
/*      */       
/* 2009 */       this.booleanParamValues[index] = val;
/* 2010 */       if (name.equals("infoset")) {
/* 2011 */         setParameter("validate-if-schema", Boolean.FALSE);
/* 2012 */         setParameter("entities", Boolean.FALSE);
/* 2013 */         setParameter("datatype-normalization", Boolean.FALSE);
/* 2014 */         setParameter("cdata-sections", Boolean.FALSE);
/* 2015 */         setParameter("well-formed", Boolean.TRUE);
/* 2016 */         setParameter("element-content-whitespace", Boolean.TRUE);
/* 2017 */         setParameter("comments", Boolean.TRUE);
/* 2018 */         setParameter("namespaces", Boolean.TRUE);
/*      */       } 
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     public Object getParameter(String name) {
/* 2026 */       if ("error-handler".equals(name)) {
/* 2027 */         return this.errorHandler;
/*      */       }
/* 2029 */       Integer index = (Integer)this.booleanParamIndexes.get(name);
/* 2030 */       if (index == null) {
/* 2031 */         throw this.this$0.createDOMException((short)8, "domconfig.param.not.found", new Object[] { name });
/*      */       }
/*      */ 
/*      */ 
/*      */       
/* 2036 */       return this.booleanParamValues[index.intValue()] ? Boolean.TRUE : Boolean.FALSE;
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     public boolean getBooleanParameter(String name) {
/* 2044 */       Boolean b = (Boolean)getParameter(name);
/* 2045 */       return b.booleanValue();
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     public boolean canSetParameter(String name, Object value) {
/* 2052 */       if (name.equals("error-handler")) {
/* 2053 */         return (value == null || value instanceof DOMErrorHandler);
/*      */       }
/* 2055 */       Integer i = (Integer)this.booleanParamIndexes.get(name);
/* 2056 */       if (i == null || value == null || !(value instanceof Boolean)) {
/* 2057 */         return false;
/*      */       }
/* 2059 */       int index = i.intValue();
/* 2060 */       boolean val = ((Boolean)value).booleanValue();
/* 2061 */       return (!this.booleanParamReadOnly[index] || this.booleanParamValues[index] == val);
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     public DOMStringList getParameterNames() {
/* 2069 */       if (this.paramNameList == null) {
/* 2070 */         this.paramNameList = new ParameterNameList(this);
/*      */       }
/* 2072 */       return this.paramNameList;
/*      */     }
/*      */     
/*      */     protected class ParameterNameList implements DOMStringList {
/*      */       private final AbstractDocument.DocumentConfiguration this$1;
/*      */       
/* 2078 */       protected ParameterNameList(AbstractDocument.DocumentConfiguration this$1) { this.this$1 = this$1; }
/*      */ 
/*      */ 
/*      */ 
/*      */       
/*      */       public String item(int index) {
/* 2084 */         if (index < 0) {
/* 2085 */           return null;
/*      */         }
/* 2087 */         if (index < this.this$1.booleanParamNames.length) {
/* 2088 */           return this.this$1.booleanParamNames[index];
/*      */         }
/* 2090 */         if (index == this.this$1.booleanParamNames.length) {
/* 2091 */           return "error-handler";
/*      */         }
/* 2093 */         return null;
/*      */       }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */       
/* 2100 */       public int getLength() { return this.this$1.booleanParamNames.length + 1; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */       
/*      */       public boolean contains(String s) {
/* 2107 */         if ("error-handler".equals(s)) {
/* 2108 */           return true;
/*      */         }
/* 2110 */         for (int i = 0; i < this.this$1.booleanParamNames.length; i++) {
/* 2111 */           if (this.this$1.booleanParamNames[i].equals(s)) {
/* 2112 */             return true;
/*      */           }
/*      */         } 
/* 2115 */         return false;
/*      */       }
/*      */     }
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/* 2127 */   public XPathExpression createExpression(String expression, XPathNSResolver resolver) throws DOMException, XPathException { return new XPathExpr(this, expression, resolver); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/* 2135 */   public XPathNSResolver createNSResolver(Node n) { return new XPathNodeNSResolver(this, n); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public Object evaluate(String expression, Node contextNode, XPathNSResolver resolver, short type, Object result) throws XPathException, DOMException {
/* 2148 */     XPathExpression xpath = createExpression(expression, resolver);
/* 2149 */     return xpath.evaluate(contextNode, type, result);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public XPathException createXPathException(short type, String key, Object[] args) {
/*      */     try {
/* 2159 */       return new XPathException(type, formatMessage(key, args));
/*      */     } catch (Exception e) {
/* 2161 */       return new XPathException(type, key);
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected class XPathExpr
/*      */     implements XPathExpression
/*      */   {
/*      */     protected XPath xpath;
/*      */ 
/*      */ 
/*      */     
/*      */     protected XPathNSResolver resolver;
/*      */ 
/*      */ 
/*      */     
/*      */     protected NSPrefixResolver prefixResolver;
/*      */ 
/*      */ 
/*      */     
/*      */     protected XPathContext context;
/*      */ 
/*      */ 
/*      */     
/*      */     private final AbstractDocument this$0;
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     public XPathExpr(AbstractDocument this$0, String expr, XPathNSResolver res) throws DOMException, XPathException {
/* 2194 */       this.this$0 = this$0;
/* 2195 */       this.resolver = res;
/* 2196 */       this.prefixResolver = new NSPrefixResolver(this);
/*      */       try {
/* 2198 */         this.xpath = new XPath(expr, null, this.prefixResolver, 0);
/* 2199 */         this.context = new XPathContext();
/*      */       } catch (TransformerException te) {
/* 2201 */         throw this$0.createXPathException((short)51, "xpath.invalid.expression", new Object[] { expr, te.getMessage() });
/*      */       } 
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     public Object evaluate(Node contextNode, short type, Object res) throws XPathException, DOMException {
/* 2214 */       if ((contextNode.getNodeType() != 9 && contextNode.getOwnerDocument() != this.this$0) || (contextNode.getNodeType() == 9 && contextNode != this.this$0))
/*      */       {
/*      */ 
/*      */         
/* 2218 */         throw this.this$0.createDOMException((short)4, "node.from.wrong.document", new Object[] { new Integer(contextNode.getNodeType()), contextNode.getNodeName() });
/*      */       }
/*      */ 
/*      */ 
/*      */ 
/*      */       
/* 2224 */       if (type < 0 || type > 9) {
/* 2225 */         throw this.this$0.createDOMException((short)9, "xpath.invalid.result.type", new Object[] { new Integer(type) });
/*      */       }
/*      */ 
/*      */       
/* 2229 */       switch (contextNode.getNodeType()) {
/*      */         case 5:
/*      */         case 6:
/*      */         case 10:
/*      */         case 11:
/*      */         case 12:
/* 2235 */           throw this.this$0.createDOMException((short)9, "xpath.invalid.context.node", new Object[] { new Integer(contextNode.getNodeType()), contextNode.getNodeName() });
/*      */       } 
/*      */ 
/*      */ 
/*      */ 
/*      */       
/* 2241 */       this.context.reset();
/* 2242 */       XObject result = null;
/*      */       try {
/* 2244 */         result = this.xpath.execute(this.context, contextNode, this.prefixResolver);
/*      */       } catch (TransformerException te) {
/* 2246 */         throw this.this$0.createXPathException((short)51, "xpath.error", new Object[] { this.xpath.getPatternString(), te.getMessage() });
/*      */       } 
/*      */ 
/*      */ 
/*      */ 
/*      */       
/*      */       try {
/* 2253 */         switch (type) {
/*      */           case 8:
/*      */           case 9:
/* 2256 */             return convertSingleNode(result, type);
/*      */           case 3:
/* 2258 */             return convertBoolean(result);
/*      */           case 1:
/* 2260 */             return convertNumber(result);
/*      */           case 4:
/*      */           case 5:
/*      */           case 6:
/*      */           case 7:
/* 2265 */             return convertNodeIterator(result, type);
/*      */           case 2:
/* 2267 */             return convertString(result);
/*      */           case 0:
/* 2269 */             switch (result.getType()) {
/*      */               case 1:
/* 2271 */                 return convertBoolean(result);
/*      */               case 2:
/* 2273 */                 return convertNumber(result);
/*      */               case 3:
/* 2275 */                 return convertString(result);
/*      */               case 4:
/* 2277 */                 return convertNodeIterator(result, (short)4);
/*      */             } 
/*      */             
/*      */             break;
/*      */         } 
/*      */       } catch (TransformerException te) {
/* 2283 */         throw this.this$0.createXPathException((short)52, "xpath.cannot.convert.result", new Object[] { new Integer(type), te.getMessage() });
/*      */       } 
/*      */ 
/*      */ 
/*      */ 
/*      */       
/* 2289 */       return null;
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 2297 */     protected Result convertSingleNode(XObject xo, short type) throws TransformerException { return new Result(this, xo.nodelist().item(0), type); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 2305 */     protected Result convertBoolean(XObject xo) throws TransformerException { return new Result(this, xo.bool()); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 2313 */     protected Result convertNumber(XObject xo) throws TransformerException { return new Result(this, xo.num()); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 2320 */     protected Result convertString(XObject xo) throws TransformerException { return new Result(this, xo.str()); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 2328 */     protected Result convertNodeIterator(XObject xo, short type) throws TransformerException { return new Result(this, xo.nodelist(), type); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     public class Result
/*      */       implements XPathResult
/*      */     {
/*      */       protected short resultType;
/*      */ 
/*      */ 
/*      */ 
/*      */       
/*      */       protected double numberValue;
/*      */ 
/*      */ 
/*      */ 
/*      */       
/*      */       protected String stringValue;
/*      */ 
/*      */ 
/*      */ 
/*      */       
/*      */       protected boolean booleanValue;
/*      */ 
/*      */ 
/*      */ 
/*      */       
/*      */       protected Node singleNodeValue;
/*      */ 
/*      */ 
/*      */ 
/*      */       
/*      */       protected NodeList iterator;
/*      */ 
/*      */ 
/*      */ 
/*      */       
/*      */       protected int iteratorPosition;
/*      */ 
/*      */ 
/*      */ 
/*      */       
/*      */       private final AbstractDocument.XPathExpr this$1;
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */       
/*      */       public Result(AbstractDocument.XPathExpr this$1, Node n, short type) {
/* 2379 */         this.this$1 = this$1;
/* 2380 */         this.resultType = type;
/* 2381 */         this.singleNodeValue = n;
/*      */       }
/*      */ 
/*      */ 
/*      */ 
/*      */       
/*      */       public Result(AbstractDocument.XPathExpr this$1, boolean b) throws TransformerException {
/* 2388 */         this.this$1 = this$1;
/* 2389 */         this.resultType = 3;
/* 2390 */         this.booleanValue = b;
/*      */       }
/*      */ 
/*      */ 
/*      */ 
/*      */       
/*      */       public Result(AbstractDocument.XPathExpr this$1, double d) throws TransformerException {
/* 2397 */         this.this$1 = this$1;
/* 2398 */         this.resultType = 1;
/* 2399 */         this.numberValue = d;
/*      */       }
/*      */ 
/*      */ 
/*      */       
/*      */       public Result(AbstractDocument.XPathExpr this$1, String s) {
/* 2405 */         this.this$1 = this$1;
/* 2406 */         this.resultType = 2;
/* 2407 */         this.stringValue = s;
/*      */       }
/*      */ 
/*      */ 
/*      */       
/*      */       public Result(AbstractDocument.XPathExpr this$1, NodeList nl, short type) {
/* 2413 */         this.this$1 = this$1;
/* 2414 */         this.resultType = type;
/* 2415 */         this.iterator = nl;
/*      */       }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */       
/* 2422 */       public short getResultType() { return this.resultType; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */       
/*      */       public boolean getBooleanValue() {
/* 2429 */         if (this.resultType != 3) {
/* 2430 */           throw this.this$1.this$0.createXPathException((short)52, "xpath.invalid.result.type", new Object[] { new Integer(this.resultType) });
/*      */         }
/*      */ 
/*      */ 
/*      */         
/* 2435 */         return this.booleanValue;
/*      */       }
/*      */ 
/*      */ 
/*      */ 
/*      */       
/*      */       public double getNumberValue() {
/* 2442 */         if (this.resultType != 1) {
/* 2443 */           throw this.this$1.this$0.createXPathException((short)52, "xpath.invalid.result.type", new Object[] { new Integer(this.resultType) });
/*      */         }
/*      */ 
/*      */ 
/*      */         
/* 2448 */         return this.numberValue;
/*      */       }
/*      */ 
/*      */ 
/*      */ 
/*      */       
/*      */       public String getStringValue() {
/* 2455 */         if (this.resultType != 2) {
/* 2456 */           throw this.this$1.this$0.createXPathException((short)52, "xpath.invalid.result.type", new Object[] { new Integer(this.resultType) });
/*      */         }
/*      */ 
/*      */ 
/*      */         
/* 2461 */         return this.stringValue;
/*      */       }
/*      */ 
/*      */ 
/*      */ 
/*      */       
/*      */       public Node getSingleNodeValue() {
/* 2468 */         if (this.resultType != 8 && this.resultType != 9)
/*      */         {
/* 2470 */           throw this.this$1.this$0.createXPathException((short)52, "xpath.invalid.result.type", new Object[] { new Integer(this.resultType) });
/*      */         }
/*      */ 
/*      */ 
/*      */         
/* 2475 */         return this.singleNodeValue;
/*      */       }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */       
/* 2483 */       public boolean getInvalidIteratorState() { return false; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */       
/*      */       public int getSnapshotLength() {
/* 2490 */         if (this.resultType != 6 && this.resultType != 7)
/*      */         {
/* 2492 */           throw this.this$1.this$0.createXPathException((short)52, "xpath.invalid.result.type", new Object[] { new Integer(this.resultType) });
/*      */         }
/*      */ 
/*      */ 
/*      */         
/* 2497 */         return this.iterator.getLength();
/*      */       }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */       
/*      */       public Node iterateNext() {
/* 2505 */         if (this.resultType != 4 && this.resultType != 5)
/*      */         {
/* 2507 */           throw this.this$1.this$0.createXPathException((short)52, "xpath.invalid.result.type", new Object[] { new Integer(this.resultType) });
/*      */         }
/*      */ 
/*      */ 
/*      */         
/* 2512 */         return this.iterator.item(this.iteratorPosition++);
/*      */       }
/*      */ 
/*      */ 
/*      */ 
/*      */       
/*      */       public Node snapshotItem(int i) {
/* 2519 */         if (this.resultType != 6 && this.resultType != 7)
/*      */         {
/* 2521 */           throw this.this$1.this$0.createXPathException((short)52, "xpath.invalid.result.type", new Object[] { new Integer(this.resultType) });
/*      */         }
/*      */ 
/*      */ 
/*      */         
/* 2526 */         return this.iterator.item(i);
/*      */       }
/*      */     }
/*      */     
/*      */     protected class NSPrefixResolver implements PrefixResolver {
/*      */       private final AbstractDocument.XPathExpr this$1;
/*      */       
/* 2533 */       protected NSPrefixResolver(AbstractDocument.XPathExpr this$1) { this.this$1 = this$1; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */       
/* 2540 */       public String getBaseIdentifier() { return null; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */       
/*      */       public String getNamespaceForPrefix(String prefix) {
/* 2547 */         if (this.this$1.resolver == null) {
/* 2548 */           return null;
/*      */         }
/* 2550 */         return this.this$1.resolver.lookupNamespaceURI(prefix);
/*      */       }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */       
/*      */       public String getNamespaceForPrefix(String prefix, Node context) {
/* 2558 */         if (this.this$1.resolver == null) {
/* 2559 */           return null;
/*      */         }
/* 2561 */         return this.this$1.resolver.lookupNamespaceURI(prefix);
/*      */       }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */       
/* 2568 */       public boolean handlesNullPrefixes() { return false; }
/*      */     }
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected class XPathNodeNSResolver
/*      */     implements XPathNSResolver
/*      */   {
/*      */     protected Node contextNode;
/*      */ 
/*      */     
/*      */     private final AbstractDocument this$0;
/*      */ 
/*      */ 
/*      */     
/*      */     public XPathNodeNSResolver(AbstractDocument this$0, Node n) {
/* 2586 */       this.this$0 = this$0;
/* 2587 */       this.contextNode = n;
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 2595 */     public String lookupNamespaceURI(String prefix) { return ((AbstractNode)this.contextNode).lookupNamespaceURI(prefix); }
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/* 2605 */   public Node getXblParentNode() { return this.xblManager.getXblParentNode(this); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/* 2612 */   public NodeList getXblChildNodes() { return this.xblManager.getXblChildNodes(this); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/* 2620 */   public NodeList getXblScopedChildNodes() { return this.xblManager.getXblScopedChildNodes(this); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/* 2627 */   public Node getXblFirstChild() { return this.xblManager.getXblFirstChild(this); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/* 2634 */   public Node getXblLastChild() { return this.xblManager.getXblLastChild(this); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/* 2642 */   public Node getXblPreviousSibling() { return this.xblManager.getXblPreviousSibling(this); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/* 2650 */   public Node getXblNextSibling() { return this.xblManager.getXblNextSibling(this); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/* 2657 */   public Element getXblFirstElementChild() { return this.xblManager.getXblFirstElementChild(this); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/* 2664 */   public Element getXblLastElementChild() { return this.xblManager.getXblLastElementChild(this); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/* 2672 */   public Element getXblPreviousElementSibling() { return this.xblManager.getXblPreviousElementSibling(this); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/* 2680 */   public Element getXblNextElementSibling() { return this.xblManager.getXblNextElementSibling(this); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/* 2687 */   public Element getXblBoundElement() { return this.xblManager.getXblBoundElement(this); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/* 2694 */   public Element getXblShadowTree() { return this.xblManager.getXblShadowTree(this); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/* 2701 */   public NodeList getXblDefinitions() { return this.xblManager.getXblDefinitions(this); }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private void writeObject(ObjectOutputStream s) throws IOException {
/* 2707 */     s.defaultWriteObject();
/*      */     
/* 2709 */     s.writeObject(this.implementation.getClass().getName());
/*      */   }
/*      */ 
/*      */   
/*      */   private void readObject(ObjectInputStream s) throws IOException, ClassNotFoundException {
/* 2714 */     s.defaultReadObject();
/*      */     
/* 2716 */     this.localizableSupport = new LocalizableSupport("org.apache.batik.dom.resources.Messages", getClass().getClassLoader());
/*      */ 
/*      */     
/* 2719 */     Class c = Class.forName((String)s.readObject());
/*      */ 
/*      */     
/* 2722 */     try { Method m = c.getMethod("getDOMImplementation", (Class[])null);
/* 2723 */       this.implementation = (DOMImplementation)m.invoke(null, (Object[])null); }
/*      */     
/* 2725 */     catch (Exception e) { try {
/* 2726 */         this.implementation = (DOMImplementation)c.newInstance();
/* 2727 */       } catch (Exception ex) {} }
/*      */   
/*      */   }
/*      */   
/*      */   public abstract Attr createAttributeNS(String paramString1, String paramString2) throws DOMException;
/*      */   
/*      */   public abstract Element createElementNS(String paramString1, String paramString2) throws DOMException;
/*      */   
/*      */   public abstract EntityReference createEntityReference(String paramString) throws DOMException;
/*      */   
/*      */   public abstract Attr createAttribute(String paramString) throws DOMException;
/*      */   
/*      */   public abstract ProcessingInstruction createProcessingInstruction(String paramString1, String paramString2) throws DOMException;
/*      */   
/*      */   public abstract CDATASection createCDATASection(String paramString) throws DOMException;
/*      */   
/*      */   public abstract Comment createComment(String paramString);
/*      */   
/*      */   public abstract Text createTextNode(String paramString);
/*      */   
/*      */   public abstract DocumentFragment createDocumentFragment();
/*      */   
/*      */   public abstract Element createElement(String paramString);
/*      */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-dom.jar!\org\apache\batik\dom\AbstractDocument.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */