/*      */ package org.apache.batik.dom;
/*      */ 
/*      */ import java.io.Serializable;
/*      */ import org.apache.batik.dom.events.DOMMutationEvent;
/*      */ import org.apache.batik.dom.util.DOMUtilities;
/*      */ import org.w3c.dom.Attr;
/*      */ import org.w3c.dom.DOMException;
/*      */ import org.w3c.dom.Element;
/*      */ import org.w3c.dom.ElementTraversal;
/*      */ import org.w3c.dom.NamedNodeMap;
/*      */ import org.w3c.dom.Node;
/*      */ import org.w3c.dom.TypeInfo;
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ public abstract class AbstractElement
/*      */   extends AbstractParentChildNode
/*      */   implements Element, ElementTraversal
/*      */ {
/*      */   protected NamedNodeMap attributes;
/*      */   protected TypeInfo typeInfo;
/*      */   
/*      */   protected AbstractElement() {}
/*      */   
/*      */   protected AbstractElement(String name, AbstractDocument owner) {
/*   70 */     this.ownerDocument = owner;
/*   71 */     if (owner.getStrictErrorChecking() && !DOMUtilities.isValidName(name)) {
/*   72 */       throw createDOMException((short)5, "xml.name", new Object[] { name });
/*      */     }
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*   84 */   public short getNodeType() { return 1; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*   91 */   public boolean hasAttributes() { return (this.attributes != null && this.attributes.getLength() != 0); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*   98 */   public NamedNodeMap getAttributes() { return (this.attributes == null) ? (this.attributes = createAttributes()) : this.attributes; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  109 */   public String getTagName() { return getNodeName(); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  116 */   public boolean hasAttribute(String name) { return (this.attributes != null && this.attributes.getNamedItem(name) != null); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public String getAttribute(String name) {
/*  123 */     if (this.attributes == null) {
/*  124 */       return "";
/*      */     }
/*  126 */     Attr attr = (Attr)this.attributes.getNamedItem(name);
/*  127 */     return (attr == null) ? "" : attr.getValue();
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void setAttribute(String name, String value) throws DOMException {
/*  135 */     if (this.attributes == null) {
/*  136 */       this.attributes = createAttributes();
/*      */     }
/*  138 */     Attr attr = getAttributeNode(name);
/*  139 */     if (attr == null) {
/*  140 */       attr = getOwnerDocument().createAttribute(name);
/*  141 */       attr.setValue(value);
/*  142 */       this.attributes.setNamedItem(attr);
/*      */     } else {
/*  144 */       attr.setValue(value);
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void removeAttribute(String name) throws DOMException {
/*  153 */     if (!hasAttribute(name)) {
/*      */       return;
/*      */     }
/*  156 */     this.attributes.removeNamedItem(name);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public Attr getAttributeNode(String name) {
/*  164 */     if (this.attributes == null) {
/*  165 */       return null;
/*      */     }
/*  167 */     return (Attr)this.attributes.getNamedItem(name);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public Attr setAttributeNode(Attr newAttr) throws DOMException {
/*  175 */     if (newAttr == null) {
/*  176 */       return null;
/*      */     }
/*  178 */     if (this.attributes == null) {
/*  179 */       this.attributes = createAttributes();
/*      */     }
/*  181 */     return (Attr)this.attributes.setNamedItemNS(newAttr);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public Attr removeAttributeNode(Attr oldAttr) throws DOMException {
/*  189 */     if (oldAttr == null) {
/*  190 */       return null;
/*      */     }
/*  192 */     if (this.attributes == null) {
/*  193 */       throw createDOMException((short)8, "attribute.missing", new Object[] { oldAttr.getName() });
/*      */     }
/*      */ 
/*      */     
/*  197 */     String nsURI = oldAttr.getNamespaceURI();
/*  198 */     return (Attr)this.attributes.removeNamedItemNS(nsURI, (nsURI == null) ? oldAttr.getNodeName() : oldAttr.getLocalName());
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void normalize() {
/*  208 */     super.normalize();
/*  209 */     if (this.attributes != null) {
/*  210 */       NamedNodeMap map = getAttributes();
/*  211 */       for (int i = map.getLength() - 1; i >= 0; i--) {
/*  212 */         map.item(i).normalize();
/*      */       }
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public boolean hasAttributeNS(String namespaceURI, String localName) {
/*  222 */     if (namespaceURI != null && namespaceURI.length() == 0) {
/*  223 */       namespaceURI = null;
/*      */     }
/*  225 */     return (this.attributes != null && this.attributes.getNamedItemNS(namespaceURI, localName) != null);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public String getAttributeNS(String namespaceURI, String localName) {
/*  234 */     if (this.attributes == null) {
/*  235 */       return "";
/*      */     }
/*  237 */     if (namespaceURI != null && namespaceURI.length() == 0) {
/*  238 */       namespaceURI = null;
/*      */     }
/*  240 */     Attr attr = (Attr)this.attributes.getNamedItemNS(namespaceURI, localName);
/*  241 */     return (attr == null) ? "" : attr.getValue();
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void setAttributeNS(String namespaceURI, String qualifiedName, String value) throws DOMException {
/*  252 */     if (this.attributes == null) {
/*  253 */       this.attributes = createAttributes();
/*      */     }
/*  255 */     if (namespaceURI != null && namespaceURI.length() == 0) {
/*  256 */       namespaceURI = null;
/*      */     }
/*  258 */     Attr attr = getAttributeNodeNS(namespaceURI, qualifiedName);
/*  259 */     if (attr == null) {
/*  260 */       attr = getOwnerDocument().createAttributeNS(namespaceURI, qualifiedName);
/*      */       
/*  262 */       attr.setValue(value);
/*  263 */       this.attributes.setNamedItemNS(attr);
/*      */     } else {
/*  265 */       attr.setValue(value);
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void removeAttributeNS(String namespaceURI, String localName) throws DOMException {
/*  275 */     if (namespaceURI != null && namespaceURI.length() == 0) {
/*  276 */       namespaceURI = null;
/*      */     }
/*  278 */     if (!hasAttributeNS(namespaceURI, localName)) {
/*      */       return;
/*      */     }
/*  281 */     this.attributes.removeNamedItemNS(namespaceURI, localName);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public Attr getAttributeNodeNS(String namespaceURI, String localName) {
/*  290 */     if (namespaceURI != null && namespaceURI.length() == 0) {
/*  291 */       namespaceURI = null;
/*      */     }
/*  293 */     if (this.attributes == null) {
/*  294 */       return null;
/*      */     }
/*  296 */     return (Attr)this.attributes.getNamedItemNS(namespaceURI, localName);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public Attr setAttributeNodeNS(Attr newAttr) throws DOMException {
/*  304 */     if (newAttr == null) {
/*  305 */       return null;
/*      */     }
/*  307 */     if (this.attributes == null) {
/*  308 */       this.attributes = createAttributes();
/*      */     }
/*  310 */     return (Attr)this.attributes.setNamedItemNS(newAttr);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public TypeInfo getSchemaTypeInfo() {
/*  317 */     if (this.typeInfo == null) {
/*  318 */       this.typeInfo = new ElementTypeInfo(this);
/*      */     }
/*  320 */     return this.typeInfo;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void setIdAttribute(String name, boolean isId) throws DOMException {
/*  328 */     AbstractAttr a = (AbstractAttr)getAttributeNode(name);
/*  329 */     if (a == null) {
/*  330 */       throw createDOMException((short)8, "attribute.missing", new Object[] { name });
/*      */     }
/*      */ 
/*      */     
/*  334 */     if (a.isReadonly()) {
/*  335 */       throw createDOMException((short)7, "readonly.node", new Object[] { name });
/*      */     }
/*      */ 
/*      */     
/*  339 */     a.isIdAttr = isId;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void setIdAttributeNS(String ns, String ln, boolean isId) throws DOMException {
/*  348 */     if (ns != null && ns.length() == 0) {
/*  349 */       ns = null;
/*      */     }
/*  351 */     AbstractAttr a = (AbstractAttr)getAttributeNodeNS(ns, ln);
/*  352 */     if (a == null) {
/*  353 */       throw createDOMException((short)8, "attribute.missing", new Object[] { ns, ln });
/*      */     }
/*      */ 
/*      */     
/*  357 */     if (a.isReadonly()) {
/*  358 */       throw createDOMException((short)7, "readonly.node", new Object[] { a.getNodeName() });
/*      */     }
/*      */ 
/*      */     
/*  362 */     a.isIdAttr = isId;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void setIdAttributeNode(Attr attr, boolean isId) throws DOMException {
/*  371 */     AbstractAttr a = (AbstractAttr)attr;
/*  372 */     if (a.isReadonly()) {
/*  373 */       throw createDOMException((short)7, "readonly.node", new Object[] { a.getNodeName() });
/*      */     }
/*      */ 
/*      */     
/*  377 */     a.isIdAttr = isId;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected Attr getIdAttribute() {
/*  384 */     NamedNodeMap nnm = getAttributes();
/*  385 */     if (nnm == null) {
/*  386 */       return null;
/*      */     }
/*  388 */     int len = nnm.getLength();
/*  389 */     for (int i = 0; i < len; i++) {
/*  390 */       AbstractAttr a = (AbstractAttr)nnm.item(i);
/*  391 */       if (a.isId()) {
/*  392 */         return a;
/*      */       }
/*      */     } 
/*  395 */     return null;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected String getId() {
/*  402 */     Attr a = getIdAttribute();
/*  403 */     if (a != null) {
/*  404 */       String id = a.getNodeValue();
/*  405 */       if (id.length() > 0) {
/*  406 */         return id;
/*      */       }
/*      */     } 
/*  409 */     return null;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  416 */   protected void nodeAdded(Node node) { invalidateElementsByTagName(node); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  423 */   protected void nodeToBeRemoved(Node node) { invalidateElementsByTagName(node); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   private void invalidateElementsByTagName(Node node) {
/*  430 */     if (node.getNodeType() != 1) {
/*      */       return;
/*      */     }
/*  433 */     AbstractDocument ad = getCurrentDocument();
/*  434 */     String ns = node.getNamespaceURI();
/*  435 */     String nm = node.getNodeName();
/*  436 */     String ln = (ns == null) ? node.getNodeName() : node.getLocalName();
/*  437 */     for (Node n = this; n != null; n = n.getParentNode()) {
/*  438 */       AbstractParentNode.ElementsByTagNameNS lns; AbstractParentNode.ElementsByTagName l; switch (n.getNodeType()) {
/*      */         case 1:
/*      */         case 9:
/*  441 */           l = ad.getElementsByTagName(n, nm);
/*  442 */           if (l != null) {
/*  443 */             l.invalidate();
/*      */           }
/*  445 */           l = ad.getElementsByTagName(n, "*");
/*  446 */           if (l != null) {
/*  447 */             l.invalidate();
/*      */           }
/*  449 */           lns = ad.getElementsByTagNameNS(n, ns, ln);
/*      */           
/*  451 */           if (lns != null) {
/*  452 */             lns.invalidate();
/*      */           }
/*  454 */           lns = ad.getElementsByTagNameNS(n, "*", ln);
/*  455 */           if (lns != null) {
/*  456 */             lns.invalidate();
/*      */           }
/*  458 */           lns = ad.getElementsByTagNameNS(n, ns, "*");
/*  459 */           if (lns != null) {
/*  460 */             lns.invalidate();
/*      */           }
/*  462 */           lns = ad.getElementsByTagNameNS(n, "*", "*");
/*  463 */           if (lns != null) {
/*  464 */             lns.invalidate();
/*      */           }
/*      */           break;
/*      */       } 
/*      */ 
/*      */ 
/*      */     
/*      */     } 
/*  472 */     Node c = node.getFirstChild();
/*  473 */     while (c != null) {
/*  474 */       invalidateElementsByTagName(c);
/*  475 */       c = c.getNextSibling();
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  484 */   protected NamedNodeMap createAttributes() { return new NamedNodeHashMap(this); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected Node export(Node n, AbstractDocument d) {
/*  493 */     super.export(n, d);
/*  494 */     AbstractElement ae = (AbstractElement)n;
/*  495 */     if (this.attributes != null) {
/*  496 */       NamedNodeMap map = this.attributes;
/*  497 */       for (int i = map.getLength() - 1; i >= 0; i--) {
/*  498 */         AbstractAttr aa = (AbstractAttr)map.item(i);
/*  499 */         if (aa.getSpecified()) {
/*  500 */           Attr attr = (Attr)aa.deepExport(aa.cloneNode(false), d);
/*  501 */           if (aa instanceof AbstractAttrNS) {
/*  502 */             ae.setAttributeNodeNS(attr);
/*      */           } else {
/*  504 */             ae.setAttributeNode(attr);
/*      */           } 
/*      */         } 
/*      */       } 
/*      */     } 
/*  509 */     return n;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected Node deepExport(Node n, AbstractDocument d) {
/*  518 */     super.deepExport(n, d);
/*  519 */     AbstractElement ae = (AbstractElement)n;
/*  520 */     if (this.attributes != null) {
/*  521 */       NamedNodeMap map = this.attributes;
/*  522 */       for (int i = map.getLength() - 1; i >= 0; i--) {
/*  523 */         AbstractAttr aa = (AbstractAttr)map.item(i);
/*  524 */         if (aa.getSpecified()) {
/*  525 */           Attr attr = (Attr)aa.deepExport(aa.cloneNode(false), d);
/*  526 */           if (aa instanceof AbstractAttrNS) {
/*  527 */             ae.setAttributeNodeNS(attr);
/*      */           } else {
/*  529 */             ae.setAttributeNode(attr);
/*      */           } 
/*      */         } 
/*      */       } 
/*      */     } 
/*  534 */     return n;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected Node copyInto(Node n) {
/*  542 */     super.copyInto(n);
/*  543 */     AbstractElement ae = (AbstractElement)n;
/*  544 */     if (this.attributes != null) {
/*  545 */       NamedNodeMap map = this.attributes;
/*  546 */       for (int i = map.getLength() - 1; i >= 0; i--) {
/*  547 */         AbstractAttr aa = (AbstractAttr)map.item(i).cloneNode(true);
/*  548 */         if (aa instanceof AbstractAttrNS) {
/*  549 */           ae.setAttributeNodeNS(aa);
/*      */         } else {
/*  551 */           ae.setAttributeNode(aa);
/*      */         } 
/*      */       } 
/*      */     } 
/*  555 */     return n;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected Node deepCopyInto(Node n) {
/*  563 */     super.deepCopyInto(n);
/*  564 */     AbstractElement ae = (AbstractElement)n;
/*  565 */     if (this.attributes != null) {
/*  566 */       NamedNodeMap map = this.attributes;
/*  567 */       for (int i = map.getLength() - 1; i >= 0; i--) {
/*  568 */         AbstractAttr aa = (AbstractAttr)map.item(i).cloneNode(true);
/*  569 */         if (aa instanceof AbstractAttrNS) {
/*  570 */           ae.setAttributeNodeNS(aa);
/*      */         } else {
/*  572 */           ae.setAttributeNode(aa);
/*      */         } 
/*      */       } 
/*      */     } 
/*  576 */     return n;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected void checkChildType(Node n, boolean replace) {
/*  584 */     switch (n.getNodeType()) {
/*      */       case 1:
/*      */       case 3:
/*      */       case 4:
/*      */       case 5:
/*      */       case 7:
/*      */       case 8:
/*      */       case 11:
/*      */         return;
/*      */     } 
/*  594 */     throw createDOMException((short)3, "child.type", new Object[] { new Integer(getNodeType()), getNodeName(), new Integer(n.getNodeType()), n.getNodeName() });
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void fireDOMAttrModifiedEvent(String name, Attr node, String oldv, String newv, short change) {
/*  617 */     switch (change) {
/*      */       case 2:
/*  619 */         if (((AbstractAttr)node).isId())
/*  620 */           this.ownerDocument.addIdEntry(this, newv); 
/*  621 */         attrAdded(node, newv);
/*      */         break;
/*      */       
/*      */       case 1:
/*  625 */         if (((AbstractAttr)node).isId())
/*  626 */           this.ownerDocument.updateIdEntry(this, oldv, newv); 
/*  627 */         attrModified(node, oldv, newv);
/*      */         break;
/*      */       
/*      */       default:
/*  631 */         if (((AbstractAttr)node).isId())
/*  632 */           this.ownerDocument.removeIdEntry(this, oldv); 
/*  633 */         attrRemoved(node, oldv); break;
/*      */     } 
/*  635 */     AbstractDocument doc = getCurrentDocument();
/*  636 */     if (doc.getEventsEnabled() && !oldv.equals(newv)) {
/*  637 */       DOMMutationEvent ev = (DOMMutationEvent)doc.createEvent("MutationEvents");
/*      */       
/*  639 */       ev.initMutationEventNS("http://www.w3.org/2001/xml-events", "DOMAttrModified", true, false, node, oldv, newv, name, change);
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */       
/*  648 */       dispatchEvent(ev);
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected void attrAdded(Attr node, String newv) {}
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected void attrModified(Attr node, String oldv, String newv) {}
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected void attrRemoved(Attr node, String oldv) {}
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public Element getFirstElementChild() {
/*  676 */     Node n = getFirstChild();
/*  677 */     while (n != null) {
/*  678 */       if (n.getNodeType() == 1) {
/*  679 */         return (Element)n;
/*      */       }
/*  681 */       n = n.getNextSibling();
/*      */     } 
/*  683 */     return null;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public Element getLastElementChild() {
/*  690 */     Node n = getLastChild();
/*  691 */     while (n != null) {
/*  692 */       if (n.getNodeType() == 1) {
/*  693 */         return (Element)n;
/*      */       }
/*  695 */       n = n.getPreviousSibling();
/*      */     } 
/*  697 */     return null;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public Element getNextElementSibling() {
/*  704 */     Node n = getNextSibling();
/*  705 */     while (n != null) {
/*  706 */       if (n.getNodeType() == 1) {
/*  707 */         return (Element)n;
/*      */       }
/*  709 */       n = n.getNextSibling();
/*      */     } 
/*  711 */     return null;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public Element getPreviousElementSibling() {
/*  718 */     Node n = getPreviousSibling();
/*  719 */     while (n != null) {
/*  720 */       if (n.getNodeType() == 1) {
/*  721 */         return (Element)n;
/*      */       }
/*  723 */       n = n.getPreviousSibling();
/*      */     } 
/*  725 */     return (Element)n;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public int getChildElementCount() {
/*  732 */     getChildNodes();
/*  733 */     return this.childNodes.elementChildren;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public class NamedNodeHashMap
/*      */     implements NamedNodeMap, Serializable
/*      */   {
/*      */     protected static final int INITIAL_CAPACITY = 3;
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     protected AbstractElement.Entry[] table;
/*      */ 
/*      */ 
/*      */     
/*      */     protected int count;
/*      */ 
/*      */ 
/*      */     
/*      */     private final AbstractElement this$0;
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     public NamedNodeHashMap(AbstractElement this$0) {
/*  762 */       this.this$0 = this$0;
/*  763 */       this.table = new AbstractElement.Entry[3];
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     public Node getNamedItem(String name) {
/*  770 */       if (name == null) {
/*  771 */         return null;
/*      */       }
/*  773 */       return get(null, name);
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     public Node setNamedItem(Node arg) {
/*  780 */       if (arg == null) {
/*  781 */         return null;
/*      */       }
/*  783 */       checkNode(arg);
/*      */       
/*  785 */       return setNamedItem(null, arg.getNodeName(), arg);
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  792 */     public Node removeNamedItem(String name) { return removeNamedItemNS(null, name); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     public Node item(int index) {
/*  799 */       if (index < 0 || index >= this.count) {
/*  800 */         return null;
/*      */       }
/*  802 */       int j = 0;
/*  803 */       for (int i = 0; i < this.table.length; i++) {
/*  804 */         AbstractElement.Entry e = this.table[i];
/*  805 */         if (e != null)
/*      */           
/*      */           do {
/*      */             
/*  809 */             if (j++ == index) {
/*  810 */               return e.value;
/*      */             }
/*  812 */             e = e.next;
/*  813 */           } while (e != null); 
/*      */       } 
/*  815 */       return null;
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  822 */     public int getLength() { return this.count; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     public Node getNamedItemNS(String namespaceURI, String localName) {
/*  830 */       if (namespaceURI != null && namespaceURI.length() == 0) {
/*  831 */         namespaceURI = null;
/*      */       }
/*  833 */       return get(namespaceURI, localName);
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     public Node setNamedItemNS(Node arg) {
/*  840 */       if (arg == null) {
/*  841 */         return null;
/*      */       }
/*  843 */       String nsURI = arg.getNamespaceURI();
/*  844 */       return setNamedItem(nsURI, (nsURI == null) ? arg.getNodeName() : arg.getLocalName(), arg);
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     public Node removeNamedItemNS(String namespaceURI, String localName) {
/*  855 */       if (this.this$0.isReadonly()) {
/*  856 */         throw this.this$0.createDOMException((short)7, "readonly.node.map", new Object[0]);
/*      */       }
/*      */ 
/*      */ 
/*      */       
/*  861 */       if (localName == null) {
/*  862 */         throw this.this$0.createDOMException((short)8, "attribute.missing", new Object[] { "" });
/*      */       }
/*      */ 
/*      */       
/*  866 */       if (namespaceURI != null && namespaceURI.length() == 0) {
/*  867 */         namespaceURI = null;
/*      */       }
/*  869 */       AbstractAttr n = (AbstractAttr)remove(namespaceURI, localName);
/*  870 */       if (n == null) {
/*  871 */         throw this.this$0.createDOMException((short)8, "attribute.missing", new Object[] { localName });
/*      */       }
/*      */ 
/*      */       
/*  875 */       n.setOwnerElement(null);
/*      */ 
/*      */       
/*  878 */       this.this$0.fireDOMAttrModifiedEvent(n.getNodeName(), n, n.getNodeValue(), "", (short)3);
/*      */       
/*  880 */       return n;
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     public Node setNamedItem(String ns, String name, Node arg) throws DOMException {
/*  889 */       if (ns != null && ns.length() == 0) {
/*  890 */         ns = null;
/*      */       }
/*  892 */       ((AbstractAttr)arg).setOwnerElement(this.this$0);
/*  893 */       AbstractAttr result = (AbstractAttr)put(ns, name, arg);
/*      */       
/*  895 */       if (result != null) {
/*  896 */         result.setOwnerElement(null);
/*  897 */         this.this$0.fireDOMAttrModifiedEvent(name, result, result.getNodeValue(), "", (short)3);
/*      */       } 
/*      */ 
/*      */ 
/*      */ 
/*      */       
/*  903 */       this.this$0.fireDOMAttrModifiedEvent(name, (Attr)arg, "", arg.getNodeValue(), (short)2);
/*      */ 
/*      */ 
/*      */ 
/*      */       
/*  908 */       return result;
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     protected void checkNode(Node arg) {
/*  915 */       if (this.this$0.isReadonly()) {
/*  916 */         throw this.this$0.createDOMException((short)7, "readonly.node.map", new Object[0]);
/*      */       }
/*      */ 
/*      */ 
/*      */       
/*  921 */       if (this.this$0.getOwnerDocument() != arg.getOwnerDocument()) {
/*  922 */         throw this.this$0.createDOMException((short)4, "node.from.wrong.document", new Object[] { new Integer(arg.getNodeType()), arg.getNodeName() });
/*      */       }
/*      */ 
/*      */ 
/*      */       
/*  927 */       if (arg.getNodeType() == 2 && ((Attr)arg).getOwnerElement() != null)
/*      */       {
/*  929 */         throw this.this$0.createDOMException((short)4, "inuse.attribute", new Object[] { arg.getNodeName() });
/*      */       }
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     protected Node get(String ns, String nm) {
/*  941 */       int hash = hashCode(ns, nm) & 0x7FFFFFFF;
/*  942 */       int index = hash % this.table.length;
/*      */       
/*  944 */       for (AbstractElement.Entry e = this.table[index]; e != null; e = e.next) {
/*  945 */         if (e.hash == hash && e.match(ns, nm)) {
/*  946 */           return e.value;
/*      */         }
/*      */       } 
/*  949 */       return null;
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     protected Node put(String ns, String nm, Node value) throws DOMException {
/*  958 */       int hash = hashCode(ns, nm) & 0x7FFFFFFF;
/*  959 */       int index = hash % this.table.length;
/*      */       
/*  961 */       for (AbstractElement.Entry e = this.table[index]; e != null; e = e.next) {
/*  962 */         if (e.hash == hash && e.match(ns, nm)) {
/*  963 */           Node old = e.value;
/*  964 */           e.value = value;
/*  965 */           return old;
/*      */         } 
/*      */       } 
/*      */ 
/*      */       
/*  970 */       int len = this.table.length;
/*  971 */       if (this.count++ >= len - (len >> 2)) {
/*      */         
/*  973 */         rehash();
/*  974 */         index = hash % this.table.length;
/*      */       } 
/*      */       
/*  977 */       AbstractElement.Entry e = new AbstractElement.Entry(hash, ns, nm, value, this.table[index]);
/*  978 */       this.table[index] = e;
/*  979 */       return null;
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     protected Node remove(String ns, String nm) {
/*  988 */       int hash = hashCode(ns, nm) & 0x7FFFFFFF;
/*  989 */       int index = hash % this.table.length;
/*      */       
/*  991 */       AbstractElement.Entry p = null;
/*  992 */       for (AbstractElement.Entry e = this.table[index]; e != null; e = e.next) {
/*  993 */         if (e.hash == hash && e.match(ns, nm)) {
/*  994 */           Node result = e.value;
/*  995 */           if (p == null) {
/*  996 */             this.table[index] = e.next;
/*      */           } else {
/*  998 */             p.next = e.next;
/*      */           } 
/* 1000 */           this.count--;
/* 1001 */           return result;
/*      */         } 
/* 1003 */         p = e;
/*      */       } 
/* 1005 */       return null;
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     protected void rehash() {
/* 1012 */       AbstractElement.Entry[] arrayOfEntry = this.table;
/*      */       
/* 1014 */       this.table = new AbstractElement.Entry[arrayOfEntry.length * 2 + 1];
/*      */       
/* 1016 */       for (int i = arrayOfEntry.length - 1; i >= 0; i--) {
/* 1017 */         for (AbstractElement.Entry old = arrayOfEntry[i]; old != null; ) {
/* 1018 */           AbstractElement.Entry e = old;
/* 1019 */           old = old.next;
/*      */           
/* 1021 */           int index = e.hash % this.table.length;
/* 1022 */           e.next = this.table[index];
/* 1023 */           this.table[index] = e;
/*      */         } 
/*      */       } 
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     protected int hashCode(String ns, String nm) {
/* 1032 */       int result = (ns == null) ? 0 : ns.hashCode();
/* 1033 */       return result ^ nm.hashCode();
/*      */     }
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected static class Entry
/*      */     implements Serializable
/*      */   {
/*      */     public int hash;
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     public String namespaceURI;
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     public String name;
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     public Node value;
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     public Entry next;
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     public Entry(int hash, String ns, String nm, Node value, Entry next) {
/* 1072 */       this.hash = hash;
/* 1073 */       this.namespaceURI = ns;
/* 1074 */       this.name = nm;
/* 1075 */       this.value = value;
/* 1076 */       this.next = next;
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     public boolean match(String ns, String nm) {
/* 1083 */       if (this.namespaceURI != null) {
/* 1084 */         if (!this.namespaceURI.equals(ns)) {
/* 1085 */           return false;
/*      */         }
/* 1087 */       } else if (ns != null) {
/* 1088 */         return false;
/*      */       } 
/* 1090 */       return this.name.equals(nm);
/*      */     }
/*      */   }
/*      */   
/*      */   public class ElementTypeInfo implements TypeInfo {
/*      */     private final AbstractElement this$0;
/*      */     
/* 1097 */     public ElementTypeInfo(AbstractElement this$0) { this.this$0 = this$0; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 1103 */     public String getTypeNamespace() { return null; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 1110 */     public String getTypeName() { return null; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 1117 */     public boolean isDerivedFrom(String ns, String name, int method) { return false; }
/*      */   }
/*      */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-dom.jar!\org\apache\batik\dom\AbstractElement.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */