/*      */ package org.apache.batik.dom;
/*      */ 
/*      */ import java.io.Serializable;
/*      */ import java.util.ArrayList;
/*      */ import java.util.HashMap;
/*      */ import java.util.Iterator;
/*      */ import java.util.Map;
/*      */ import org.apache.batik.dom.events.DOMMutationEvent;
/*      */ import org.apache.batik.dom.events.EventSupport;
/*      */ import org.apache.batik.dom.events.NodeEventTarget;
/*      */ import org.apache.batik.dom.util.DOMUtilities;
/*      */ import org.apache.batik.dom.xbl.NodeXBL;
/*      */ import org.apache.batik.dom.xbl.XBLManagerData;
/*      */ import org.apache.batik.util.ParsedURL;
/*      */ import org.w3c.dom.Attr;
/*      */ import org.w3c.dom.DOMException;
/*      */ import org.w3c.dom.Document;
/*      */ import org.w3c.dom.DocumentType;
/*      */ import org.w3c.dom.Element;
/*      */ import org.w3c.dom.NamedNodeMap;
/*      */ import org.w3c.dom.Node;
/*      */ import org.w3c.dom.NodeList;
/*      */ import org.w3c.dom.UserDataHandler;
/*      */ import org.w3c.dom.events.Event;
/*      */ import org.w3c.dom.events.EventException;
/*      */ import org.w3c.dom.events.EventListener;
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ public abstract class AbstractNode
/*      */   implements ExtendedNode, NodeXBL, XBLManagerData, Serializable
/*      */ {
/*   66 */   public static final NodeList EMPTY_NODE_LIST = new NodeList() {
/*   67 */       public Node item(int i) { return null; }
/*   68 */       public int getLength() { return 0; }
/*      */     };
/*      */ 
/*      */ 
/*      */   
/*      */   protected AbstractDocument ownerDocument;
/*      */ 
/*      */   
/*      */   protected EventSupport eventSupport;
/*      */ 
/*      */   
/*      */   protected HashMap userData;
/*      */ 
/*      */   
/*      */   protected HashMap userDataHandlers;
/*      */ 
/*      */   
/*      */   protected Object managerData;
/*      */ 
/*      */   
/*      */   public static final short DOCUMENT_POSITION_DISCONNECTED = 1;
/*      */ 
/*      */   
/*      */   public static final short DOCUMENT_POSITION_PRECEDING = 2;
/*      */ 
/*      */   
/*      */   public static final short DOCUMENT_POSITION_FOLLOWING = 4;
/*      */ 
/*      */   
/*      */   public static final short DOCUMENT_POSITION_CONTAINS = 8;
/*      */   
/*      */   public static final short DOCUMENT_POSITION_CONTAINED_BY = 16;
/*      */   
/*      */   public static final short DOCUMENT_POSITION_IMPLEMENTATION_SPECIFIC = 32;
/*      */ 
/*      */   
/*      */   public void setNodeName(String v) {}
/*      */ 
/*      */   
/*  107 */   public void setOwnerDocument(Document doc) { this.ownerDocument = (AbstractDocument)doc; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  115 */   public void setSpecified(boolean v) { throw createDOMException((short)11, "node.type", new Object[] { new Integer(getNodeType()), getNodeName() }); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  126 */   public String getNodeValue() throws DOMException { return null; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void setNodeValue(String nodeValue) {}
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  141 */   public Node getParentNode() { return null; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  149 */   public void setParentNode(Node v) { throw createDOMException((short)3, "parent.not.allowed", new Object[] { new Integer(getNodeType()), getNodeName() }); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  160 */   public NodeList getChildNodes() { return EMPTY_NODE_LIST; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  168 */   public Node getFirstChild() { return null; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  176 */   public Node getLastChild() { return null; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  184 */   public void setPreviousSibling(Node n) { throw createDOMException((short)3, "sibling.not.allowed", new Object[] { new Integer(getNodeType()), getNodeName() }); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  195 */   public Node getPreviousSibling() { return null; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  203 */   public void setNextSibling(Node n) { throw createDOMException((short)3, "sibling.not.allowed", new Object[] { new Integer(getNodeType()), getNodeName() }); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  214 */   public Node getNextSibling() { return null; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  222 */   public boolean hasAttributes() { return false; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  230 */   public NamedNodeMap getAttributes() { return null; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  238 */   public Document getOwnerDocument() { return this.ownerDocument; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  246 */   public String getNamespaceURI() throws DOMException { return null; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  256 */   public Node insertBefore(Node newChild, Node refChild) throws DOMException { throw createDOMException((short)3, "children.not.allowed", new Object[] { new Integer(getNodeType()), getNodeName() }); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  269 */   public Node replaceChild(Node newChild, Node oldChild) throws DOMException { throw createDOMException((short)3, "children.not.allowed", new Object[] { new Integer(getNodeType()), getNodeName() }); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  280 */   public Node removeChild(Node oldChild) throws DOMException { throw createDOMException((short)3, "children.not.allowed", new Object[] { new Integer(getNodeType()), getNodeName() }); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  291 */   public Node appendChild(Node newChild) throws DOMException { throw createDOMException((short)3, "children.not.allowed", new Object[] { new Integer(getNodeType()), getNodeName() }); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  302 */   public boolean hasChildNodes() { return false; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public Node cloneNode(boolean deep) {
/*  309 */     Node n = deep ? deepCopyInto(newNode()) : copyInto(newNode());
/*  310 */     fireUserDataHandlers((short)1, this, n);
/*  311 */     return n;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void normalize() {}
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  326 */   public boolean isSupported(String feature, String version) { return getCurrentDocument().getImplementation().hasFeature(feature, version); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  334 */   public String getPrefix() throws DOMException { return (getNamespaceURI() == null) ? null : DOMUtilities.getPrefix(getNodeName()); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void setPrefix(String prefix) {
/*  343 */     if (isReadonly()) {
/*  344 */       throw createDOMException((short)7, "readonly.node", new Object[] { new Integer(getNodeType()), getNodeName() });
/*      */     }
/*      */ 
/*      */ 
/*      */     
/*  349 */     String uri = getNamespaceURI();
/*  350 */     if (uri == null) {
/*  351 */       throw createDOMException((short)14, "namespace", new Object[] { new Integer(getNodeType()), getNodeName() });
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  357 */     String name = getLocalName();
/*  358 */     if (prefix == null) {
/*      */       
/*  360 */       setNodeName(name);
/*      */       
/*      */       return;
/*      */     } 
/*      */     
/*  365 */     if (!prefix.equals("") && !DOMUtilities.isValidName(prefix)) {
/*  366 */       throw createDOMException((short)5, "prefix", new Object[] { new Integer(getNodeType()), getNodeName(), prefix });
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  372 */     if (!DOMUtilities.isValidPrefix(prefix)) {
/*  373 */       throw createDOMException((short)14, "prefix", new Object[] { new Integer(getNodeType()), getNodeName(), prefix });
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  379 */     if ((prefix.equals("xml") && !"http://www.w3.org/XML/1998/namespace".equals(uri)) || (prefix.equals("xmlns") && !"http://www.w3.org/2000/xmlns/".equals(uri)))
/*      */     {
/*      */ 
/*      */       
/*  383 */       throw createDOMException((short)14, "namespace.uri", new Object[] { new Integer(getNodeType()), getNodeName(), uri });
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  389 */     setNodeName(prefix + ':' + name);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  396 */   public String getLocalName() throws DOMException { return (getNamespaceURI() == null) ? null : DOMUtilities.getLocalName(getNodeName()); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public DOMException createDOMException(short type, String key, Object[] args) {
/*      */     try {
/*  408 */       return new DOMException(type, getCurrentDocument().formatMessage(key, args));
/*      */     } catch (Exception e) {
/*      */       
/*  411 */       return new DOMException(type, key);
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected String getCascadedXMLBase(Node node) {
/*  420 */     String base = null;
/*  421 */     Node n = node.getParentNode();
/*  422 */     while (n != null) {
/*  423 */       if (n.getNodeType() == 1) {
/*  424 */         base = getCascadedXMLBase(n);
/*      */         break;
/*      */       } 
/*  427 */       n = n.getParentNode();
/*      */     } 
/*  429 */     if (base == null) {
/*      */       AbstractDocument abstractDocument;
/*  431 */       if (node.getNodeType() == 9) {
/*  432 */         abstractDocument = (AbstractDocument)node;
/*      */       } else {
/*  434 */         abstractDocument = (AbstractDocument)node.getOwnerDocument();
/*      */       } 
/*  436 */       base = abstractDocument.getDocumentURI();
/*      */     } 
/*  438 */     while (node != null && node.getNodeType() != 1) {
/*  439 */       node = node.getParentNode();
/*      */     }
/*  441 */     if (node == null) {
/*  442 */       return base;
/*      */     }
/*  444 */     Element e = (Element)node;
/*  445 */     Attr attr = e.getAttributeNodeNS("http://www.w3.org/XML/1998/namespace", "base");
/*      */     
/*  447 */     if (attr != null) {
/*  448 */       if (base == null) {
/*  449 */         base = attr.getNodeValue();
/*      */       } else {
/*  451 */         base = (new ParsedURL(base, attr.getNodeValue())).toString();
/*      */       } 
/*      */     }
/*  454 */     return base;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  461 */   public String getBaseURI() throws DOMException { return getCascadedXMLBase(this); }
/*      */ 
/*      */ 
/*      */   
/*  465 */   public static String getBaseURI(Node n) { return ((AbstractNode)n).getBaseURI(); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public short compareDocumentPosition(Node other) throws DOMException {
/*  484 */     if (this == other) {
/*  485 */       return 0;
/*      */     }
/*  487 */     ArrayList a1 = new ArrayList(10);
/*  488 */     ArrayList a2 = new ArrayList(10);
/*  489 */     int c1 = 0;
/*  490 */     int c2 = 0;
/*      */     
/*  492 */     if (getNodeType() == 2) {
/*  493 */       a1.add(this);
/*  494 */       c1++;
/*  495 */       node = ((Attr)this).getOwnerElement();
/*  496 */       if (other.getNodeType() == 2) {
/*  497 */         Attr otherAttr = (Attr)other;
/*  498 */         if (node == otherAttr.getOwnerElement()) {
/*  499 */           if (hashCode() < ((Attr)other).hashCode()) {
/*  500 */             return 34;
/*      */           }
/*      */           
/*  503 */           return 36;
/*      */         }
/*      */       
/*      */       } 
/*      */     } else {
/*      */       
/*  509 */       node = this;
/*      */     } 
/*  511 */     while (node != null) {
/*  512 */       if (node == other) {
/*  513 */         return 20;
/*      */       }
/*      */       
/*  516 */       a1.add(node);
/*  517 */       c1++;
/*  518 */       Node node1 = node.getParentNode();
/*      */     } 
/*  520 */     if (other.getNodeType() == 2) {
/*  521 */       a2.add(other);
/*  522 */       c2++;
/*  523 */       Element element = ((Attr)other).getOwnerElement();
/*      */     } else {
/*  525 */       node = other;
/*      */     } 
/*  527 */     while (node != null) {
/*  528 */       if (node == this) {
/*  529 */         return 10;
/*      */       }
/*      */       
/*  532 */       a2.add(node);
/*  533 */       c2++;
/*  534 */       node = node.getParentNode();
/*      */     } 
/*  536 */     int i1 = c1 - 1;
/*  537 */     int i2 = c2 - 1;
/*  538 */     if (a1.get(i1) != a2.get(i2)) {
/*  539 */       if (hashCode() < other.hashCode()) {
/*  540 */         return 35;
/*      */       }
/*      */ 
/*      */       
/*  544 */       return 37;
/*      */     } 
/*      */ 
/*      */ 
/*      */     
/*  549 */     Object n1 = a1.get(i1);
/*  550 */     Object n2 = a2.get(i2);
/*  551 */     while (n1 == n2) {
/*  552 */       node = (Node)n1;
/*  553 */       n1 = a1.get(--i1);
/*  554 */       n2 = a2.get(--i2);
/*      */     } 
/*  556 */     for (Node node = node.getFirstChild(); node != null; node = node.getNextSibling()) {
/*  557 */       if (node == n1)
/*  558 */         return 2; 
/*  559 */       if (node == n2) {
/*  560 */         return 4;
/*      */       }
/*      */     } 
/*  563 */     return 1;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  570 */   public String getTextContent() throws DOMException { return null; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void setTextContent(String s) {
/*  577 */     if (isReadonly()) {
/*  578 */       throw createDOMException((short)7, "readonly.node", new Object[] { new Integer(getNodeType()), getNodeName() });
/*      */     }
/*      */ 
/*      */ 
/*      */     
/*  583 */     if (getNodeType() != 10) {
/*  584 */       while (getFirstChild() != null) {
/*  585 */         removeChild(getFirstChild());
/*      */       }
/*  587 */       appendChild(getOwnerDocument().createTextNode(s));
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  595 */   public boolean isSameNode(Node other) { return (this == other); }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public String lookupPrefix(String namespaceURI) {
/*      */     AbstractNode ownerElement, de;
/*  602 */     if (namespaceURI == null || namespaceURI.length() == 0) {
/*  603 */       return null;
/*      */     }
/*  605 */     int type = getNodeType();
/*  606 */     switch (type) {
/*      */       case 1:
/*  608 */         return lookupNamespacePrefix(namespaceURI, (Element)this);
/*      */       case 9:
/*  610 */         de = (AbstractNode)((Document)this).getDocumentElement();
/*      */         
/*  612 */         return de.lookupPrefix(namespaceURI);
/*      */       case 6:
/*      */       case 10:
/*      */       case 11:
/*      */       case 12:
/*  617 */         return null;
/*      */       case 2:
/*  619 */         ownerElement = (AbstractNode)((Attr)this).getOwnerElement();
/*      */         
/*  621 */         if (ownerElement != null) {
/*  622 */           return ownerElement.lookupPrefix(namespaceURI);
/*      */         }
/*  624 */         return null;
/*      */     } 
/*  626 */     Node n = getParentNode();
/*  627 */     for (; n != null; 
/*  628 */       n = n.getParentNode()) {
/*  629 */       if (n.getNodeType() == 1) {
/*  630 */         return ((AbstractNode)n).lookupPrefix(namespaceURI);
/*      */       }
/*      */     } 
/*  633 */     return null;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected String lookupNamespacePrefix(String namespaceURI, Element originalElement) {
/*  642 */     String ns = originalElement.getNamespaceURI();
/*  643 */     String prefix = originalElement.getPrefix();
/*  644 */     if (ns != null && ns.equals(namespaceURI) && prefix != null) {
/*      */ 
/*      */       
/*  647 */       String pns = ((AbstractNode)originalElement).lookupNamespaceURI(prefix);
/*      */       
/*  649 */       if (pns != null && pns.equals(namespaceURI)) {
/*  650 */         return prefix;
/*      */       }
/*      */     } 
/*  653 */     NamedNodeMap nnm = originalElement.getAttributes();
/*  654 */     if (nnm != null) {
/*  655 */       for (int i = 0; i < nnm.getLength(); i++) {
/*  656 */         Node attr = nnm.item(i);
/*  657 */         if ("xmlns".equals(attr.getPrefix()) && attr.getNodeValue().equals(namespaceURI)) {
/*      */           
/*  659 */           String ln = attr.getLocalName();
/*  660 */           AbstractNode oe = (AbstractNode)originalElement;
/*  661 */           String pns = oe.lookupNamespaceURI(ln);
/*  662 */           if (pns != null && pns.equals(namespaceURI)) {
/*  663 */             return ln;
/*      */           }
/*      */         } 
/*      */       } 
/*      */     }
/*  668 */     for (Node n = getParentNode(); n != null; n = n.getParentNode()) {
/*  669 */       if (n.getNodeType() == 1) {
/*  670 */         return ((AbstractNode)n).lookupNamespacePrefix(namespaceURI, originalElement);
/*      */       }
/*      */     } 
/*      */     
/*  674 */     return null;
/*      */   }
/*      */ 
/*      */   
/*      */   public boolean isDefaultNamespace(String namespaceURI) {
/*      */     NamedNodeMap nnm;
/*      */     AbstractNode owner;
/*      */     AbstractNode de;
/*  682 */     switch (getNodeType()) {
/*      */       case 9:
/*  684 */         de = (AbstractNode)((Document)this).getDocumentElement();
/*      */         
/*  686 */         return de.isDefaultNamespace(namespaceURI);
/*      */       case 6:
/*      */       case 10:
/*      */       case 11:
/*      */       case 12:
/*  691 */         return false;
/*      */       case 2:
/*  693 */         owner = (AbstractNode)((Attr)this).getOwnerElement();
/*      */         
/*  695 */         if (owner != null) {
/*  696 */           return owner.isDefaultNamespace(namespaceURI);
/*      */         }
/*  698 */         return false;
/*      */       case 1:
/*  700 */         if (getPrefix() == null) {
/*  701 */           String ns = getNamespaceURI();
/*  702 */           return ((ns == null && namespaceURI == null) || (ns != null && ns.equals(namespaceURI)));
/*      */         } 
/*      */         
/*  705 */         nnm = getAttributes();
/*  706 */         if (nnm != null) {
/*  707 */           for (int i = 0; i < nnm.getLength(); i++) {
/*  708 */             Node attr = nnm.item(i);
/*  709 */             if ("xmlns".equals(attr.getLocalName()))
/*      */             {
/*  711 */               return attr.getNodeValue().equals(namespaceURI);
/*      */             }
/*      */           } 
/*      */         }
/*      */         break;
/*      */     } 
/*  717 */     for (Node n = this; n != null; n = n.getParentNode()) {
/*  718 */       if (n.getNodeType() == 1) {
/*  719 */         AbstractNode an = (AbstractNode)n;
/*  720 */         return an.isDefaultNamespace(namespaceURI);
/*      */       } 
/*      */     } 
/*  723 */     return false;
/*      */   }
/*      */ 
/*      */ 
/*      */   
/*      */   public String lookupNamespaceURI(String prefix) {
/*      */     NamedNodeMap nnm;
/*      */     AbstractNode owner;
/*      */     AbstractNode de;
/*  732 */     switch (getNodeType()) {
/*      */       case 9:
/*  734 */         de = (AbstractNode)((Document)this).getDocumentElement();
/*      */         
/*  736 */         return de.lookupNamespaceURI(prefix);
/*      */       case 6:
/*      */       case 10:
/*      */       case 11:
/*      */       case 12:
/*  741 */         return null;
/*      */       case 2:
/*  743 */         owner = (AbstractNode)((Attr)this).getOwnerElement();
/*      */         
/*  745 */         if (owner != null) {
/*  746 */           return owner.lookupNamespaceURI(prefix);
/*      */         }
/*  748 */         return null;
/*      */ 
/*      */ 
/*      */ 
/*      */       
/*      */       case 1:
/*  754 */         nnm = getAttributes();
/*  755 */         if (nnm != null) {
/*  756 */           for (int i = 0; i < nnm.getLength(); i++) {
/*  757 */             Node attr = nnm.item(i);
/*  758 */             String attrPrefix = attr.getPrefix();
/*  759 */             String localName = attr.getLocalName();
/*  760 */             if (localName == null) {
/*  761 */               localName = attr.getNodeName();
/*      */             }
/*  763 */             if (("xmlns".equals(attrPrefix) && compareStrings(localName, prefix)) || ("xmlns".equals(localName) && prefix == null)) {
/*      */ 
/*      */ 
/*      */               
/*  767 */               String value = attr.getNodeValue();
/*  768 */               if (value.length() > 0) {
/*  769 */                 return value;
/*      */               }
/*  771 */               return null;
/*      */             } 
/*      */           } 
/*      */         }
/*      */         break;
/*      */     } 
/*  777 */     for (Node n = getParentNode(); n != null; n = n.getParentNode()) {
/*  778 */       if (n.getNodeType() == 1) {
/*  779 */         AbstractNode an = (AbstractNode)n;
/*  780 */         return an.lookupNamespaceURI(prefix);
/*      */       } 
/*      */     } 
/*  783 */     return null;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public boolean isEqualNode(Node other) {
/*  791 */     if (other == null) {
/*  792 */       return false;
/*      */     }
/*  794 */     int nt = other.getNodeType();
/*  795 */     if (nt != getNodeType() || !compareStrings(getNodeName(), other.getNodeName()) || !compareStrings(getLocalName(), other.getLocalName()) || !compareStrings(getPrefix(), other.getPrefix()) || !compareStrings(getNodeValue(), other.getNodeValue()) || !compareStrings(getNodeValue(), other.getNodeValue()) || !compareNamedNodeMaps(getAttributes(), other.getAttributes()))
/*      */     {
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */       
/*  803 */       return false;
/*      */     }
/*  805 */     if (nt == 10) {
/*  806 */       DocumentType dt1 = (DocumentType)this;
/*  807 */       DocumentType dt2 = (DocumentType)other;
/*  808 */       if (!compareStrings(dt1.getPublicId(), dt2.getPublicId()) || !compareStrings(dt1.getSystemId(), dt2.getSystemId()) || !compareStrings(dt1.getInternalSubset(), dt2.getInternalSubset()) || !compareNamedNodeMaps(dt1.getEntities(), dt2.getEntities()) || !compareNamedNodeMaps(dt1.getNotations(), dt2.getNotations()))
/*      */       {
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */         
/*  816 */         return false;
/*      */       }
/*      */     } 
/*  819 */     Node n = getFirstChild();
/*  820 */     Node m = other.getFirstChild();
/*  821 */     if (n != null && m != null && 
/*  822 */       !((AbstractNode)n).isEqualNode(m)) {
/*  823 */       return false;
/*      */     }
/*      */     
/*  826 */     return (n == m);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  833 */   protected boolean compareStrings(String s1, String s2) { return ((s1 != null && s1.equals(s2)) || (s1 == null && s2 == null)); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected boolean compareNamedNodeMaps(NamedNodeMap nnm1, NamedNodeMap nnm2) {
/*  841 */     if ((nnm1 == null && nnm2 != null) || (nnm1 != null && nnm2 == null))
/*      */     {
/*  843 */       return false;
/*      */     }
/*  845 */     if (nnm1 != null) {
/*  846 */       int len = nnm1.getLength();
/*  847 */       if (len != nnm2.getLength()) {
/*  848 */         return false;
/*      */       }
/*  850 */       for (int i = 0; i < len; i++) {
/*  851 */         Node node, n1 = nnm1.item(i);
/*  852 */         String n1ln = n1.getLocalName();
/*      */         
/*  854 */         if (n1ln != null) {
/*  855 */           node = nnm2.getNamedItemNS(n1.getNamespaceURI(), n1ln);
/*      */         } else {
/*  857 */           node = nnm2.getNamedItem(n1.getNodeName());
/*      */         } 
/*  859 */         if (!((AbstractNode)n1).isEqualNode(node)) {
/*  860 */           return false;
/*      */         }
/*      */       } 
/*      */     } 
/*  864 */     return true;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  872 */   public Object getFeature(String feature, String version) { return null; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public Object getUserData(String key) {
/*  879 */     if (this.userData == null) {
/*  880 */       return null;
/*      */     }
/*  882 */     return this.userData.get(key);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public Object setUserData(String key, Object data, UserDataHandler handler) {
/*  890 */     if (this.userData == null) {
/*  891 */       this.userData = new HashMap();
/*  892 */       this.userDataHandlers = new HashMap();
/*      */     } 
/*  894 */     if (data == null) {
/*  895 */       this.userData.remove(key);
/*  896 */       return this.userDataHandlers.remove(key);
/*      */     } 
/*  898 */     this.userDataHandlers.put(key, handler);
/*  899 */     return this.userData.put(key, data);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected void fireUserDataHandlers(short type, Node oldNode, Node newNode) {
/*  908 */     AbstractNode an = (AbstractNode)oldNode;
/*  909 */     if (an.userData != null) {
/*  910 */       Iterator i = an.userData.entrySet().iterator();
/*  911 */       while (i.hasNext()) {
/*  912 */         Map.Entry e = (Map.Entry)i.next();
/*  913 */         UserDataHandler h = (UserDataHandler)an.userDataHandlers.get(e.getKey());
/*      */         
/*  915 */         if (h != null) {
/*  916 */           h.handle(type, (String)e.getKey(), e.getValue(), oldNode, newNode);
/*      */         }
/*      */       } 
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void addEventListener(String type, EventListener listener, boolean useCapture) {
/*  936 */     if (this.eventSupport == null) {
/*  937 */       initializeEventSupport();
/*      */     }
/*  939 */     this.eventSupport.addEventListener(type, listener, useCapture);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void addEventListenerNS(String namespaceURI, String type, EventListener listener, boolean useCapture, Object evtGroup) {
/*  952 */     if (this.eventSupport == null) {
/*  953 */       initializeEventSupport();
/*      */     }
/*  955 */     if (namespaceURI != null && namespaceURI.length() == 0) {
/*  956 */       namespaceURI = null;
/*      */     }
/*  958 */     this.eventSupport.addEventListenerNS(namespaceURI, type, listener, useCapture, evtGroup);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void removeEventListener(String type, EventListener listener, boolean useCapture) {
/*  973 */     if (this.eventSupport != null) {
/*  974 */       this.eventSupport.removeEventListener(type, listener, useCapture);
/*      */     }
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void removeEventListenerNS(String namespaceURI, String type, EventListener listener, boolean useCapture) {
/*  987 */     if (this.eventSupport != null) {
/*  988 */       if (namespaceURI != null && namespaceURI.length() == 0) {
/*  989 */         namespaceURI = null;
/*      */       }
/*  991 */       this.eventSupport.removeEventListenerNS(namespaceURI, type, listener, useCapture);
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/* 1003 */   public NodeEventTarget getParentNodeEventTarget() { return (NodeEventTarget)getXblParentNode(); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public boolean dispatchEvent(Event evt) throws EventException {
/* 1011 */     if (this.eventSupport == null) {
/* 1012 */       initializeEventSupport();
/*      */     }
/* 1014 */     return this.eventSupport.dispatchEvent(this, evt);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/* 1023 */   public boolean willTriggerNS(String namespaceURI, String type) { return true; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public boolean hasEventListenerNS(String namespaceURI, String type) {
/* 1032 */     if (this.eventSupport == null) {
/* 1033 */       return false;
/*      */     }
/* 1035 */     if (namespaceURI != null && namespaceURI.length() == 0) {
/* 1036 */       namespaceURI = null;
/*      */     }
/* 1038 */     return this.eventSupport.hasEventListenerNS(namespaceURI, type);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/* 1045 */   public EventSupport getEventSupport() { return this.eventSupport; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public EventSupport initializeEventSupport() {
/* 1053 */     if (this.eventSupport == null) {
/* 1054 */       AbstractDocument doc = getCurrentDocument();
/* 1055 */       AbstractDOMImplementation di = (AbstractDOMImplementation)doc.getImplementation();
/*      */       
/* 1057 */       this.eventSupport = di.createEventSupport(this);
/* 1058 */       doc.setEventsEnabled(true);
/*      */     } 
/* 1060 */     return this.eventSupport;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void fireDOMNodeInsertedIntoDocumentEvent() {
/* 1067 */     AbstractDocument doc = getCurrentDocument();
/* 1068 */     if (doc.getEventsEnabled()) {
/* 1069 */       DOMMutationEvent ev = (DOMMutationEvent)doc.createEvent("MutationEvents");
/*      */       
/* 1071 */       ev.initMutationEventNS("http://www.w3.org/2001/xml-events", "DOMNodeInsertedIntoDocument", true, false, null, null, null, null, (short)2);
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */       
/* 1080 */       dispatchEvent(ev);
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void fireDOMNodeRemovedFromDocumentEvent() {
/* 1088 */     AbstractDocument doc = getCurrentDocument();
/* 1089 */     if (doc.getEventsEnabled()) {
/* 1090 */       DOMMutationEvent ev = (DOMMutationEvent)doc.createEvent("MutationEvents");
/*      */       
/* 1092 */       ev.initMutationEventNS("http://www.w3.org/2001/xml-events", "DOMNodeRemovedFromDocument", true, false, null, null, null, null, (short)3);
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */       
/* 1101 */       dispatchEvent(ev);
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected void fireDOMCharacterDataModifiedEvent(String oldv, String newv) {
/* 1110 */     AbstractDocument doc = getCurrentDocument();
/* 1111 */     if (doc.getEventsEnabled()) {
/* 1112 */       DOMMutationEvent ev = (DOMMutationEvent)doc.createEvent("MutationEvents");
/*      */       
/* 1114 */       ev.initMutationEventNS("http://www.w3.org/2001/xml-events", "DOMCharacterDataModified", true, false, null, oldv, newv, null, (short)1);
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */       
/* 1123 */       dispatchEvent(ev);
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/* 1131 */   protected AbstractDocument getCurrentDocument() { return this.ownerDocument; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected abstract Node newNode();
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected Node export(Node n, AbstractDocument d) {
/* 1143 */     AbstractNode p = (AbstractNode)n;
/* 1144 */     p.ownerDocument = d;
/* 1145 */     p.setReadonly(false);
/* 1146 */     return n;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected Node deepExport(Node n, AbstractDocument d) {
/* 1153 */     AbstractNode p = (AbstractNode)n;
/* 1154 */     p.ownerDocument = d;
/* 1155 */     p.setReadonly(false);
/* 1156 */     return n;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected Node copyInto(Node n) throws DOMException {
/* 1164 */     AbstractNode an = (AbstractNode)n;
/* 1165 */     an.ownerDocument = this.ownerDocument;
/* 1166 */     return n;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected Node deepCopyInto(Node n) throws DOMException {
/* 1174 */     AbstractNode an = (AbstractNode)n;
/* 1175 */     an.ownerDocument = this.ownerDocument;
/* 1176 */     return n;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/* 1183 */   protected void checkChildType(Node n, boolean replace) { throw createDOMException((short)3, "children.not.allowed", new Object[] { new Integer(getNodeType()), getNodeName() }); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/* 1195 */   public Node getXblParentNode() { return this.ownerDocument.getXBLManager().getXblParentNode(this); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/* 1202 */   public NodeList getXblChildNodes() { return this.ownerDocument.getXBLManager().getXblChildNodes(this); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/* 1210 */   public NodeList getXblScopedChildNodes() { return this.ownerDocument.getXBLManager().getXblScopedChildNodes(this); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/* 1217 */   public Node getXblFirstChild() { return this.ownerDocument.getXBLManager().getXblFirstChild(this); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/* 1224 */   public Node getXblLastChild() { return this.ownerDocument.getXBLManager().getXblLastChild(this); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/* 1232 */   public Node getXblPreviousSibling() { return this.ownerDocument.getXBLManager().getXblPreviousSibling(this); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/* 1240 */   public Node getXblNextSibling() { return this.ownerDocument.getXBLManager().getXblNextSibling(this); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/* 1247 */   public Element getXblFirstElementChild() { return this.ownerDocument.getXBLManager().getXblFirstElementChild(this); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/* 1254 */   public Element getXblLastElementChild() { return this.ownerDocument.getXBLManager().getXblLastElementChild(this); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/* 1262 */   public Element getXblPreviousElementSibling() { return this.ownerDocument.getXBLManager().getXblPreviousElementSibling(this); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/* 1270 */   public Element getXblNextElementSibling() { return this.ownerDocument.getXBLManager().getXblNextElementSibling(this); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/* 1277 */   public Element getXblBoundElement() { return this.ownerDocument.getXBLManager().getXblBoundElement(this); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/* 1284 */   public Element getXblShadowTree() { return this.ownerDocument.getXBLManager().getXblShadowTree(this); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/* 1291 */   public NodeList getXblDefinitions() { return this.ownerDocument.getXBLManager().getXblDefinitions(this); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/* 1300 */   public Object getManagerData() { return this.managerData; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/* 1307 */   public void setManagerData(Object data) { this.managerData = data; }
/*      */   
/*      */   public abstract void setReadonly(boolean paramBoolean);
/*      */   
/*      */   public abstract boolean isReadonly();
/*      */   
/*      */   public abstract short getNodeType();
/*      */   
/*      */   public abstract String getNodeName() throws DOMException;
/*      */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-dom.jar!\org\apache\batik\dom\AbstractNode.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */