/*     */ package org.apache.batik.dom;
/*     */ 
/*     */ import java.util.Iterator;
/*     */ import java.util.LinkedList;
/*     */ import java.util.List;
/*     */ import java.util.ListIterator;
/*     */ import java.util.Locale;
/*     */ import java.util.MissingResourceException;
/*     */ import org.apache.batik.css.engine.CSSContext;
/*     */ import org.apache.batik.css.engine.CSSEngine;
/*     */ import org.apache.batik.css.engine.value.ShorthandManager;
/*     */ import org.apache.batik.css.engine.value.ValueManager;
/*     */ import org.apache.batik.css.parser.ExtendedParser;
/*     */ import org.apache.batik.css.parser.ExtendedParserWrapper;
/*     */ import org.apache.batik.dom.util.DOMUtilities;
/*     */ import org.apache.batik.dom.util.HashTable;
/*     */ import org.apache.batik.i18n.Localizable;
/*     */ import org.apache.batik.i18n.LocalizableSupport;
/*     */ import org.apache.batik.util.DoublyIndexedTable;
/*     */ import org.apache.batik.util.Service;
/*     */ import org.apache.batik.util.XMLResourceDescriptor;
/*     */ import org.w3c.css.sac.Parser;
/*     */ import org.w3c.dom.DOMException;
/*     */ import org.w3c.dom.Document;
/*     */ import org.w3c.dom.Element;
/*     */ import org.w3c.dom.Node;
/*     */ import org.w3c.dom.css.CSSStyleSheet;
/*     */ import org.w3c.dom.css.DOMImplementationCSS;
/*     */ import org.w3c.dom.css.ViewCSS;
/*     */ import org.w3c.dom.stylesheets.StyleSheet;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public abstract class ExtensibleDOMImplementation
/*     */   extends AbstractDOMImplementation
/*     */   implements DOMImplementationCSS, StyleSheetFactory, Localizable
/*     */ {
/*     */   protected DoublyIndexedTable customFactories;
/*     */   protected List customValueManagers;
/*     */   protected List customShorthandManagers;
/*     */   protected static final String RESOURCES = "org.apache.batik.dom.resources.Messages";
/*     */   protected LocalizableSupport localizableSupport;
/*     */   
/*     */   public ExtensibleDOMImplementation() {
/*  93 */     initLocalizable();
/*     */     
/*  95 */     Iterator iter = getDomExtensions().iterator();
/*     */     
/*  97 */     while (iter.hasNext()) {
/*  98 */       DomExtension de = (DomExtension)iter.next();
/*  99 */       de.registerTags(this);
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 109 */   public void setLocale(Locale l) { this.localizableSupport.setLocale(l); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 116 */   public Locale getLocale() { return this.localizableSupport.getLocale(); }
/*     */ 
/*     */ 
/*     */   
/* 120 */   protected void initLocalizable() { this.localizableSupport = new LocalizableSupport("org.apache.batik.dom.resources.Messages", getClass().getClassLoader()); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 129 */   public String formatMessage(String key, Object[] args) throws MissingResourceException { return this.localizableSupport.formatMessage(key, args); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void registerCustomElementFactory(String namespaceURI, String localName, ElementFactory factory) {
/* 138 */     if (this.customFactories == null) {
/* 139 */       this.customFactories = new DoublyIndexedTable();
/*     */     }
/* 141 */     this.customFactories.put(namespaceURI, localName, factory);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void registerCustomCSSValueManager(ValueManager vm) {
/* 148 */     if (this.customValueManagers == null) {
/* 149 */       this.customValueManagers = new LinkedList();
/*     */     }
/* 151 */     this.customValueManagers.add(vm);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void registerCustomCSSShorthandManager(ShorthandManager sm) {
/* 158 */     if (this.customShorthandManagers == null) {
/* 159 */       this.customShorthandManagers = new LinkedList();
/*     */     }
/* 161 */     this.customShorthandManagers.add(sm);
/*     */   }
/*     */ 
/*     */   
/*     */   public CSSEngine createCSSEngine(AbstractStylableDocument doc, CSSContext ctx) {
/*     */     ShorthandManager[] arrayOfShorthandManager;
/*     */     ValueManager[] arrayOfValueManager;
/*     */     Parser p;
/* 169 */     String pn = XMLResourceDescriptor.getCSSParserClassName();
/*     */     
/*     */     try {
/* 172 */       p = (Parser)Class.forName(pn).newInstance();
/*     */     } catch (ClassNotFoundException e) {
/* 174 */       throw new DOMException((short)15, formatMessage("css.parser.class", new Object[] { pn }));
/*     */     }
/*     */     catch (InstantiationException e) {
/*     */       
/* 178 */       throw new DOMException((short)15, formatMessage("css.parser.creation", new Object[] { pn }));
/*     */     }
/*     */     catch (IllegalAccessException e) {
/*     */       
/* 182 */       throw new DOMException((short)15, formatMessage("css.parser.access", new Object[] { pn }));
/*     */     } 
/*     */ 
/*     */     
/* 186 */     ExtendedParser ep = ExtendedParserWrapper.wrap(p);
/*     */ 
/*     */     
/* 189 */     if (this.customValueManagers == null) {
/* 190 */       arrayOfValueManager = new ValueManager[0];
/*     */     } else {
/* 192 */       arrayOfValueManager = new ValueManager[this.customValueManagers.size()];
/* 193 */       arrayOfShorthandManager = this.customValueManagers.iterator();
/* 194 */       int i = 0;
/* 195 */       while (arrayOfShorthandManager.hasNext()) {
/* 196 */         arrayOfValueManager[i++] = (ValueManager)arrayOfShorthandManager.next();
/*     */       }
/*     */     } 
/*     */ 
/*     */     
/* 201 */     if (this.customShorthandManagers == null) {
/* 202 */       arrayOfShorthandManager = new ShorthandManager[0];
/*     */     } else {
/* 204 */       arrayOfShorthandManager = new ShorthandManager[this.customShorthandManagers.size()];
/* 205 */       Iterator it = this.customShorthandManagers.iterator();
/* 206 */       int i = 0;
/* 207 */       while (it.hasNext()) {
/* 208 */         arrayOfShorthandManager[i++] = (ShorthandManager)it.next();
/*     */       }
/*     */     } 
/*     */     
/* 212 */     CSSEngine result = createCSSEngine(doc, ctx, ep, arrayOfValueManager, arrayOfShorthandManager);
/* 213 */     doc.setCSSEngine(result);
/* 214 */     return result;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public Element createElementNS(AbstractDocument document, String namespaceURI, String qualifiedName) {
/* 235 */     if (namespaceURI != null && namespaceURI.length() == 0) {
/* 236 */       namespaceURI = null;
/*     */     }
/* 238 */     if (namespaceURI == null) {
/* 239 */       return new GenericElement(qualifiedName.intern(), document);
/*     */     }
/* 241 */     if (this.customFactories != null) {
/* 242 */       String name = DOMUtilities.getLocalName(qualifiedName);
/*     */       
/* 244 */       ElementFactory cef = (ElementFactory)this.customFactories.get(namespaceURI, name);
/* 245 */       if (cef != null) {
/* 246 */         return cef.create(DOMUtilities.getPrefix(qualifiedName), document);
/*     */       }
/*     */     } 
/*     */     
/* 250 */     return new GenericElementNS(namespaceURI.intern(), qualifiedName.intern(), document);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 269 */   protected static List extensions = null;
/*     */   
/*     */   protected static List getDomExtensions() {
/* 272 */     if (extensions != null) {
/* 273 */       return extensions;
/*     */     }
/* 275 */     extensions = new LinkedList();
/*     */     
/* 277 */     iter = Service.providers(DomExtension.class);
/*     */     
/* 279 */     while (iter.hasNext()) {
/* 280 */       DomExtension de = (DomExtension)iter.next();
/* 281 */       float priority = de.getPriority();
/* 282 */       ListIterator li = extensions.listIterator();
/*     */       while (true) {
/* 284 */         if (!li.hasNext()) {
/* 285 */           li.add(de);
/*     */           break;
/*     */         } 
/* 288 */         DomExtension lde = (DomExtension)li.next();
/* 289 */         if (lde.getPriority() > priority) {
/* 290 */           li.previous();
/* 291 */           li.add(de);
/*     */         } 
/*     */       } 
/*     */     } 
/*     */ 
/*     */     
/* 297 */     return extensions;
/*     */   }
/*     */   
/*     */   public abstract CSSEngine createCSSEngine(AbstractStylableDocument paramAbstractStylableDocument, CSSContext paramCSSContext, ExtendedParser paramExtendedParser, ValueManager[] paramArrayOfValueManager, ShorthandManager[] paramArrayOfShorthandManager);
/*     */   
/*     */   public abstract ViewCSS createViewCSS(AbstractStylableDocument paramAbstractStylableDocument);
/*     */   
/*     */   public abstract CSSStyleSheet createCSSStyleSheet(String paramString1, String paramString2) throws DOMException;
/*     */   
/*     */   public abstract StyleSheet createStyleSheet(Node paramNode, HashTable paramHashTable);
/*     */   
/*     */   public static interface ElementFactory {
/*     */     Element create(String param1String, Document param1Document);
/*     */   }
/*     */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-dom.jar!\org\apache\batik\dom\ExtensibleDOMImplementation.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */