/*     */ package org.apache.batik.dom.events;
/*     */ 
/*     */ import org.apache.batik.dom.util.HashTable;
/*     */ import org.w3c.dom.DOMException;
/*     */ import org.w3c.dom.events.Event;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class DocumentEventSupport
/*     */ {
/*     */   public static final String EVENT_TYPE = "Event";
/*     */   public static final String MUTATION_EVENT_TYPE = "MutationEvent";
/*     */   public static final String MUTATION_NAME_EVENT_TYPE = "MutationNameEvent";
/*     */   public static final String MOUSE_EVENT_TYPE = "MouseEvent";
/*     */   public static final String UI_EVENT_TYPE = "UIEvent";
/*     */   public static final String KEYBOARD_EVENT_TYPE = "KeyboardEvent";
/*     */   public static final String TEXT_EVENT_TYPE = "TextEvent";
/*     */   public static final String CUSTOM_EVENT_TYPE = "CustomEvent";
/*     */   public static final String EVENT_DOM2_TYPE = "Events";
/*     */   public static final String MUTATION_EVENT_DOM2_TYPE = "MutationEvents";
/*     */   public static final String MOUSE_EVENT_DOM2_TYPE = "MouseEvents";
/*     */   public static final String UI_EVENT_DOM2_TYPE = "UIEvents";
/*     */   public static final String KEY_EVENT_DOM2_TYPE = "KeyEvents";
/*     */   protected HashTable eventFactories;
/*     */   
/*     */   public DocumentEventSupport() {
/* 101 */     this.eventFactories = new HashTable();
/*     */ 
/*     */     
/* 104 */     this.eventFactories.put("Event".toLowerCase(), new SimpleEventFactory());
/*     */     
/* 106 */     this.eventFactories.put("MutationEvent".toLowerCase(), new MutationEventFactory());
/*     */     
/* 108 */     this.eventFactories.put("MutationNameEvent".toLowerCase(), new MutationNameEventFactory());
/*     */     
/* 110 */     this.eventFactories.put("MouseEvent".toLowerCase(), new MouseEventFactory());
/*     */     
/* 112 */     this.eventFactories.put("KeyboardEvent".toLowerCase(), new KeyboardEventFactory());
/*     */     
/* 114 */     this.eventFactories.put("UIEvent".toLowerCase(), new UIEventFactory());
/*     */     
/* 116 */     this.eventFactories.put("TextEvent".toLowerCase(), new TextEventFactory());
/*     */     
/* 118 */     this.eventFactories.put("CustomEvent".toLowerCase(), new CustomEventFactory());
/*     */ 
/*     */     
/* 121 */     this.eventFactories.put("Events".toLowerCase(), new SimpleEventFactory());
/*     */     
/* 123 */     this.eventFactories.put("MutationEvents".toLowerCase(), new MutationEventFactory());
/*     */     
/* 125 */     this.eventFactories.put("MouseEvents".toLowerCase(), new MouseEventFactory());
/*     */     
/* 127 */     this.eventFactories.put("KeyEvents".toLowerCase(), new KeyEventFactory());
/*     */     
/* 129 */     this.eventFactories.put("UIEvents".toLowerCase(), new UIEventFactory());
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public Event createEvent(String eventType) throws DOMException {
/* 164 */     EventFactory ef = (EventFactory)this.eventFactories.get(eventType.toLowerCase());
/* 165 */     if (ef == null) {
/* 166 */       throw new DOMException((short)9, "Bad event type: " + eventType);
/*     */     }
/*     */     
/* 169 */     return ef.createEvent();
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 177 */   public void registerEventFactory(String eventType, EventFactory factory) { this.eventFactories.put(eventType.toLowerCase(), factory); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public static interface EventFactory
/*     */   {
/*     */     Event createEvent();
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected static class SimpleEventFactory
/*     */     implements EventFactory
/*     */   {
/* 199 */     public Event createEvent() { return new DOMEvent(); }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected static class MutationEventFactory
/*     */     implements EventFactory
/*     */   {
/* 211 */     public Event createEvent() { return new DOMMutationEvent(); }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected static class MutationNameEventFactory
/*     */     implements EventFactory
/*     */   {
/* 223 */     public Event createEvent() { return new DOMMutationNameEvent(); }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected static class MouseEventFactory
/*     */     implements EventFactory
/*     */   {
/* 235 */     public Event createEvent() { return new DOMMouseEvent(); }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected static class KeyEventFactory
/*     */     implements EventFactory
/*     */   {
/* 247 */     public Event createEvent() { return new DOMKeyEvent(); }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected static class KeyboardEventFactory
/*     */     implements EventFactory
/*     */   {
/* 259 */     public Event createEvent() { return new DOMKeyboardEvent(); }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected static class UIEventFactory
/*     */     implements EventFactory
/*     */   {
/* 271 */     public Event createEvent() { return new DOMUIEvent(); }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected static class TextEventFactory
/*     */     implements EventFactory
/*     */   {
/* 283 */     public Event createEvent() { return new DOMTextEvent(); }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected static class CustomEventFactory
/*     */     implements EventFactory
/*     */   {
/* 295 */     public Event createEvent() { return new DOMCustomEvent(); }
/*     */   }
/*     */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-dom.jar!\org\apache\batik\dom\events\DocumentEventSupport.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */