/*     */ package org.apache.batik.dom.events;
/*     */ 
/*     */ import org.apache.batik.dom.util.HashTable;
/*     */ import org.apache.batik.dom.util.IntTable;
/*     */ import org.w3c.dom.events.EventListener;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class EventListenerList
/*     */ {
/*     */   protected int n;
/*     */   protected Entry head;
/*  48 */   protected IntTable counts = new IntTable();
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected Entry[] listeners;
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  58 */   protected HashTable listenersNS = new HashTable();
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void addListener(String namespaceURI, Object group, EventListener listener) {
/*  66 */     for (Entry e = this.head; e != null; e = e.next) {
/*  67 */       if (((namespaceURI != null && namespaceURI.equals(e.namespaceURI)) || (namespaceURI == null && e.namespaceURI == null)) && e.listener == listener) {
/*     */         return;
/*     */       }
/*     */     } 
/*     */ 
/*     */ 
/*     */     
/*  74 */     this.head = new Entry(this, listener, namespaceURI, group, this.head);
/*  75 */     this.counts.inc(namespaceURI);
/*  76 */     this.n++;
/*  77 */     this.listeners = null;
/*  78 */     this.listenersNS.remove(namespaceURI);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void removeListener(String namespaceURI, EventListener listener) {
/*  86 */     if (this.head == null)
/*     */       return; 
/*  88 */     if (this.head != null && ((namespaceURI != null && namespaceURI.equals(this.head.namespaceURI)) || (namespaceURI == null && this.head.namespaceURI == null)) && listener == this.head.listener) {
/*     */ 
/*     */ 
/*     */       
/*  92 */       this.head = this.head.next;
/*     */     } else {
/*     */       
/*  95 */       Entry prev = this.head;
/*  96 */       for (Entry e = this.head.next; e != null; e = e.next) {
/*  97 */         if (((namespaceURI != null && namespaceURI.equals(e.namespaceURI)) || (namespaceURI == null && e.namespaceURI == null)) && e.listener == listener) {
/*     */ 
/*     */           
/* 100 */           prev.next = e.next;
/*     */           break;
/*     */         } 
/* 103 */         prev = e;
/*     */       } 
/* 105 */       if (e == null) {
/*     */         return;
/*     */       }
/*     */     } 
/*     */     
/* 110 */     this.counts.dec(namespaceURI);
/* 111 */     this.n--;
/* 112 */     this.listeners = null;
/* 113 */     this.listenersNS.remove(namespaceURI);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public Entry[] getEventListeners() {
/* 120 */     if (this.listeners != null) {
/* 121 */       return this.listeners;
/*     */     }
/* 123 */     this.listeners = new Entry[this.n];
/* 124 */     int i = 0;
/* 125 */     for (Entry e = this.head; e != null; e = e.next) {
/* 126 */       this.listeners[i++] = e;
/*     */     }
/* 128 */     return this.listeners;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public Entry[] getEventListeners(String namespaceURI) {
/* 135 */     if (namespaceURI == null) {
/* 136 */       return getEventListeners();
/*     */     }
/* 138 */     Entry[] ls = (Entry[])this.listenersNS.get(namespaceURI);
/* 139 */     if (ls != null) {
/* 140 */       return ls;
/*     */     }
/* 142 */     int count = this.counts.get(namespaceURI);
/* 143 */     if (count == 0) {
/* 144 */       return null;
/*     */     }
/* 146 */     Entry[] arrayOfEntry = new Entry[count];
/* 147 */     this.listenersNS.put(namespaceURI, arrayOfEntry);
/* 148 */     int i = 0;
/* 149 */     for (Entry e = this.head; i < count; e = e.next) {
/* 150 */       if (namespaceURI.equals(e.namespaceURI)) {
/* 151 */         arrayOfEntry[i++] = e;
/*     */       }
/*     */     } 
/* 154 */     return arrayOfEntry;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public boolean hasEventListener(String namespaceURI) {
/* 161 */     if (namespaceURI == null) {
/* 162 */       return (this.n != 0);
/*     */     }
/* 164 */     return (this.counts.get(namespaceURI) != 0);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 171 */   public int size() { return this.n; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public class Entry
/*     */   {
/*     */     protected EventListener listener;
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected String namespaceURI;
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected Object group;
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected boolean mark;
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected Entry next;
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     private final EventListenerList this$0;
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public Entry(EventListenerList this$0, EventListener listener, String namespaceURI, Object group, Entry next) {
/* 210 */       this.this$0 = this$0;
/* 211 */       this.listener = listener;
/* 212 */       this.namespaceURI = namespaceURI;
/* 213 */       this.group = group;
/* 214 */       this.next = next;
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 221 */     public EventListener getListener() { return this.listener; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 228 */     public Object getGroup() { return this.group; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 235 */     public String getNamespaceURI() { return this.namespaceURI; }
/*     */   }
/*     */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-dom.jar!\org\apache\batik\dom\events\EventListenerList.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */