/*     */ package org.apache.batik.dom.events;
/*     */ 
/*     */ import java.util.HashSet;
/*     */ import java.util.Iterator;
/*     */ import java.util.List;
/*     */ import org.apache.batik.dom.AbstractDocument;
/*     */ import org.apache.batik.dom.AbstractNode;
/*     */ import org.apache.batik.dom.util.HashTable;
/*     */ import org.w3c.dom.events.Event;
/*     */ import org.w3c.dom.events.EventException;
/*     */ import org.w3c.dom.events.EventListener;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class EventSupport
/*     */ {
/*     */   protected HashTable capturingListeners;
/*     */   protected HashTable bubblingListeners;
/*     */   protected AbstractNode node;
/*     */   
/*  66 */   public EventSupport(AbstractNode n) { this.node = n; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  98 */   public void addEventListener(String type, EventListener listener, boolean useCapture) { addEventListenerNS(null, type, listener, useCapture, null); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void addEventListenerNS(String namespaceURI, String type, EventListener listener, boolean useCapture, Object group) {
/*     */     HashTable hashTable;
/* 111 */     if (useCapture) {
/* 112 */       if (this.capturingListeners == null) {
/* 113 */         this.capturingListeners = new HashTable();
/*     */       }
/* 115 */       hashTable = this.capturingListeners;
/*     */     } else {
/* 117 */       if (this.bubblingListeners == null) {
/* 118 */         this.bubblingListeners = new HashTable();
/*     */       }
/* 120 */       hashTable = this.bubblingListeners;
/*     */     } 
/* 122 */     EventListenerList list = (EventListenerList)hashTable.get(type);
/* 123 */     if (list == null) {
/* 124 */       list = new EventListenerList();
/* 125 */       hashTable.put(type, list);
/*     */     } 
/* 127 */     list.addListener(namespaceURI, group, listener);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 159 */   public void removeEventListener(String type, EventListener listener, boolean useCapture) { removeEventListenerNS(null, type, listener, useCapture); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void removeEventListenerNS(String namespaceURI, String type, EventListener listener, boolean useCapture) {
/*     */     HashTable hashTable;
/* 170 */     if (useCapture) {
/* 171 */       hashTable = this.capturingListeners;
/*     */     } else {
/* 173 */       hashTable = this.bubblingListeners;
/*     */     } 
/* 175 */     if (hashTable == null) {
/*     */       return;
/*     */     }
/* 178 */     EventListenerList list = (EventListenerList)hashTable.get(type);
/* 179 */     if (list != null) {
/* 180 */       list.removeListener(namespaceURI, listener);
/* 181 */       if (list.size() == 0) {
/* 182 */         hashTable.remove(type);
/*     */       }
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void moveEventListeners(EventSupport other) {
/* 194 */     other.capturingListeners = this.capturingListeners;
/* 195 */     other.bubblingListeners = this.bubblingListeners;
/* 196 */     this.capturingListeners = null;
/* 197 */     this.bubblingListeners = null;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public boolean dispatchEvent(NodeEventTarget target, Event evt) throws EventException {
/* 228 */     if (evt == null) {
/* 229 */       return false;
/*     */     }
/* 231 */     if (!(evt instanceof AbstractEvent)) {
/* 232 */       throw createEventException((short)9, "unsupported.event", new Object[0]);
/*     */     }
/*     */ 
/*     */     
/* 236 */     AbstractEvent e = (AbstractEvent)evt;
/* 237 */     String type = e.getType();
/* 238 */     if (type == null || type.length() == 0) {
/* 239 */       throw createEventException((short)0, "unspecified.event", new Object[0]);
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 245 */     e.setTarget(target);
/* 246 */     e.stopPropagation(false);
/* 247 */     e.stopImmediatePropagation(false);
/* 248 */     e.preventDefault(false);
/*     */     
/* 250 */     NodeEventTarget[] ancestors = getAncestors(target);
/*     */     
/* 252 */     e.setEventPhase((short)1);
/* 253 */     HashSet stoppedGroups = new HashSet();
/* 254 */     HashSet toBeStoppedGroups = new HashSet();
/* 255 */     for (int i = 0; i < ancestors.length; i++) {
/* 256 */       NodeEventTarget node = ancestors[i];
/* 257 */       e.setCurrentTarget(node);
/* 258 */       fireEventListeners(node, e, true, stoppedGroups, toBeStoppedGroups);
/*     */       
/* 260 */       stoppedGroups.addAll(toBeStoppedGroups);
/* 261 */       toBeStoppedGroups.clear();
/*     */     } 
/*     */     
/* 264 */     e.setEventPhase((short)2);
/* 265 */     e.setCurrentTarget(target);
/* 266 */     fireEventListeners(target, e, false, stoppedGroups, toBeStoppedGroups);
/*     */     
/* 268 */     stoppedGroups.addAll(toBeStoppedGroups);
/* 269 */     toBeStoppedGroups.clear();
/*     */     
/* 271 */     if (e.getBubbles()) {
/* 272 */       e.setEventPhase((short)3);
/* 273 */       for (int i = ancestors.length - 1; i >= 0; i--) {
/* 274 */         NodeEventTarget node = ancestors[i];
/* 275 */         e.setCurrentTarget(node);
/* 276 */         fireEventListeners(node, e, false, stoppedGroups, toBeStoppedGroups);
/*     */         
/* 278 */         stoppedGroups.addAll(toBeStoppedGroups);
/* 279 */         toBeStoppedGroups.clear();
/*     */       } 
/*     */     } 
/* 282 */     if (!e.getDefaultPrevented()) {
/* 283 */       runDefaultActions(e);
/*     */     }
/* 285 */     return e.getDefaultPrevented();
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected void runDefaultActions(AbstractEvent e) {
/* 292 */     List runables = e.getDefaultActions();
/* 293 */     if (runables != null) {
/* 294 */       Iterator i = runables.iterator();
/* 295 */       while (i.hasNext()) {
/* 296 */         Runnable r = (Runnable)i.next();
/* 297 */         r.run();
/*     */       } 
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected void fireEventListeners(NodeEventTarget node, AbstractEvent e, Entry[] listeners, HashSet stoppedGroups, HashSet toBeStoppedGroups) {
/* 310 */     if (listeners == null) {
/*     */       return;
/*     */     }
/*     */     
/* 314 */     String eventNS = e.getNamespaceURI();
/* 315 */     for (int i = 0; i < listeners.length; i++) {
/*     */       
/* 317 */       try { String listenerNS = listeners[i].getNamespaceURI();
/* 318 */         if (listenerNS == null || eventNS == null || listenerNS.equals(eventNS)) {
/*     */ 
/*     */ 
/*     */           
/* 322 */           Object group = listeners[i].getGroup();
/* 323 */           if (stoppedGroups == null || !stoppedGroups.contains(group)) {
/* 324 */             listeners[i].getListener().handleEvent(e);
/* 325 */             if (e.getStopImmediatePropagation()) {
/* 326 */               if (stoppedGroups != null) {
/* 327 */                 stoppedGroups.add(group);
/*     */               }
/* 329 */               e.stopImmediatePropagation(false);
/* 330 */             } else if (e.getStopPropagation()) {
/* 331 */               if (toBeStoppedGroups != null) {
/* 332 */                 toBeStoppedGroups.add(group);
/*     */               }
/* 334 */               e.stopPropagation(false);
/*     */             } 
/*     */           } 
/*     */         }  }
/* 338 */       catch (ThreadDeath td) { throw td; }
/*     */       catch (Throwable th)
/* 340 */       { th.printStackTrace(); }
/*     */     
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected void fireEventListeners(NodeEventTarget node, AbstractEvent e, boolean useCapture, HashSet stoppedGroups, HashSet toBeStoppedGroups) {
/* 353 */     String type = e.getType();
/* 354 */     EventSupport support = node.getEventSupport();
/*     */     
/* 356 */     if (support == null) {
/*     */       return;
/*     */     }
/* 359 */     EventListenerList list = support.getEventListeners(type, useCapture);
/*     */     
/* 361 */     if (list == null) {
/*     */       return;
/*     */     }
/*     */     
/* 365 */     EventListenerList.Entry[] arrayOfEntry = list.getEventListeners();
/* 366 */     fireEventListeners(node, e, arrayOfEntry, stoppedGroups, toBeStoppedGroups);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected NodeEventTarget[] getAncestors(NodeEventTarget node) {
/* 374 */     node = node.getParentNodeEventTarget();
/* 375 */     int nancestors = 0;
/* 376 */     NodeEventTarget n = node;
/* 377 */     while (n != null) {
/* 378 */       n = n.getParentNodeEventTarget(); nancestors++;
/*     */     } 
/* 380 */     NodeEventTarget[] ancestors = new NodeEventTarget[nancestors];
/* 381 */     int i = nancestors - 1;
/* 382 */     for (; i >= 0; 
/* 383 */       i--, node = node.getParentNodeEventTarget()) {
/* 384 */       ancestors[i] = node;
/*     */     }
/* 386 */     return ancestors;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public boolean hasEventListenerNS(String namespaceURI, String type) {
/* 394 */     if (this.capturingListeners != null) {
/* 395 */       EventListenerList ell = (EventListenerList)this.capturingListeners.get(type);
/*     */       
/* 397 */       if (ell != null && 
/* 398 */         ell.hasEventListener(namespaceURI)) {
/* 399 */         return true;
/*     */       }
/*     */     } 
/*     */     
/* 403 */     if (this.bubblingListeners != null) {
/* 404 */       EventListenerList ell = (EventListenerList)this.capturingListeners.get(type);
/*     */       
/* 406 */       if (ell != null) {
/* 407 */         return ell.hasEventListener(namespaceURI);
/*     */       }
/*     */     } 
/* 410 */     return false;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public EventListenerList getEventListeners(String type, boolean useCapture) {
/* 421 */     HashTable listeners = useCapture ? this.capturingListeners : this.bubblingListeners;
/*     */     
/* 423 */     if (listeners == null) {
/* 424 */       return null;
/*     */     }
/* 426 */     return (EventListenerList)listeners.get(type);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected EventException createEventException(short code, String key, Object[] args) {
/*     */     try {
/* 440 */       AbstractDocument doc = (AbstractDocument)this.node.getOwnerDocument();
/* 441 */       return new EventException(code, doc.formatMessage(key, args));
/*     */     } catch (Exception e) {
/* 443 */       return new EventException(code, key);
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 451 */   protected void setTarget(AbstractEvent e, NodeEventTarget target) { e.setTarget(target); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 458 */   protected void stopPropagation(AbstractEvent e, boolean b) { e.stopPropagation(b); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 465 */   protected void stopImmediatePropagation(AbstractEvent e, boolean b) { e.stopImmediatePropagation(b); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 472 */   protected void preventDefault(AbstractEvent e, boolean b) { e.preventDefault(b); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 479 */   protected void setCurrentTarget(AbstractEvent e, NodeEventTarget target) { e.setCurrentTarget(target); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 486 */   protected void setEventPhase(AbstractEvent e, short phase) { e.setEventPhase(phase); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public static Event getUltimateOriginalEvent(Event evt) {
/* 493 */     AbstractEvent e = (AbstractEvent)evt;
/*     */     while (true) {
/* 495 */       AbstractEvent origEvt = (AbstractEvent)e.getOriginalEvent();
/* 496 */       if (origEvt == null) {
/*     */         break;
/*     */       }
/* 499 */       e = origEvt;
/*     */     } 
/* 501 */     return e;
/*     */   }
/*     */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-dom.jar!\org\apache\batik\dom\events\EventSupport.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */