/*     */ package org.apache.batik.dom.util;
/*     */ 
/*     */ import java.io.IOException;
/*     */ import java.io.StringReader;
/*     */ import java.io.StringWriter;
/*     */ import java.io.Writer;
/*     */ import java.util.ArrayList;
/*     */ import java.util.Iterator;
/*     */ import java.util.Map;
/*     */ import java.util.Set;
/*     */ import org.apache.batik.xml.XMLCharacters;
/*     */ import org.apache.batik.xml.XMLUtilities;
/*     */ import org.w3c.dom.Attr;
/*     */ import org.w3c.dom.DOMException;
/*     */ import org.w3c.dom.DOMImplementation;
/*     */ import org.w3c.dom.Document;
/*     */ import org.w3c.dom.DocumentType;
/*     */ import org.w3c.dom.Element;
/*     */ import org.w3c.dom.NamedNodeMap;
/*     */ import org.w3c.dom.Node;
/*     */ import org.w3c.dom.NodeList;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class DOMUtilities
/*     */   extends XMLUtilities
/*     */ {
/*     */   public static void writeDocument(Document doc, Writer w) throws IOException {
/*  59 */     Node n = doc.getFirstChild();
/*  60 */     for (; n != null; 
/*  61 */       n = n.getNextSibling()) {
/*  62 */       writeNode(n, w);
/*     */     }
/*     */   }
/*     */   
/*     */   public static void writeNode(Node n, Writer w) throws IOException {
/*     */     String pubID;
/*     */     DocumentType dt;
/*     */     Node c;
/*  70 */     switch (n.getNodeType()) {
/*     */       case 1:
/*  72 */         w.write("<");
/*  73 */         w.write(n.getNodeName());
/*     */         
/*  75 */         if (n.hasAttributes()) {
/*  76 */           NamedNodeMap attr = n.getAttributes();
/*  77 */           int len = attr.getLength();
/*  78 */           for (int i = 0; i < len; i++) {
/*  79 */             Attr a = (Attr)attr.item(i);
/*  80 */             w.write(" ");
/*  81 */             w.write(a.getNodeName());
/*  82 */             w.write("=\"");
/*  83 */             w.write(contentToString(a.getNodeValue()));
/*  84 */             w.write("\"");
/*     */           } 
/*     */         } 
/*     */         
/*  88 */         c = n.getFirstChild();
/*  89 */         if (c != null) {
/*  90 */           w.write(">");
/*  91 */           for (; c != null; 
/*  92 */             c = c.getNextSibling()) {
/*  93 */             writeNode(c, w);
/*     */           }
/*  95 */           w.write("</");
/*  96 */           w.write(n.getNodeName());
/*  97 */           w.write(">");
/*     */         } else {
/*  99 */           w.write("/>");
/*     */         } 
/*     */         return;
/*     */       case 3:
/* 103 */         w.write(contentToString(n.getNodeValue()));
/*     */         return;
/*     */       case 4:
/* 106 */         w.write("<![CDATA[");
/* 107 */         w.write(n.getNodeValue());
/* 108 */         w.write("]]>");
/*     */         return;
/*     */       case 5:
/* 111 */         w.write("&");
/* 112 */         w.write(n.getNodeName());
/* 113 */         w.write(";");
/*     */         return;
/*     */       case 7:
/* 116 */         w.write("<?");
/* 117 */         w.write(n.getNodeName());
/*     */         
/* 119 */         w.write(" ");
/* 120 */         w.write(n.getNodeValue());
/* 121 */         w.write("?>");
/*     */         return;
/*     */       case 8:
/* 124 */         w.write("<!--");
/* 125 */         w.write(n.getNodeValue());
/* 126 */         w.write("-->");
/*     */         return;
/*     */       case 10:
/* 129 */         dt = (DocumentType)n;
/* 130 */         w.write("<!DOCTYPE ");
/* 131 */         w.write(n.getOwnerDocument().getDocumentElement().getNodeName());
/* 132 */         pubID = dt.getPublicId();
/* 133 */         if (pubID != null) {
/* 134 */           w.write(" PUBLIC \"" + dt.getNodeName() + "\" \"" + pubID + "\">");
/*     */         } else {
/*     */           
/* 137 */           String sysID = dt.getSystemId();
/* 138 */           if (sysID != null) {
/* 139 */             w.write(" SYSTEM \"" + sysID + "\">");
/*     */           }
/*     */         } 
/*     */         return;
/*     */     } 
/* 144 */     throw new IOException("Unknown DOM node type " + n.getNodeType());
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public static String getXML(Node n) {
/* 157 */     Writer writer = new StringWriter();
/*     */     try {
/* 159 */       writeNode(n, writer);
/* 160 */       writer.close();
/*     */     } catch (IOException ex) {
/* 162 */       return "";
/*     */     } 
/* 164 */     return writer.toString();
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public static String contentToString(String s) {
/* 172 */     StringBuffer result = new StringBuffer(s.length());
/*     */     
/* 174 */     for (int i = 0; i < s.length(); i++) {
/* 175 */       char c = s.charAt(i);
/*     */       
/* 177 */       switch (c) {
/*     */         case '<':
/* 179 */           result.append("&lt;");
/*     */           break;
/*     */         case '>':
/* 182 */           result.append("&gt;");
/*     */           break;
/*     */         case '&':
/* 185 */           result.append("&amp;");
/*     */           break;
/*     */         case '"':
/* 188 */           result.append("&quot;");
/*     */           break;
/*     */         case '\'':
/* 191 */           result.append("&apos;");
/*     */           break;
/*     */         default:
/* 194 */           result.append(c);
/*     */           break;
/*     */       } 
/*     */     } 
/* 198 */     return result.toString();
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public static int getChildIndex(Node child, Node parent) {
/* 212 */     if (child == null || child.getParentNode() != parent || child.getParentNode() == null)
/*     */     {
/* 214 */       return -1;
/*     */     }
/* 216 */     return getChildIndex(child);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public static int getChildIndex(Node child) {
/* 227 */     NodeList children = child.getParentNode().getChildNodes();
/* 228 */     for (int i = 0; i < children.getLength(); i++) {
/* 229 */       Node currentChild = children.item(i);
/* 230 */       if (currentChild == child) {
/* 231 */         return i;
/*     */       }
/*     */     } 
/* 234 */     return -1;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public static boolean isAnyNodeAncestorOf(ArrayList ancestorNodes, Node node) {
/* 248 */     int n = ancestorNodes.size();
/* 249 */     for (int i = 0; i < n; i++) {
/* 250 */       Node ancestor = (Node)ancestorNodes.get(i);
/* 251 */       if (isAncestorOf(ancestor, node)) {
/* 252 */         return true;
/*     */       }
/*     */     } 
/* 255 */     return false;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public static boolean isAncestorOf(Node node, Node descendant) {
/* 268 */     if (node == null || descendant == null) {
/* 269 */       return false;
/*     */     }
/* 271 */     for (Node currentNode = descendant.getParentNode(); currentNode != null; currentNode = currentNode.getParentNode()) {
/*     */       
/* 273 */       if (currentNode == node) {
/* 274 */         return true;
/*     */       }
/*     */     } 
/* 277 */     return false;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public static boolean isParentOf(Node node, Node parentNode) {
/* 290 */     if (node == null || parentNode == null || node.getParentNode() != parentNode)
/*     */     {
/* 292 */       return false;
/*     */     }
/* 294 */     return true;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public static boolean canAppend(Node node, Node parentNode) {
/* 307 */     if (node == null || parentNode == null || node == parentNode || isAncestorOf(node, parentNode))
/*     */     {
/* 309 */       return false;
/*     */     }
/* 311 */     return true;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public static boolean canAppendAny(ArrayList children, Node parentNode) {
/* 325 */     if (!canHaveChildren(parentNode)) {
/* 326 */       return false;
/*     */     }
/* 328 */     int n = children.size();
/* 329 */     for (int i = 0; i < n; i++) {
/* 330 */       Node child = (Node)children.get(i);
/* 331 */       if (canAppend(child, parentNode)) {
/* 332 */         return true;
/*     */       }
/*     */     } 
/* 335 */     return false;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public static boolean canHaveChildren(Node parentNode) {
/* 346 */     if (parentNode == null) {
/* 347 */       return false;
/*     */     }
/* 349 */     switch (parentNode.getNodeType()) {
/*     */       case 3:
/*     */       case 4:
/*     */       case 7:
/*     */       case 8:
/*     */       case 9:
/* 355 */         return false;
/*     */     } 
/* 357 */     return true;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public static Node parseXML(String text, Document doc, String uri, Map prefixes, String wrapperElementName, SAXDocumentFactory documentFactory) {
/* 388 */     String wrapperElementPrefix = "";
/* 389 */     String wrapperElementSuffix = "";
/* 390 */     if (wrapperElementName != null) {
/* 391 */       wrapperElementPrefix = "<" + wrapperElementName;
/*     */       
/* 393 */       if (prefixes != null) {
/* 394 */         wrapperElementPrefix = wrapperElementPrefix + " ";
/* 395 */         Set keySet = prefixes.keySet();
/* 396 */         Iterator iter = keySet.iterator();
/* 397 */         while (iter.hasNext()) {
/* 398 */           String currentKey = (String)iter.next();
/* 399 */           String currentValue = (String)prefixes.get(currentKey);
/* 400 */           wrapperElementPrefix = wrapperElementPrefix + currentKey + "=\"" + currentValue + "\" ";
/*     */         } 
/*     */       } 
/*     */       
/* 404 */       wrapperElementPrefix = wrapperElementPrefix + ">";
/* 405 */       wrapperElementSuffix = wrapperElementSuffix + "</" + wrapperElementName + ">";
/*     */     } 
/*     */ 
/*     */     
/* 409 */     if (wrapperElementPrefix.trim().length() == 0 && wrapperElementSuffix.trim().length() == 0) {
/*     */       
/*     */       try {
/* 412 */         Document d = documentFactory.createDocument(uri, new StringReader(text));
/*     */         
/* 414 */         if (doc == null) {
/* 415 */           return d;
/*     */         }
/* 417 */         Node result = doc.createDocumentFragment();
/* 418 */         result.appendChild(doc.importNode(d.getDocumentElement(), true));
/*     */ 
/*     */         
/* 421 */         return result;
/* 422 */       } catch (Exception ex) {}
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 428 */     StringBuffer sb = new StringBuffer(wrapperElementPrefix.length() + text.length() + wrapperElementSuffix.length());
/*     */     
/* 430 */     sb.append(wrapperElementPrefix);
/* 431 */     sb.append(text);
/* 432 */     sb.append(wrapperElementSuffix);
/* 433 */     String newText = sb.toString();
/*     */     try {
/* 435 */       Document d = documentFactory.createDocument(uri, new StringReader(newText));
/*     */       
/* 437 */       if (doc == null) {
/* 438 */         return d;
/*     */       }
/* 440 */       for (Node node = d.getDocumentElement().getFirstChild(); node != null; 
/* 441 */         node = node.getNextSibling()) {
/* 442 */         if (node.getNodeType() == 1) {
/* 443 */           node = doc.importNode(node, true);
/* 444 */           Node result = doc.createDocumentFragment();
/* 445 */           result.appendChild(node);
/* 446 */           return result;
/*     */         } 
/*     */       } 
/* 449 */     } catch (Exception exc) {}
/*     */ 
/*     */     
/* 452 */     return null;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public static Document deepCloneDocument(Document doc, DOMImplementation impl) {
/* 459 */     Element root = doc.getDocumentElement();
/* 460 */     Document result = impl.createDocument(root.getNamespaceURI(), root.getNodeName(), null);
/*     */ 
/*     */     
/* 463 */     Element rroot = result.getDocumentElement();
/* 464 */     boolean before = true;
/* 465 */     for (Node n = doc.getFirstChild(); n != null; n = n.getNextSibling()) {
/* 466 */       if (n == root) {
/* 467 */         before = false;
/* 468 */         if (root.hasAttributes()) {
/* 469 */           NamedNodeMap attr = root.getAttributes();
/* 470 */           int len = attr.getLength();
/* 471 */           for (int i = 0; i < len; i++) {
/* 472 */             rroot.setAttributeNode((Attr)result.importNode(attr.item(i), true));
/*     */           }
/*     */         } 
/*     */         
/* 476 */         Node c = root.getFirstChild();
/* 477 */         for (; c != null; 
/* 478 */           c = c.getNextSibling()) {
/* 479 */           rroot.appendChild(result.importNode(c, true));
/*     */         }
/*     */       }
/* 482 */       else if (n.getNodeType() != 10) {
/* 483 */         if (before) {
/* 484 */           result.insertBefore(result.importNode(n, true), rroot);
/*     */         } else {
/* 486 */           result.appendChild(result.importNode(n, true));
/*     */         } 
/*     */       } 
/*     */     } 
/*     */     
/* 491 */     return result;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public static boolean isValidName(String s) {
/* 498 */     int len = s.length();
/* 499 */     if (len == 0) {
/* 500 */       return false;
/*     */     }
/* 502 */     char c = s.charAt(0);
/* 503 */     int d = c / ' ';
/* 504 */     int m = c % ' ';
/* 505 */     if ((XMLCharacters.NAME_FIRST_CHARACTER[d] & 1 << m) == 0) {
/* 506 */       return false;
/*     */     }
/* 508 */     for (int i = 1; i < len; i++) {
/* 509 */       c = s.charAt(i);
/* 510 */       d = c / ' ';
/* 511 */       m = c % ' ';
/* 512 */       if ((XMLCharacters.NAME_CHARACTER[d] & 1 << m) == 0) {
/* 513 */         return false;
/*     */       }
/*     */     } 
/* 516 */     return true;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public static boolean isValidName11(String s) {
/* 523 */     int len = s.length();
/* 524 */     if (len == 0) {
/* 525 */       return false;
/*     */     }
/* 527 */     char c = s.charAt(0);
/* 528 */     int d = c / ' ';
/* 529 */     int m = c % ' ';
/* 530 */     if ((XMLCharacters.NAME11_FIRST_CHARACTER[d] & 1 << m) == 0) {
/* 531 */       return false;
/*     */     }
/* 533 */     for (int i = 1; i < len; i++) {
/* 534 */       c = s.charAt(i);
/* 535 */       d = c / ' ';
/* 536 */       m = c % ' ';
/* 537 */       if ((XMLCharacters.NAME11_CHARACTER[d] & 1 << m) == 0) {
/* 538 */         return false;
/*     */       }
/*     */     } 
/* 541 */     return true;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 549 */   public static boolean isValidPrefix(String s) { return (s.indexOf(':') == -1); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public static String getPrefix(String s) {
/* 557 */     int i = s.indexOf(':');
/* 558 */     return (i == -1 || i == s.length() - 1) ? null : s.substring(0, i);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public static String getLocalName(String s) {
/* 568 */     int i = s.indexOf(':');
/* 569 */     return (i == -1 || i == s.length() - 1) ? s : s.substring(i + 1);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public static void parseStyleSheetPIData(String data, HashTable table) {
/* 581 */     int i = 0;
/*     */     
/* 583 */     while (i < data.length()) {
/* 584 */       char c = data.charAt(i);
/* 585 */       if (!XMLUtilities.isXMLSpace(c)) {
/*     */         break;
/*     */       }
/* 588 */       i++;
/*     */     } 
/* 590 */     while (i < data.length()) {
/*     */       
/* 592 */       char c1 = data.charAt(i);
/* 593 */       int d = c1 / ' ';
/* 594 */       int m = c1 % ' ';
/* 595 */       if ((XMLCharacters.NAME_FIRST_CHARACTER[d] & 1 << m) == 0) {
/* 596 */         throw new DOMException((short)5, "Wrong name initial:  " + c1);
/*     */       }
/*     */       
/* 599 */       StringBuffer ident = new StringBuffer();
/* 600 */       ident.append(c1);
/* 601 */       while (++i < data.length()) {
/* 602 */         c1 = data.charAt(i);
/* 603 */         d = c1 / ' ';
/* 604 */         m = c1 % ' ';
/* 605 */         if ((XMLCharacters.NAME_CHARACTER[d] & 1 << m) == 0) {
/*     */           break;
/*     */         }
/* 608 */         ident.append(c1);
/*     */       } 
/* 610 */       if (i >= data.length()) {
/* 611 */         throw new DOMException((short)12, "Wrong xml-stylesheet data: " + data);
/*     */       }
/*     */ 
/*     */       
/* 615 */       while (i < data.length()) {
/* 616 */         c1 = data.charAt(i);
/* 617 */         if (!XMLUtilities.isXMLSpace(c1)) {
/*     */           break;
/*     */         }
/* 620 */         i++;
/*     */       } 
/* 622 */       if (i >= data.length()) {
/* 623 */         throw new DOMException((short)12, "Wrong xml-stylesheet data: " + data);
/*     */       }
/*     */ 
/*     */       
/* 627 */       if (data.charAt(i) != '=') {
/* 628 */         throw new DOMException((short)12, "Wrong xml-stylesheet data: " + data);
/*     */       }
/*     */       
/* 631 */       i++;
/*     */       
/* 633 */       while (i < data.length()) {
/* 634 */         c1 = data.charAt(i);
/* 635 */         if (!XMLUtilities.isXMLSpace(c1)) {
/*     */           break;
/*     */         }
/* 638 */         i++;
/*     */       } 
/* 640 */       if (i >= data.length()) {
/* 641 */         throw new DOMException((short)12, "Wrong xml-stylesheet data: " + data);
/*     */       }
/*     */ 
/*     */       
/* 645 */       c1 = data.charAt(i);
/* 646 */       i++;
/* 647 */       StringBuffer value = new StringBuffer();
/* 648 */       if (c1 == '\'') {
/* 649 */         while (i < data.length()) {
/* 650 */           c1 = data.charAt(i);
/* 651 */           if (c1 == '\'') {
/*     */             break;
/*     */           }
/* 654 */           value.append(c1);
/* 655 */           i++;
/*     */         } 
/* 657 */         if (i >= data.length()) {
/* 658 */           throw new DOMException((short)12, "Wrong xml-stylesheet data: " + data);
/*     */         
/*     */         }
/*     */       }
/* 662 */       else if (c1 == '"') {
/* 663 */         while (i < data.length()) {
/* 664 */           c1 = data.charAt(i);
/* 665 */           if (c1 == '"') {
/*     */             break;
/*     */           }
/* 668 */           value.append(c1);
/* 669 */           i++;
/*     */         } 
/* 671 */         if (i >= data.length()) {
/* 672 */           throw new DOMException((short)12, "Wrong xml-stylesheet data: " + data);
/*     */         }
/*     */       }
/*     */       else {
/*     */         
/* 677 */         throw new DOMException((short)12, "Wrong xml-stylesheet data: " + data);
/*     */       } 
/*     */       
/* 680 */       table.put(ident.toString().intern(), value.toString());
/* 681 */       i++;
/*     */       
/* 683 */       while (i < data.length()) {
/* 684 */         c1 = data.charAt(i);
/* 685 */         if (!XMLUtilities.isXMLSpace(c1)) {
/*     */           break;
/*     */         }
/* 688 */         i++;
/*     */       } 
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected static final String[] LOCK_STRINGS = { 
/* 697 */       "", "CapsLock", "NumLock", "NumLock CapsLock", "Scroll", "Scroll CapsLock", "Scroll NumLock", "Scroll NumLock CapsLock", "KanaMode", "KanaMode CapsLock", "KanaMode NumLock", "KanaMode NumLock CapsLock", "KanaMode Scroll", "KanaMode Scroll CapsLock", "KanaMode Scroll NumLock", "KanaMode Scroll NumLock CapsLock" };
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected static final String[] MODIFIER_STRINGS = { 
/* 720 */       "", "Shift", "Control", "Control Shift", "Meta", "Meta Shift", "Control Meta", "Control Meta Shift", "Alt", "Alt Shift", "Alt Control", "Alt Control Shift", "Alt Meta", "Alt Meta Shift", "Alt Control Meta", "Alt Control Meta Shift", "AltGraph", "AltGraph Shift", "AltGraph Control", "AltGraph Control Shift", "AltGraph Meta", "AltGraph Meta Shift", "AltGraph Control Meta", "AltGraph Control Meta Shift", "Alt AltGraph", "Alt AltGraph Shift", "Alt AltGraph Control", "Alt AltGraph Control Shift", "Alt AltGraph Meta", "Alt AltGraph Meta Shift", "Alt AltGraph Control Meta", "Alt AltGraph Control Meta Shift" };
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 760 */   public static String getModifiersList(int lockState, int modifiers) { return DOMUtilitiesSupport.getModifiersList(lockState, modifiers); }
/*     */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-dom.jar!\org\apache\batik\do\\util\DOMUtilities.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */