/*     */ package org.apache.batik.dom.util;
/*     */ 
/*     */ import java.io.Serializable;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class HashTable
/*     */   implements Serializable
/*     */ {
/*     */   protected static final int INITIAL_CAPACITY = 11;
/*     */   protected Entry[] table;
/*     */   protected int count;
/*     */   
/*  50 */   public HashTable() { this.table = new Entry[11]; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  59 */   public HashTable(int c) { this.table = new Entry[c]; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public HashTable(HashTable t) {
/*  67 */     this.count = t.count;
/*  68 */     this.table = new Entry[t.table.length];
/*  69 */     for (int i = 0; i < this.table.length; i++) {
/*  70 */       Entry e = t.table[i];
/*  71 */       Entry n = null;
/*  72 */       if (e != null) {
/*  73 */         n = new Entry(e.hash, e.key, e.value, null);
/*  74 */         this.table[i] = n;
/*  75 */         e = e.next;
/*  76 */         while (e != null) {
/*  77 */           n.next = new Entry(e.hash, e.key, e.value, null);
/*  78 */           n = n.next;
/*  79 */           e = e.next;
/*     */         } 
/*     */       } 
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  89 */   public int size() { return this.count; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public Object get(Object key) {
/*  97 */     int hash = (key == null) ? 0 : (key.hashCode() & 0x7FFFFFFF);
/*  98 */     int index = hash % this.table.length;
/*     */     
/* 100 */     for (Entry e = this.table[index]; e != null; e = e.next) {
/* 101 */       if (e.hash == hash && ((e.key == null && key == null) || (e.key != null && e.key.equals(key))))
/*     */       {
/*     */         
/* 104 */         return e.value;
/*     */       }
/*     */     } 
/* 107 */     return null;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public Object put(Object key, Object value) {
/* 115 */     int hash = (key == null) ? 0 : (key.hashCode() & 0x7FFFFFFF);
/* 116 */     int index = hash % this.table.length;
/*     */     
/* 118 */     for (Entry e = this.table[index]; e != null; e = e.next) {
/* 119 */       if (e.hash == hash && ((e.key == null && key == null) || (e.key != null && e.key.equals(key)))) {
/*     */ 
/*     */         
/* 122 */         Object old = e.value;
/* 123 */         e.value = value;
/* 124 */         return old;
/*     */       } 
/*     */     } 
/*     */ 
/*     */     
/* 129 */     int len = this.table.length;
/* 130 */     if (this.count++ >= len - (len >> 2)) {
/*     */       
/* 132 */       rehash();
/* 133 */       index = hash % this.table.length;
/*     */     } 
/*     */     
/* 136 */     Entry e = new Entry(hash, key, value, this.table[index]);
/* 137 */     this.table[index] = e;
/* 138 */     return null;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public Object remove(Object key) {
/* 147 */     int hash = (key == null) ? 0 : (key.hashCode() & 0x7FFFFFFF);
/* 148 */     int index = hash % this.table.length;
/*     */     
/* 150 */     Entry p = null;
/* 151 */     for (Entry e = this.table[index]; e != null; e = e.next) {
/* 152 */       if (e.hash == hash && ((e.key == null && key == null) || (e.key != null && e.key.equals(key)))) {
/*     */ 
/*     */         
/* 155 */         Object result = e.value;
/* 156 */         if (p == null) {
/* 157 */           this.table[index] = e.next;
/*     */         } else {
/* 159 */           p.next = e.next;
/*     */         } 
/* 161 */         this.count--;
/* 162 */         return result;
/*     */       } 
/* 164 */       p = e;
/*     */     } 
/* 166 */     return null;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public Object key(int index) {
/* 173 */     if (index < 0 || index >= this.count) {
/* 174 */       return null;
/*     */     }
/* 176 */     int j = 0;
/* 177 */     for (int i = 0; i < this.table.length; i++) {
/* 178 */       Entry e = this.table[i];
/* 179 */       if (e != null)
/*     */         
/*     */         do {
/*     */           
/* 183 */           if (j++ == index) {
/* 184 */             return e.key;
/*     */           }
/* 186 */           e = e.next;
/* 187 */         } while (e != null); 
/*     */     } 
/* 189 */     return null;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public Object item(int index) {
/* 196 */     if (index < 0 || index >= this.count) {
/* 197 */       return null;
/*     */     }
/* 199 */     int j = 0;
/* 200 */     for (int i = 0; i < this.table.length; i++) {
/* 201 */       Entry e = this.table[i];
/* 202 */       if (e != null)
/*     */         
/*     */         do {
/*     */           
/* 206 */           if (j++ == index) {
/* 207 */             return e.value;
/*     */           }
/* 209 */           e = e.next;
/* 210 */         } while (e != null); 
/*     */     } 
/* 212 */     return null;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void clear() {
/* 219 */     for (int i = 0; i < this.table.length; i++) {
/* 220 */       this.table[i] = null;
/*     */     }
/* 222 */     this.count = 0;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected void rehash() {
/* 229 */     Entry[] arrayOfEntry = this.table;
/*     */     
/* 231 */     this.table = new Entry[arrayOfEntry.length * 2 + 1];
/*     */     
/* 233 */     for (int i = arrayOfEntry.length - 1; i >= 0; i--) {
/* 234 */       for (Entry old = arrayOfEntry[i]; old != null; ) {
/* 235 */         Entry e = old;
/* 236 */         old = old.next;
/*     */         
/* 238 */         int index = e.hash % this.table.length;
/* 239 */         e.next = this.table[index];
/* 240 */         this.table[index] = e;
/*     */       } 
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected static class Entry
/*     */     implements Serializable
/*     */   {
/*     */     public int hash;
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public Object key;
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public Object value;
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public Entry next;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public Entry(int hash, Object key, Object value, Entry next) {
/* 275 */       this.hash = hash;
/* 276 */       this.key = key;
/* 277 */       this.value = value;
/* 278 */       this.next = next;
/*     */     }
/*     */   }
/*     */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-dom.jar!\org\apache\batik\do\\util\HashTable.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */