/*     */ package org.apache.batik.dom.util;
/*     */ 
/*     */ import java.io.IOException;
/*     */ import java.io.InputStream;
/*     */ import java.io.InterruptedIOException;
/*     */ import java.io.Reader;
/*     */ import java.util.Iterator;
/*     */ import java.util.LinkedList;
/*     */ import java.util.List;
/*     */ import javax.xml.parsers.ParserConfigurationException;
/*     */ import javax.xml.parsers.SAXParser;
/*     */ import javax.xml.parsers.SAXParserFactory;
/*     */ import org.apache.batik.util.HaltingThread;
/*     */ import org.w3c.dom.DOMImplementation;
/*     */ import org.w3c.dom.Document;
/*     */ import org.w3c.dom.Element;
/*     */ import org.w3c.dom.Node;
/*     */ import org.w3c.dom.Text;
/*     */ import org.xml.sax.Attributes;
/*     */ import org.xml.sax.ErrorHandler;
/*     */ import org.xml.sax.InputSource;
/*     */ import org.xml.sax.Locator;
/*     */ import org.xml.sax.SAXException;
/*     */ import org.xml.sax.SAXNotRecognizedException;
/*     */ import org.xml.sax.SAXParseException;
/*     */ import org.xml.sax.XMLReader;
/*     */ import org.xml.sax.ext.LexicalHandler;
/*     */ import org.xml.sax.helpers.DefaultHandler;
/*     */ import org.xml.sax.helpers.XMLReaderFactory;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class SAXDocumentFactory
/*     */   extends DefaultHandler
/*     */   implements LexicalHandler, DocumentFactory
/*     */ {
/*     */   protected DOMImplementation implementation;
/*     */   protected String parserClassName;
/*     */   protected XMLReader parser;
/*     */   protected Document document;
/*     */   protected DocumentDescriptor documentDescriptor;
/*     */   protected boolean createDocumentDescriptor;
/*     */   protected Node currentNode;
/*     */   protected Locator locator;
/*     */   protected StringBuffer stringBuffer;
/*     */   protected boolean stringContent;
/*     */   protected boolean inDTD;
/*     */   protected boolean inCDATA;
/*     */   protected boolean inProlog;
/*     */   protected boolean isValidating;
/*     */   protected boolean isStandalone;
/*     */   protected String xmlVersion;
/*     */   protected HashTableStack namespaces;
/*     */   protected ErrorHandler errorHandler;
/*     */   protected List preInfo;
/*     */   
/*     */   protected static interface PreInfo
/*     */   {
/*     */     Node createNode(Document param1Document);
/*     */   }
/*     */   
/*     */   static class ProcessingInstructionInfo
/*     */     implements PreInfo
/*     */   {
/*     */     public String target;
/*     */     public String data;
/*     */     
/*     */     public ProcessingInstructionInfo(String target, String data) throws SAXException {
/* 163 */       this.target = target;
/* 164 */       this.data = data;
/*     */     }
/*     */     
/* 167 */     public Node createNode(Document doc) { return doc.createProcessingInstruction(this.target, this.data); }
/*     */   }
/*     */   
/*     */   static class CommentInfo
/*     */     implements PreInfo {
/*     */     public String comment;
/*     */     
/* 174 */     public CommentInfo(String comment) throws SAXException { this.comment = comment; }
/*     */ 
/*     */     
/* 177 */     public Node createNode(Document doc) { return doc.createComment(this.comment); }
/*     */   }
/*     */   
/*     */   static class CDataInfo
/*     */     implements PreInfo {
/*     */     public String cdata;
/*     */     
/* 184 */     public CDataInfo(String cdata) throws SAXException { this.cdata = cdata; }
/*     */ 
/*     */     
/* 187 */     public Node createNode(Document doc) { return doc.createCDATASection(this.cdata); }
/*     */   }
/*     */   
/*     */   static class TextInfo
/*     */     implements PreInfo {
/*     */     public String text;
/*     */     
/* 194 */     public TextInfo(String text) throws SAXException { this.text = text; }
/*     */ 
/*     */     
/* 197 */     public Node createNode(Document doc) { return doc.createTextNode(this.text); }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public SAXDocumentFactory(DOMImplementation impl, String parser) {
/*     */     this.stringBuffer = new StringBuffer();
/* 215 */     this.implementation = impl;
/* 216 */     this.parserClassName = parser;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public SAXDocumentFactory(DOMImplementation impl, String parser, boolean dd) {
/*     */     this.stringBuffer = new StringBuffer();
/* 228 */     this.implementation = impl;
/* 229 */     this.parserClassName = parser;
/* 230 */     this.createDocumentDescriptor = dd;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 242 */   public Document createDocument(String ns, String root, String uri) throws IOException { return createDocument(ns, root, uri, new InputSource(uri)); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 252 */   public Document createDocument(String uri) throws IOException { return createDocument(new InputSource(uri)); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public Document createDocument(String ns, String root, String uri, InputStream is) throws IOException {
/* 265 */     InputSource inp = new InputSource(is);
/* 266 */     inp.setSystemId(uri);
/* 267 */     return createDocument(ns, root, uri, inp);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public Document createDocument(String uri, InputStream is) throws IOException {
/* 278 */     InputSource inp = new InputSource(is);
/* 279 */     inp.setSystemId(uri);
/* 280 */     return createDocument(inp);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public Document createDocument(String ns, String root, String uri, Reader r) throws IOException {
/* 293 */     InputSource inp = new InputSource(r);
/* 294 */     inp.setSystemId(uri);
/* 295 */     return createDocument(ns, root, uri, inp);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public Document createDocument(String ns, String root, String uri, XMLReader r) throws IOException {
/* 308 */     r.setContentHandler(this);
/* 309 */     r.setDTDHandler(this);
/* 310 */     r.setEntityResolver(this);
/*     */     try {
/* 312 */       r.parse(uri);
/*     */     } catch (SAXException e) {
/* 314 */       Exception ex = e.getException();
/* 315 */       if (ex != null && ex instanceof InterruptedIOException) {
/* 316 */         throw (InterruptedIOException)ex;
/*     */       }
/* 318 */       throw new SAXIOException(e);
/*     */     } 
/* 320 */     this.currentNode = null;
/* 321 */     Document ret = this.document;
/* 322 */     this.document = null;
/* 323 */     return ret;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public Document createDocument(String uri, Reader r) throws IOException {
/* 333 */     InputSource inp = new InputSource(r);
/* 334 */     inp.setSystemId(uri);
/* 335 */     return createDocument(inp);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected Document createDocument(String ns, String root, String uri, InputSource is) throws IOException {
/* 349 */     Document ret = createDocument(is);
/* 350 */     Element docElem = ret.getDocumentElement();
/*     */     
/* 352 */     String lname = root;
/* 353 */     String nsURI = ns;
/* 354 */     if (ns == null) {
/* 355 */       int idx = lname.indexOf(':');
/* 356 */       String nsp = (idx == -1 || idx == lname.length() - 1) ? "" : lname.substring(0, idx);
/*     */ 
/*     */       
/* 359 */       nsURI = this.namespaces.get(nsp);
/* 360 */       if (idx != -1 && idx != lname.length() - 1) {
/* 361 */         lname = lname.substring(idx + 1);
/*     */       }
/*     */     } 
/*     */ 
/*     */     
/* 366 */     String docElemNS = docElem.getNamespaceURI();
/* 367 */     if (docElemNS != nsURI && (docElemNS == null || !docElemNS.equals(nsURI)))
/*     */     {
/* 369 */       throw new IOException("Root element namespace does not match that requested:\nRequested: " + nsURI + "\n" + "Found: " + docElemNS);
/*     */     }
/*     */ 
/*     */ 
/*     */     
/* 374 */     if (docElemNS != null) {
/* 375 */       if (!docElem.getLocalName().equals(lname)) {
/* 376 */         throw new IOException("Root element does not match that requested:\nRequested: " + lname + "\n" + "Found: " + docElem.getLocalName());
/*     */       
/*     */       }
/*     */     
/*     */     }
/* 381 */     else if (!docElem.getNodeName().equals(lname)) {
/* 382 */       throw new IOException("Root element does not match that requested:\nRequested: " + lname + "\n" + "Found: " + docElem.getNodeName());
/*     */     } 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 388 */     return ret;
/*     */   }
/*     */ 
/*     */ 
/*     */   
/* 393 */   static SAXParserFactory saxFactory = SAXParserFactory.newInstance();
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected Document createDocument(InputSource is) throws IOException {
/*     */     try {
/* 404 */       if (this.parserClassName != null) {
/* 405 */         this.parser = XMLReaderFactory.createXMLReader(this.parserClassName);
/*     */       } else {
/*     */         SAXParser saxParser;
/*     */         try {
/* 409 */           saxParser = saxFactory.newSAXParser();
/*     */         } catch (ParserConfigurationException pce) {
/* 411 */           throw new IOException("Could not create SAXParser: " + pce.getMessage());
/*     */         } 
/*     */         
/* 414 */         this.parser = saxParser.getXMLReader();
/*     */       } 
/*     */       
/* 417 */       this.parser.setContentHandler(this);
/* 418 */       this.parser.setDTDHandler(this);
/* 419 */       this.parser.setEntityResolver(this);
/* 420 */       this.parser.setErrorHandler((this.errorHandler == null) ? this : this.errorHandler);
/*     */ 
/*     */       
/* 423 */       this.parser.setFeature("http://xml.org/sax/features/namespaces", true);
/*     */       
/* 425 */       this.parser.setFeature("http://xml.org/sax/features/namespace-prefixes", true);
/*     */       
/* 427 */       this.parser.setFeature("http://xml.org/sax/features/validation", this.isValidating);
/*     */       
/* 429 */       this.parser.setProperty("http://xml.org/sax/properties/lexical-handler", this);
/*     */       
/* 431 */       this.parser.parse(is);
/*     */     } catch (SAXException e) {
/* 433 */       Exception ex = e.getException();
/* 434 */       if (ex != null && ex instanceof InterruptedIOException) {
/* 435 */         throw (InterruptedIOException)ex;
/*     */       }
/* 437 */       throw new SAXIOException(e);
/*     */     } 
/*     */     
/* 440 */     this.currentNode = null;
/* 441 */     Document ret = this.document;
/* 442 */     this.document = null;
/* 443 */     this.locator = null;
/* 444 */     this.parser = null;
/* 445 */     return ret;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 454 */   public DocumentDescriptor getDocumentDescriptor() { return this.documentDescriptor; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 462 */   public void setDocumentLocator(Locator l) { this.locator = l; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 473 */   public void setValidating(boolean isValidating) { this.isValidating = isValidating; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 481 */   public boolean isValidating() { return this.isValidating; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 488 */   public void setErrorHandler(ErrorHandler eh) { this.errorHandler = eh; }
/*     */ 
/*     */ 
/*     */   
/* 492 */   public DOMImplementation getDOMImplementation(String ver) { return this.implementation; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 500 */   public void fatalError(SAXParseException ex) throws SAXException { throw ex; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 508 */   public void error(SAXParseException ex) throws SAXException { throw ex; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void warning(SAXParseException ex) throws SAXException {}
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void startDocument() throws SAXException {
/* 523 */     this.preInfo = new LinkedList();
/* 524 */     this.namespaces = new HashTableStack();
/* 525 */     this.namespaces.put("xml", "http://www.w3.org/XML/1998/namespace");
/* 526 */     this.namespaces.put("xmlns", "http://www.w3.org/2000/xmlns/");
/* 527 */     this.namespaces.put("", null);
/*     */     
/* 529 */     this.inDTD = false;
/* 530 */     this.inCDATA = false;
/* 531 */     this.inProlog = true;
/* 532 */     this.currentNode = null;
/* 533 */     this.document = null;
/* 534 */     this.isStandalone = false;
/* 535 */     this.xmlVersion = "1.0";
/*     */     
/* 537 */     this.stringBuffer.setLength(0);
/* 538 */     this.stringContent = false;
/*     */     
/* 540 */     if (this.createDocumentDescriptor) {
/* 541 */       this.documentDescriptor = new DocumentDescriptor();
/*     */     } else {
/* 543 */       this.documentDescriptor = null;
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void startElement(String uri, String localName, String rawName, Attributes attributes) throws SAXException {
/*     */     Element element;
/* 556 */     if (HaltingThread.hasBeenHalted()) {
/* 557 */       throw new SAXException(new InterruptedIOException());
/*     */     }
/*     */     
/* 560 */     if (this.inProlog) {
/* 561 */       this.inProlog = false;
/*     */       try {
/* 563 */         this.isStandalone = this.parser.getFeature("http://xml.org/sax/features/is-standalone");
/*     */       }
/* 565 */       catch (SAXNotRecognizedException ex) {}
/*     */       
/*     */       try {
/* 568 */         this.xmlVersion = (String)this.parser.getProperty("http://xml.org/sax/properties/document-xml-version");
/*     */       }
/* 570 */       catch (SAXNotRecognizedException ex) {}
/*     */     } 
/*     */ 
/*     */ 
/*     */     
/* 575 */     int len = attributes.getLength();
/* 576 */     this.namespaces.push();
/* 577 */     String version = null;
/* 578 */     for (int i = 0; i < len; i++) {
/* 579 */       element = attributes.getQName(i);
/* 580 */       int slen = element.length();
/* 581 */       if (slen >= 5)
/*     */       {
/* 583 */         if (element.equals("version")) {
/* 584 */           version = attributes.getValue(i);
/*     */         
/*     */         }
/* 587 */         else if (element.startsWith("xmlns")) {
/*     */           
/* 589 */           if (slen == 5) {
/* 590 */             String ns = attributes.getValue(i);
/* 591 */             if (ns.length() == 0)
/* 592 */               ns = null; 
/* 593 */             this.namespaces.put("", ns);
/* 594 */           } else if (element.charAt(5) == ':') {
/* 595 */             String ns = attributes.getValue(i);
/* 596 */             if (ns.length() == 0) {
/* 597 */               ns = null;
/*     */             }
/* 599 */             this.namespaces.put(element.substring(6), ns);
/*     */           } 
/*     */         } 
/*     */       }
/*     */     } 
/* 604 */     appendStringData();
/*     */ 
/*     */ 
/*     */     
/* 608 */     int idx = rawName.indexOf(':');
/* 609 */     String nsp = (idx == -1 || idx == rawName.length() - 1) ? "" : rawName.substring(0, idx);
/*     */ 
/*     */     
/* 612 */     String nsURI = this.namespaces.get(nsp);
/* 613 */     if (this.currentNode == null) {
/* 614 */       this.implementation = getDOMImplementation(version);
/* 615 */       this.document = this.implementation.createDocument(nsURI, rawName, null);
/* 616 */       Iterator i = this.preInfo.iterator();
/* 617 */       this.currentNode = element = this.document.getDocumentElement();
/* 618 */       while (i.hasNext()) {
/* 619 */         PreInfo pi = (PreInfo)i.next();
/* 620 */         Node n = pi.createNode(this.document);
/* 621 */         this.document.insertBefore(n, element);
/*     */       } 
/* 623 */       this.preInfo = null;
/*     */     } else {
/* 625 */       element = this.document.createElementNS(nsURI, rawName);
/* 626 */       this.currentNode.appendChild(element);
/* 627 */       this.currentNode = element;
/*     */     } 
/*     */ 
/*     */     
/* 631 */     if (this.createDocumentDescriptor && this.locator != null) {
/* 632 */       this.documentDescriptor.setLocation(element, this.locator.getLineNumber(), this.locator.getColumnNumber());
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 638 */     for (int i = 0; i < len; i++) {
/* 639 */       String aname = attributes.getQName(i);
/* 640 */       if (aname.equals("xmlns")) {
/* 641 */         element.setAttributeNS("http://www.w3.org/2000/xmlns/", aname, attributes.getValue(i));
/*     */       }
/*     */       else {
/*     */         
/* 645 */         idx = aname.indexOf(':');
/* 646 */         nsURI = (idx == -1) ? null : this.namespaces.get(aname.substring(0, idx));
/*     */ 
/*     */         
/* 649 */         element.setAttributeNS(nsURI, aname, attributes.getValue(i));
/*     */       } 
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void endElement(String uri, String localName, String rawName) throws SAXException {
/* 660 */     appendStringData();
/*     */     
/* 662 */     if (this.currentNode != null)
/* 663 */       this.currentNode = this.currentNode.getParentNode(); 
/* 664 */     this.namespaces.pop();
/*     */   }
/*     */   
/*     */   public void appendStringData() throws SAXException {
/* 668 */     if (!this.stringContent)
/*     */       return; 
/* 670 */     String str = this.stringBuffer.toString();
/* 671 */     this.stringBuffer.setLength(0);
/* 672 */     this.stringContent = false;
/* 673 */     if (this.currentNode == null) {
/* 674 */       if (this.inCDATA) { this.preInfo.add(new CDataInfo(str)); }
/* 675 */       else { this.preInfo.add(new TextInfo(str)); }
/*     */     
/*     */     } else {
/* 678 */       Text text; if (this.inCDATA) { text = this.document.createCDATASection(str); }
/* 679 */       else { text = this.document.createTextNode(str); }
/* 680 */        this.currentNode.appendChild(text);
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void characters(char[] ch, int start, int length) throws SAXException {
/* 690 */     this.stringBuffer.append(ch, start, length);
/* 691 */     this.stringContent = true;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void ignorableWhitespace(char[] ch, int start, int length) throws SAXException {
/* 703 */     this.stringBuffer.append(ch, start, length);
/* 704 */     this.stringContent = true;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void processingInstruction(String target, String data) throws SAXException {
/* 713 */     if (this.inDTD) {
/*     */       return;
/*     */     }
/* 716 */     appendStringData();
/*     */     
/* 718 */     if (this.currentNode == null) {
/* 719 */       this.preInfo.add(new ProcessingInstructionInfo(target, data));
/*     */     } else {
/* 721 */       this.currentNode.appendChild(this.document.createProcessingInstruction(target, data));
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void startDTD(String name, String publicId, String systemId) throws SAXException {
/* 733 */     appendStringData();
/* 734 */     this.inDTD = true;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 741 */   public void endDTD() throws SAXException { this.inDTD = false; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void startEntity(String name) throws SAXException {}
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void endEntity(String name) throws SAXException {}
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void startCDATA() throws SAXException {
/* 763 */     appendStringData();
/* 764 */     this.inCDATA = true;
/* 765 */     this.stringContent = true;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void endCDATA() throws SAXException {
/* 773 */     appendStringData();
/* 774 */     this.inCDATA = false;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void comment(char[] ch, int start, int length) throws SAXException {
/* 782 */     if (this.inDTD)
/* 783 */       return;  appendStringData();
/*     */     
/* 785 */     String str = new String(ch, start, length);
/* 786 */     if (this.currentNode == null) {
/* 787 */       this.preInfo.add(new CommentInfo(str));
/*     */     } else {
/* 789 */       this.currentNode.appendChild(this.document.createComment(str));
/*     */     } 
/*     */   }
/*     */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-dom.jar!\org\apache\batik\do\\util\SAXDocumentFactory.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */